@@ -3,41 +3,22 @@
 
 =head1 NAME
 
-RDF::Query - A complete SPARQL 1.1 Query and Update implementation for use with RDF::Trine.
+RDF::Query - An RDF query implementation of SPARQL/RDQL in Perl for use with RDF::Trine.
 
 =head1 VERSION
 
-This document describes RDF::Query version 2.919.
+This document describes RDF::Query version 3.000_01, released 30 January 2010.
 
 =head1 SYNOPSIS
 
- # SPARQL SELECT Query
- my $query = RDF::Query->new( 'SELECT * WHERE ...' );
+ my $query = new RDF::Query ( $sparql );
  my $iterator = $query->execute( $model );
  while (my $row = $iterator->next) {
-   # $row is a HASHref containing variable name -> RDF Term bindings
-   print $row->{ 'var' }->as_string;
+   print $row->{ var }->as_string;
  }
  
- # SPARQL CONSTRUCT/DESCRIBE Query
- my $query = RDF::Query->new( 'CONSTRUCT { ... } WHERE ...' );
- my $iterator = $query->execute( $model );
- while (my $st = $iterator->next) {
-   # $st is a RDF::Trine::Statement object representing an RDF triple
-   print $st->as_string;
- }
- 
- # SPARQL ASK Query
- my $query = RDF::Query->new( 'ASK WHERE ...' );
- my $iterator = $query->execute( $model );
- my $bool = $iterator->get_boolean;
- if ($bool) {
-   print "Yes!\n";
- }
- 
- # RDQL Query
  my $query = new RDF::Query ( $rdql, { lang => 'rdql' } );
- my @rows = $query->execute( $model ); # in list context, returns all results
+ my @rows = $query->execute( $model );
 
 =head1 DESCRIPTION
 
@@ -49,18 +30,6 @@ See L<http://www.w3.org/TR/rdf-sparql-query/> for more information on SPARQL.
 See L<http://www.w3.org/Submission/2004/SUBM-RDQL-20040109/> for more
 information on RDQL.
 
-=head1 CHANGES IN VERSION 2.900
-
-The 2.9xx versions of RDF::Query introduce some significant changes that will
-lead to a stable 3.000 release supporting SPARQL 1.1. Version 2.902 introduces
-the SPARQL 1.1 features up to date with the SPARQL 1.1 working drafts as of its
-release date. Version 2.902 also is the first version to require use of
-RDF::Trine for the underlying RDF store. This change means that RDF::Core is
-no longer supported, and while Redland is still supported, its handling of
-"contexts" (named graphs) means that existing RDF triples stored in Redland
-without associated contexts will not be accessible from RDF::Query.
-See L<RDF::Trine::Store> for more information on supported backend stores.
-
 =head1 CHANGES IN VERSION 2.000
 
 There are many changes in the code between the 1.x and 2.x releases. Most of
@@ -131,12 +100,10 @@ use Scalar::Util qw(blessed reftype looks_like_number);
 use DateTime::Format::W3CDTF;
 
 use Log::Log4perl qw(:easy);
-if (! Log::Log4perl::initialized()) {
-    Log::Log4perl->easy_init($ERROR);
-}
+Log::Log4perl->easy_init($ERROR);
 
 no warnings 'numeric';
-use RDF::Trine 1.004;
+use RDF::Trine 0.124;
 require RDF::Query::Functions;	# (needs to happen at runtime because some of the functions rely on RDF::Query being fully loaded (to call add_hook(), for example))
 								# all the built-in functions including:
 								#     datatype casting, language ops, logical ops,
@@ -158,7 +125,7 @@ use RDF::Query::Plan;
 
 our ($VERSION, $DEFAULT_PARSER);
 BEGIN {
-	$VERSION		= '2.919';
+	$VERSION		= '3.000_01';
 	$DEFAULT_PARSER	= 'sparql11';
 }
 
@@ -171,27 +138,15 @@ BEGIN {
 
 =item C<< new ( $query, \%options ) >>
 
+=item C<< new ( $query, $baseuri, $languri, $lang, %options ) >>
+
 Returns a new RDF::Query object for the specified C<$query>.
-The query language defaults to SPARQL 1.1, but may be set specifically
-with the appropriate C<< %options >> value. Valid C<< %options >> are:
+The query language defaults to SPARQL, but may be set specifically by
+specifying either C<$languri> or C<$lang>, whose acceptable values are:
 
-* lang
+  $lang: 'rdql', 'sparql11', or 'sparql'
 
-Specifies the query language. Acceptable values are 'sparql11', 'sparql', or 'rdql'.
-
-* base_uri
-
-Specifies the base URI used in parsing the query.
-
-* update
-
-A boolean value indicating whether update operations are allowed during query execution.
-
-* load_data
-
-A boolean value indicating whether URIs used in SPARQL FROM and FROM NAMED clauses
-should be dereferenced and the resulting RDF content used to construct the dataset
-against which the query is run.
+  $languri: 'http://www.w3.org/TR/rdf-sparql-query/', or 'http://jena.hpl.hp.com/2003/07/query/RDQL'
 
 =cut
 
@@ -199,15 +154,13 @@ sub new {
 	my $class	= shift;
 	my $query	= shift;
 
-	my ($base_uri, $languri, $lang, %options);
+	my ($baseuri, $languri, $lang, %options);
 	if (@_ and ref($_[0])) {
 		%options	= %{ shift() };
-		$lang		= delete $options{ lang };
-		$base_uri	= $options{ base_uri } || $options{ base } ;
-		delete $options{ base_uri };
-		delete $options{ base };
+		$lang		= $options{ lang };
+		$baseuri	= $options{ base };
 	} else {
-		($base_uri, $languri, $lang, %options)	= @_;
+		($baseuri, $languri, $lang, %options)	= @_;
 	}
 	$class->clear_error;
 	
@@ -222,58 +175,24 @@ sub new {
 	my %uris	= (
 					'http://jena.hpl.hp.com/2003/07/query/RDQL'	=> 'RDF::Query::Parser::RDQL',
 					'http://www.w3.org/TR/rdf-sparql-query/'	=> 'RDF::Query::Parser::SPARQL',
-					'http://www.w3.org/ns/sparql-service-description#SPARQL10Query'	=> 'RDF::Query::Parser::SPARQL',
-					'http://www.w3.org/ns/sparql-service-description#SPARQL11Query'	=> 'RDF::Query::Parser::SPARQL11',
-					'http://www.w3.org/ns/sparql-service-description#SPARQL11Update'	=> 'RDF::Query::Parser::SPARQL11',
 				);
 	
-	if ($base_uri) {
-		$base_uri	= RDF::Query::Node::Resource->new( $base_uri );
+	if ($baseuri) {
+		$baseuri	= RDF::Query::Node::Resource->new( $baseuri );
 	}
 	
-	my %pargs;
-	if ($options{canonicalize}) {
-		$pargs{canonicalize}	= 1;
-	}
-	my $update	= ((delete $options{update}) ? 1 : 0);
+	my $update	= ($options{update} ? 1 : 0);
 	my $pclass	= $names{ $lang } || $uris{ $languri } || $names{ $DEFAULT_PARSER };
-	my $parser	= $pclass->new( %pargs );
-	my $parsed;
-	
-	if (ref($query) and $query->isa('RDF::Query::Algebra')) {
-		my $method	= 'SELECT';
-		$method		= 'ASK' if ($query->isa('RDF::Query::Algebra::Ask'));
-		$method		= 'CONSTRUCT' if ($query->isa('RDF::Query::Algebra::Construct'));
-		my @vars	= map { RDF::Query::Node::Variable->new($_) } _uniq($query->potentially_bound);
-		if ($method eq 'SELECT') {
-			unless ($query->isa('RDF::Query::Algebra::Project')) {
-				$query	= RDF::Query::Algebra::Project->new($query, \@vars);
-			}
-		}
-		$parsed	= {
-					method		=> $method,
-					triples		=> [$query],
-					sources		=> [],
-					base		=> $base_uri,
-					options		=> {},
-					star		=> 0,
-					variables	=> \@vars,
-				};
-		$query	= $query->as_sparql;
-	} else {
-		$parsed	= $parser->parse( $query, $base_uri, $update );
-	}
+	my $parser	= $pclass->new();
+	my $parsed	= $parser->parse( $query, $baseuri, $update );
 	
 	my $self	= $class->_new(
-					base_uri		=> $base_uri,
+					base			=> $baseuri,
 					parser			=> $parser,
 					parsed			=> $parsed,
-					query_string	=> $query,
-					update			=> $update,
-					options			=> { %options },
 				);
-	if (exists $options{load_data}) {
-		$self->{load_data}	= delete $options{load_data};
+	if ($options{load_data}) {
+		$self->{load_data}	= $options{load_data};
 	} elsif ($pclass =~ /^RDF::Query::Parser::(RDQL|SPARQL)$/) {
 		$self->{load_data}	= 1;
 	} else {
@@ -286,27 +205,27 @@ sub new {
 	}
 	
 	if (defined $options{defines}) {
-		@{ $self->{options} }{ keys %{ $options{defines} } }	= values %{ delete $options{defines} };
+		@{ $self->{options} }{ keys %{ $options{defines} } }	= values %{ $options{defines} };
 	}
 	
 	if ($options{logger}) {
 		$l->debug("got external logger");
-		$self->{logger}	= delete $options{logger};
+		$self->{logger}	= $options{logger};
 	}
 	
-	if (my $opt = delete $options{optimize}) {
+	if (my $opt = $options{optimize}) {
 		$l->debug("got optimization flag: $opt");
 		$self->{optimize}	= $opt;
 	} else {
 		$self->{optimize}	= 0;
 	}
 	
-	if (my $opt = delete $options{force_no_optimization}) {
+	if (my $opt = $options{force_no_optimization}) {
 		$l->debug("got force_no_optimization flag");
 		$self->{force_no_optimization}	= 1;
 	}
 	
-	if (my $time = delete $options{optimistic_threshold_time}) {
+	if (my $time = $options{optimistic_threshold_time}) {
 		$l->debug("got optimistic_threshold_time flag");
 		$self->{optimistic_threshold_time}	= $time;
 	}
@@ -341,7 +260,7 @@ sub get {
 	}
 }
 
-=item C<< prepare ( $model ) >>
+=item C<< prepare ( $store ) >>
 
 Prepares the query, constructing a query execution plan, and returns a list
 containing ($plan, $context). To execute the plan, call
@@ -351,29 +270,17 @@ C<< execute_plan( $plan, $context ) >>.
 
 sub prepare {
 	my $self	= shift;
-	my $_model	= shift;
+	my $store	= shift;
 	my %args	= @_;
 	my $l		= Log::Log4perl->get_logger("rdf.query");
 	
 	$self->{_query_cache}	= {};	# a new scratch hash for each execution.
-	my %bound;
-	if ($args{ 'bind' }) {
-		%bound	= %{ $args{ 'bind' } };
-	}
-	
-	my $delegate;
-	if (defined $args{ 'delegate' }) {
-		$delegate	= delete $args{ 'delegate' };
-		if ($delegate and not blessed($delegate)) {
-			$delegate	= $delegate->new();
-		}
-	}
+	my %bound	= ($args{ 'bind' }) ? %{ $args{ 'bind' } } : ();
 	my $errors	= ($args{ 'strict_errors' }) ? 1 : 0;
 	my $parsed	= $self->{parsed};
 	my @vars	= $self->variables( $parsed );
 	
-	local($self->{model})	= $self->{model};
-	my $model	= $self->{model} || $self->get_model( $_model, %args );
+	my $model	= $self->{model} || $self->get_model( $store, %args );
 	if ($model) {
 		$self->model( $model );
 		$l->debug("got model $model");
@@ -385,7 +292,6 @@ sub prepare {
 		$l->trace("loading data");
 		$self->load_data();
 	}
-	
 	$model		= $self->model();	# reload the model object, because load_data might have changed it.
 	
 	my $dataset	= ($model->isa('RDF::Trine::Model::Dataset')) ? $model : RDF::Trine::Model::Dataset->new($model);
@@ -395,22 +301,20 @@ sub prepare {
 					bound						=> \%bound,
 					model						=> $dataset,
 					query						=> $self,
-					base_uri					=> $parsed->{base_uri},
-					ns			       			=> $parsed->{namespaces},
+					base						=> $parsed->{base},
+					ns							=> $parsed->{namespaces},
 					logger						=> $self->logger,
 					optimize					=> $self->{optimize},
 					force_no_optimization		=> $self->{force_no_optimization},
 					optimistic_threshold_time	=> $self->{optimistic_threshold_time} || 0,
 					requested_variables			=> \@vars,
 					strict_errors				=> $errors,
-					options						=> $self->{options},
-					delegate					=> $delegate,
 				);
+	
 	$self->{model}		= $model;
 	
 	$l->trace("getting QEP...");
-	my %plan_args	= %{ $args{ planner_args } || {} };
-	my $plan		= $self->query_plan( $context, %plan_args );
+	my $plan		= $self->query_plan( $context );
 	$l->trace("-> done.");
 	
 	unless ($plan) {
@@ -420,66 +324,33 @@ sub prepare {
 	return ($plan, $context);
 }
 
-=item C<execute ( $model, %args )>
+=item C<execute ( $store, %args )>
 
-Executes the query using the specified RDF C<< $model >>. If called in a list
-context, returns an array of rows, otherwise returns an L<RDF::Trine::Iterator>
-object. The iterator returned may be an instance of several subclasses of
-L<RDF::Trine::Iterator>:
-
-* A L<RDF::Trine::Iterator::Bindings> object is returned for query forms producing variable binding results (SELECT queries).
-
-* A L<RDF::Trine::Iterator::Graph> object is returned for query forms producing in an RDF graph result (DESCRIBE and CONSTRUCT queries).
-
-* A L<RDF::Trine::Iterator::Boolean> object is returned for query forms producing a true/false result (ASK queries).
+Executes the query using the specified RDF C<< $store >>. If called in a list
+context, returns an array of rows, otherwise returns an iterator.
 
 =cut
 
 sub execute {
 	my $self	= shift;
-	my $model	= shift;
+	my $store	= shift;
 	my %args	= @_;
 	my $l		= Log::Log4perl->get_logger("rdf.query");
-	$l->debug("executing query with model " . ($model or ''));
+	$l->debug("executing query with model " . ($store or ''));
 	
-	my $lang_iri	= '';
-	my $parser	= $self->{parser};
-	my $name;
-	if ($parser->isa('RDF::Query::Parser::SPARQL11')) {
-		if ($self->is_update) {
-			$name		= 'SPARQL 1.1 Update';
-			$lang_iri	= 'http://www.w3.org/ns/sparql-service-description#SPARQL11Update';
-		} else {
-			$name		= 'SPARQL 1.1 Query';
-			$lang_iri	= 'http://www.w3.org/ns/sparql-service-description#SPARQL11Query';
-		}
-	} elsif ($parser->isa('RDF::Query::Parser::SPARQL')) {
-		$name		= 'SPARQL 1.0 Query';
-		$lang_iri	= 'http://www.w3.org/ns/sparql-service-description#SPARQL10Query';
-	}
-	
-	local($self->{model})	= $self->{model};
-# 	warn "model: $self->{model}";
-# 	warn "passthrough checking if model supports $lang_iri\n";
-	if ($self->{options}{allow_passthrough} and $model->supports($lang_iri)) {
-		$l->info("delegating $name execution to the underlying model");
-		return $model->get_sparql( $self->{query_string} );
-	} else {
-		my ($plan, $context)	= $self->prepare( $model, %args );
-		if ($l->is_trace) {
-			$l->trace(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
-			$l->trace($self->as_sparql);
-			$l->trace(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
-		}
-		return $self->execute_plan( $plan, $context );
+	my ($plan, $context)	= $self->prepare( $store, %args );
+	if ($l->is_trace) {
+		$l->trace(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
+		$l->trace($self->as_sparql);
+		$l->trace(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
 	}
+	return $self->execute_plan( $plan, $context );
 }
 
 =item C<< execute_plan ( $plan, $context ) >>
 
-Executes the query plan generated by the C<<prepare>> method using the supplied
-L<RDF::Query::ExecutionContext> object. Return value(s) are the same as for the
-C<<execute>> method.
+Executes the query using the supplied ExecutionContext. If called in a list
+context, returns an array of rows, otherwise returns an iterator.
 
 =cut
 
@@ -513,11 +384,18 @@ sub execute_plan {
 	
 	$plan->execute( $context );
 	my $stream	= $plan->as_iterator( $context );
+# 	my $stream	= RDF::Trine::Iterator::Bindings->new( sub { $plan->next }, \@vars, distinct => $plan->distinct, sorted_by => $plan->ordered );
+	
+	$l->debug("performing projection");
+	my $expr	= 0;
+	foreach my $v (@{ $parsed->{'variables'} }) {
+		$expr	= 1 if ($v->isa('RDF::Query::Expression::Alias'));
+	}
 	
 	if ($parsed->{'method'} eq 'DESCRIBE') {
-		$stream	= $self->describe( $stream, $context );
+		$stream	= $self->describe( $stream );
 	} elsif ($parsed->{'method'} eq 'ASK') {
-		$stream	= $self->ask( $stream, $context );
+		$stream	= $self->ask( $stream );
 	}
 	
 	$l->debug("going to call post-execute hook");
@@ -530,35 +408,9 @@ sub execute_plan {
 	}
 }
 
-=item C<< prepare_with_named_graphs ( $model, @uris ) >>
+=item C<< execute_with_named_graphs ( $store, @uris ) >>
 
-=cut
-
-sub prepare_with_named_graphs {
-	my $self		= shift;
-	my $_model		= shift;
-	my @graphs		= @_;
-	my $l		= Log::Log4perl->get_logger("rdf.query");
-#	$self->{model}	= $model;
-	my $model		= $self->get_model( $_model );
-	if ($model) {
-		$self->model( $model );
-	} else {
-		throw RDF::Query::Error::ModelError ( -text => "Could not create a model object." );
-	}
-	
-	foreach my $gdata (@graphs) {
-		my $url	= (blessed($gdata)) ? $gdata->uri_value : $gdata;
-		$l->debug("-> adding graph data $url");
-		$self->parse_url( $url, 1 );
-	}
-	
-	return $self->prepare( $model );
-}
-
-=item C<< execute_with_named_graphs ( $model, @uris ) >>
-
-Executes the query using the specified RDF C<< $model >>, loading the contents
+Executes the query using the specified RDF C<< $store >>, loading the contents
 of the specified C<@uris> into named graphs immediately prior to matching the
 query. Otherwise, acts just like C<< execute >>.
 
@@ -566,20 +418,23 @@ query. Otherwise, acts just like C<< execute >>.
 
 sub execute_with_named_graphs {
 	my $self		= shift;
-	my $_model		= shift;
-	my @graphs;
-	my @options;
-	if (scalar(@_)) {
-		if (not(blessed($_[0])) and reftype($_[0]) eq 'ARRAY') {
-			@graphs		= @{ shift(@_) };
-			@options	= @_;
-		} else {
-			@graphs		= @_;
-		}
+	my $store		= shift;
+	
+	my $l		= Log::Log4perl->get_logger("rdf.query");
+#	$self->{model}	= $model;
+	my $model		= $self->get_model( $store );
+	if ($model) {
+		$self->model( $model );
+	} else {
+		throw RDF::Query::Error::ModelError ( -text => "Could not create a model object." );
 	}
 	
-	my ($plan, $ctx)	= $self->prepare_with_named_graphs( $_model, @graphs );
-	return $self->execute_plan( $plan, $ctx );
+	foreach my $gdata (@_) {
+		$l->debug("-> adding graph data " . $gdata->uri_value);
+		$self->parse_url( $gdata->uri_value, 1 );
+	}
+	
+	return $self->execute( $model );
 }
 
 =begin private
@@ -596,30 +451,7 @@ current query.
 sub query_plan {
 	my $self	= shift;
 	my $context	= shift;
-	my %args	= @_;
 	my $parsed	= $self->{parsed};
-	
-	my $bound	= $context->bound;
-	my @bkeys	= keys %{ $bound };
-	my $model	= $context->model;
-	
-	unless ($self->{update}) {
-		if (not exists $self->{options}{'rdf.query.plan.delegate'} or $self->{options}{'rdf.query.plan.delegate'}) {
-			my $delegate_key	= $self->{update}
-								? 'http://www.w3.org/ns/sparql-service-description#SPARQL11Update'
-								: "http://www.w3.org/ns/sparql-service-description#SPARQL10Query";	# TODO: need to determine if the query is only 1.0, and if so, check for 1.0 support. otherwise check for 1.1 support
-			if (scalar(@bkeys) == 0 and $model->supports($delegate_key)) {
-				my $plan	= RDF::Query::Plan::Iterator->new( sub {
-					my $context	= shift;
-					my $model	= $context->model;
-					my $iter	= $model->get_sparql( $self->{query_string} );
-					return $iter;
-				} );
-				return $plan;
-			}
-		}
-	}
-	
 	my %constant_plan;
 	if (my $b = $self->{parsed}{bindings}) {
 		my $vars	= $b->{vars};
@@ -644,7 +476,7 @@ sub query_plan {
 	
 	my $algebra		= $self->pattern;
 	my $pclass		= $self->plan_class;
-	my @plans		= $pclass->generate_plans( $algebra, $context, %args, %constant_plan );
+	my @plans		= $pclass->generate_plans( $algebra, $context, %constant_plan );
 	
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan");
 	if (wantarray) {
@@ -676,7 +508,7 @@ sub plan_class {
 
 =begin private
 
-=item C<< describe ( $iter, $context ) >>
+=item C<describe ( $stream )>
 
 Takes a stream of matching statements and constructs a DESCRIBE graph.
 
@@ -687,8 +519,7 @@ Takes a stream of matching statements and constructs a DESCRIBE graph.
 sub describe {
 	my $self	= shift;
 	my $stream	= shift;
-	my $context	= shift;
-	my $model	= $context->model;
+	my $model	= $self->model;
 	my @nodes;
 	my %seen;
 	while (my $row = $stream->next) {
@@ -708,7 +539,8 @@ sub describe {
 	$self->{'describe_nodes'}	= [];
 	foreach my $node (@nodes) {
 		push(@{ $self->{'describe_nodes'} }, $node);
-		push(@streams, $model->bounded_description( $node ));
+		push(@streams, $model->get_statements( $node ));
+		push(@streams, $model->get_statements( undef, undef, $node ));
 	}
 	
 	my $ret	= sub {
@@ -728,7 +560,7 @@ sub describe {
 
 =begin private
 
-=item C<ask ( $iter, $context )>
+=item C<ask ( $stream )>
 
 Takes a stream of matching statements and returns a boolean query result stream.
 
@@ -739,7 +571,6 @@ Takes a stream of matching statements and returns a boolean query result stream.
 sub ask {
 	my $self	= shift;
 	my $stream	= shift;
-	my $context	= shift;
 	my $value	= $stream->next;
 	my $bool	= ($value) ? 1 : 0;
 	return RDF::Trine::Iterator::Boolean->new( [ $bool ] );
@@ -767,7 +598,6 @@ sub pattern {
 									or $triples[0]->isa('RDF::Query::Algebra::Construct')
 									or $triples[0]->isa('RDF::Query::Algebra::Load')
 									or $triples[0]->isa('RDF::Query::Algebra::Clear')
-									or $triples[0]->isa('RDF::Query::Algebra::Create')
 									or $triples[0]->isa('RDF::Query::Algebra::Update')
 								)) {
 		my $ggp		= $triples[0];
@@ -777,21 +607,6 @@ sub pattern {
 	}
 }
 
-=item C<< is_update >>
-
-=cut
-
-sub is_update {
-	my $self	= shift;
-	my $pat		= $self->pattern;
-	return 1 if ($pat->subpatterns_of_type('RDF::Query::Algebra::Clear'));
-	return 1 if ($pat->subpatterns_of_type('RDF::Query::Algebra::Copy'));
-	return 1 if ($pat->subpatterns_of_type('RDF::Query::Algebra::Create'));
-	return 1 if ($pat->subpatterns_of_type('RDF::Query::Algebra::Move'));
-	return 1 if ($pat->subpatterns_of_type('RDF::Query::Algebra::Update'));
-	return 0;
-}
-
 =item C<< as_sparql >>
 
 Returns the query as a string in the SPARQL syntax.
@@ -804,27 +619,22 @@ sub as_sparql {
 	
 	my $context	= { namespaces => { %{ $parsed->{namespaces} || {} } } };
 	my $method	= $parsed->{method};
-	
-	if ($method =~ /^(DESCRIBE|ASK)$/i) {
-		$context->{force_ggp_braces}	= 1;
-	}
-	
 	my @vars	= map { $_->as_sparql( $context, '' ) } @{ $parsed->{ variables } };
 	my $vars	= join(' ', @vars);
 	my $ggp		= $self->pattern;
 	
-	if ($method =~ /^(LOAD|CLEAR|CREATE|UPDATE)$/) {
+	if ($method =~ /^(LOAD|CLEAR|UPDATE)$/) {
 		return $ggp->as_sparql;
 	} else {
 		{
 			my $pvars	= join(' ', sort $ggp->referenced_variables);
-			my $svars	= join(' ', sort map { $_->isa('RDF::Query::Node::Resource') ? $_->as_string : $_->name } @{ $parsed->{ variables } });
+			my $svars	= join(' ', sort map { $_->name } @{ $parsed->{ variables } });
 			if ($pvars eq $svars) {
 				$vars	= '*';
 			}
 		}
 		
-		my @ns		= map { "PREFIX " . ($_ eq '__DEFAULT__' ? '' : $_) . ": <$parsed->{namespaces}{$_}>" } (sort keys %{ $parsed->{namespaces} });
+		my @ns		= map { "PREFIX $_: <$parsed->{namespaces}{$_}>" } (sort keys %{ $parsed->{namespaces} });
 		my @mod;
 		if (my $ob = $parsed->{options}{orderby}) {
 			push(@mod, 'ORDER BY ' . join(' ', map {
@@ -852,21 +662,12 @@ sub as_sparql {
 		}
 		
 		my $ns	= scalar(@ns) ? join("\n", @ns, '') : '';
-		my $sparql;
-		if ($methoddata or $ns) {
-			$sparql	= sprintf(
-				"$ns%s %s\n%s",
-				$methoddata,
-				$ggp->as_sparql( $context, '' ),
-				$mod,
-			);
-		} else {
-			$sparql	= sprintf(
-				"%s\n%s",
-				$ggp->as_sparql( $context, '' ),
-				$mod,
-			);
-		}
+		my $sparql	= sprintf(
+			"$ns%s %s\n%s",
+			$methoddata,
+			$ggp->as_sparql( $context, '' ),
+			$mod,
+		);
 		
 		chomp($sparql);
 		return $sparql;
@@ -898,12 +699,12 @@ sub sse {
 	my $ggp		= $self->pattern;
 	my $ns		= $parsed->{namespaces};
 	my $nscount	= scalar(@{ [ keys %$ns ] });
-	my $base_uri	= $parsed->{base};
+	my $base	= $parsed->{base};
 	
 	my $indent	= '  ';
 	my $context	= { namespaces => $ns, indent => $indent };
 	my $indentcount	= 0;
-	$indentcount++ if ($base_uri);
+	$indentcount++ if ($base);
 	$indentcount++ if ($nscount);
 	my $prefix	= $indent x $indentcount;
 	
@@ -913,8 +714,8 @@ sub sse {
 		$sse		= sprintf("(prefix (%s)\n${prefix}%s)", join("\n${indent}" . ' 'x9, map { "(${_}: <$ns->{$_}>)" } (sort keys %$ns)), $sse);
 	}
 	
-	if ($base_uri) {
-		$sse	= sprintf("(base <%s>\n${indent}%s)", $base_uri->uri_value, $sse);
+	if ($base) {
+		$sse	= sprintf("(base <%s>\n${indent}%s)", $base->uri_value, $sse);
 	}
 	
 	chomp($sse);
@@ -935,7 +736,7 @@ sub dateparser {
 
 =begin private
 
-=item C<< supports ( $model, $feature ) >>
+=item C<supports ( $store, $feature )>
 
 Returns a boolean value representing the support of $feature for the given model.
 
@@ -945,31 +746,17 @@ Returns a boolean value representing the support of $feature for the given model
 
 sub supports {
 	my $self	= shift;
-	my $obj		= shift;
-	my $model	= $self->get_model( $obj );
+	my $store	= shift;
+	my $model	= $self->get_model( $store );
 	return $model->supports( @_ );
 }
 
-=item C<< specifies_update_dataset >>
-
-Returns true if the query specifies a custom update dataset via the WITH or
-USING keywords, false otherwise.
-
-=cut
-
-sub specifies_update_dataset {
-	my $self	= shift;
-	no warnings 'uninitialized';
-	return $self->{parsed}{custom_update_dataset} ? 1 : 0;
-}
 
 =begin private
 
-=item C<< get_model ( $model ) >>
+=item C<< get_model ( $store ) >>
 
-Returns a model object for use during execution.
-If C<< $model >> is a usable model, it is simply returned.
-Otherwise, a temporary model is constructed and returned.
+Returns a model object for the specified RDF C<< $store >>.
 
 =end private
 
@@ -995,7 +782,7 @@ sub get_model {
 			return;
 		}
 	} elsif ($store->isa('RDF::Core::Model')) {
-		Carp::croak "RDF::Core is no longer supported";
+		die "RDF::Core is no longer supported";
 	} else {
 		Carp::confess "unknown store type: $store";
 	}
@@ -1015,15 +802,29 @@ Loads any external data required by this query (FROM and FROM NAMED clauses).
 
 sub load_data {
 	my $self	= shift;
+	my $model	= $self->model;
 	my $parsed	= $self->{parsed};
 	
 	## LOAD ANY EXTERNAL RDF FILES
 	my $sources	= $parsed->{'sources'};
-	if (ref($sources) and reftype($sources) eq 'ARRAY' and scalar(@$sources)) {
-		my $model	= RDF::Trine::Model->temporary_model;
-		$self->model( $model );
-		foreach my $source (@$sources) {
+	if (ref($sources) and reftype($sources) eq 'ARRAY') {
+		my $need_new_model	= 1;
+		my $named_query		= 0;
+		
+		# put non-named sources first, because they will cause a new model to be
+		# constructed. subsequent named data will then be loaded into the correct
+		# model object.
+		my @sources	= sort { @$a == 2 } @$sources;
+		
+		foreach my $source (@sources) {
 			my $named_source	= (2 == @{$source} and $source->[1] eq 'NAMED');
+			if ((not $named_source) and $need_new_model) {
+				# query uses FROM <..> clauses, so create a new model so we don't add the statements to a persistent default graph
+				$model				= RDF::Trine::Model->temporary_model;
+				$self->model( $model );
+				$need_new_model	= 0;
+			}
+			
 			my $uri	= $source->[0]->uri_value;
 			$self->parse_url( $uri, $named_source );
 		}
@@ -1034,7 +835,7 @@ sub load_data {
 
 =begin private
 
-=item C<< var_or_expr_value ( \%bound, $value, $context ) >>
+=item C<< var_or_expr_value ( \%bound, $value ) >>
 
 Returns an (non-variable) RDF::Query::Node value based on C<< $value >>.
 If  C<< $value >> is  a node object, it is simply returned. If it is an
@@ -1050,10 +851,9 @@ sub var_or_expr_value {
 	my $self	= shift;
 	my $bound	= shift;
 	my $v		= shift;
-	my $ctx		= shift;
 	Carp::confess 'not an object value in var_or_expr_value: ' . Dumper($v) unless (blessed($v));
 	if ($v->isa('RDF::Query::Expression')) {
-		return $v->evaluate( $self, $bound, $ctx );
+		return $v->evaluate( $self, $bound );
 	} elsif ($v->isa('RDF::Trine::Node::Variable')) {
 		return $bound->{ $v->name };
 	} elsif ($v->isa('RDF::Query::Node')) {
@@ -1322,7 +1122,7 @@ sub run_hook {
 
 =begin private
 
-=item C<< parse_url ( $url, $named ) >>
+=item C<parse_url ( $url, $named )>
 
 Retrieve a remote file by URL, and parse RDF into the RDF store.
 If $named is TRUE, associate all parsed triples with a named graph.
@@ -1390,7 +1190,6 @@ sub model {
 	}
 	my $model	= $self->{model};
 	unless (defined $model) {
-		Carp::confess "query->model shouldn't be calling get_model";
 		$model	= $self->get_model();
 	}
 	
@@ -1482,13 +1281,10 @@ Sets the object's error variable.
 sub set_error {
 	my $self	= shift;
 	my $error	= shift;
-	my $e		= shift;
 	if (blessed($self)) {
-		$self->{error}		= $error;
-		$self->{exception}	= $e;
+		$self->{error}	= $error;
 	}
-	our $_ERROR		= $error;
-	our $_EXCEPTION	= $e;
+	our $_ERROR	= $error;
 }
 
 =begin private
@@ -1504,12 +1300,10 @@ Clears the object's error variable.
 sub clear_error {
 	my $self	= shift;
 	if (blessed($self)) {
-		$self->{error}		= undef;
-		$self->{exception}	= undef;
+		$self->{error}	= undef;
 	}
-	our($_ERROR, $_EXCEPTION);
+	our $_ERROR;
 	undef $_ERROR;
-	undef $_EXCEPTION;
 }
 
 
@@ -1579,9 +1373,9 @@ L<http://www.perlrdf.org/>
 
  Gregory Todd Williams <gwilliams@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT
 
-Copyright (c) 2005-2012 Gregory Todd Williams. This
+Copyright (c) 2005-2009 Gregory Todd Williams. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
