@@ -7,7 +7,7 @@ RDF::Query::Algebra - Base class for Algebra expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra version 2.919.
+This document describes RDF::Query::Algebra version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
@@ -19,7 +19,7 @@ package RDF::Query::Algebra;
 
 our (@ISA, @EXPORT_OK);
 BEGIN {
-	our $VERSION	= '2.919';
+	our $VERSION	= '3.000_01';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
@@ -60,16 +60,14 @@ use RDF::Query::Algebra::Distinct;
 use RDF::Query::Algebra::Path;
 use RDF::Query::Algebra::Project;
 use RDF::Query::Algebra::Extend;
+use RDF::Query::Algebra::Not;
+use RDF::Query::Algebra::Exists;
 use RDF::Query::Algebra::SubSelect;
 use RDF::Query::Algebra::Load;
 use RDF::Query::Algebra::Clear;
 use RDF::Query::Algebra::Update;
 use RDF::Query::Algebra::Minus;
 use RDF::Query::Algebra::Sequence;
-use RDF::Query::Algebra::Create;
-use RDF::Query::Algebra::Copy;
-use RDF::Query::Algebra::Move;
-use RDF::Query::Algebra::Table;
 
 use constant SSE_TAGS	=> {
 	'BGP'					=> 'RDF::Query::Algebra::BasicGraphPattern',
@@ -90,14 +88,14 @@ use constant SSE_TAGS	=> {
 	'leftjoin'				=> 'RDF::Query::Algebra::Optional',
 };
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
 	return $self->referenced_variables;
 }
@@ -154,25 +152,34 @@ sub check_duplicate_blanks {
 	my @data;
 	foreach my $arg ($self->construct_args) {
 		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			$arg->check_duplicate_blanks();
+			push(@data, $arg->_check_duplicate_blanks);
+		}
+	}
+	
+	my %seen;
+	foreach my $d (@data) {
+		foreach my $b (@$d) {
+			if ($seen{ $b }++) {
+				throw RDF::Query::Error::QueryPatternError -text => "Same blank node identifier ($b) used in more than one BasicGraphPattern.";
+			}
 		}
 	}
 	
 	return 1;
 }
 
-sub _referenced_blanks {
+sub _check_duplicate_blanks {
 	my $self	= shift;
 	my @data;
 	foreach my $arg ($self->construct_args) {
 		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push( @data, $arg->_referenced_blanks );
+			push( @data, $arg->_check_duplicate_blanks );
 		}
 	}
 	return @data;
 }
 
-=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
+=item C<< qualify_uris ( \%namespaces, $base ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -183,11 +190,11 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base_uri	= shift;
+	my $base	= shift;
 	my @args;
 	foreach my $arg ($self->construct_args) {
 		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@args, $arg->qualify_uris( $ns, $base_uri ));
+			push(@args, $arg->qualify_uris( $ns, $base ));
 		} elsif (blessed($arg) and $arg->isa('RDF::Query::Node::Resource')) {
 			my $uri	= $arg->uri_value;
 			if (ref($uri)) {
@@ -256,10 +263,7 @@ sub subpatterns_of_type {
 	push(@patterns, $self) if ($self->isa($type));
 	foreach my $arg ($self->construct_args) {
 		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@patterns, $arg->subpatterns_of_type($type, $block));
-		} elsif (blessed($arg) and $arg->isa('RDF::Query')) {
-			my $pattern = $arg->pattern;
-			push(@patterns, $pattern->subpatterns_of_type($type, $block));
+			push(@patterns, $arg->subpatterns_of_type($type));
 		}
 	}
 	return @patterns;
