@@ -7,7 +7,7 @@ RDF::Query::Algebra::Aggregate - Algebra class for aggregate patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Aggregate version 2.917.
+This document describes RDF::Query::Algebra::Aggregate version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -27,16 +27,13 @@ use RDF::Trine::Iterator qw(smap);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -130,7 +127,7 @@ sub ops {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -138,13 +135,13 @@ sub sse {
 	my $self	= shift;
 	my $context	= shift;
 	my $prefix	= shift || '';
-	my $indent	= ($context->{indent} ||= '  ');
+	my $indent	= $context->{indent} || '  ';
 	
 	my @ops_sse;
 	my @ops		= $self->ops;
 	foreach my $data (@ops) {
 		my ($alias, $op, $opts, @cols)	= @$data;
-		my @col_strings	= map { (not(blessed($_)) and $_ eq '*') ? '*' : $_->sse( $context, "${prefix}${indent}" ) } @cols;
+		my @col_strings	= map { ($_ eq '*') ? '*' : $_->sse( $context, "${prefix}${indent}" ) } @cols;
 		my $col_string	= join(' ', @col_strings);
 		if (@col_strings > 1) {
 			$col_string	= '(' . $col_string . ')';
@@ -171,7 +168,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -179,7 +176,7 @@ sub as_sparql {
 	my $self	= shift;
 	my $context	= shift;
 	my $indent	= shift;
-	return $self->pattern->as_sparql($context, $indent);
+	throw RDF::Query::Error::SerializationError -text => "Aggregates can't be serialized as SPARQL";
 }
 
 =item C<< as_hash >>
@@ -191,19 +188,11 @@ Returns the query as a nested set of plain data structures (no objects).
 sub as_hash {
 	my $self	= shift;
 	my $context	= shift;
-	
-	my @ops	= $self->ops;
-	my @expressions;
-	foreach my $o (@ops) {
-		my ($alias, $op, $agg_options, @cols)	= @$o;
-		push(@expressions, { alias => $alias, op => $op, scalarvals => $agg_options, columns => [ map { $_->as_hash } @cols ] });
-	}
-	
 	return {
 		type 		=> lc($self->type),
 		pattern		=> $self->pattern->as_hash,
 		groupby		=> [ map { $_->as_hash } $self->groupby ],
-		expressions	=> \@expressions,
+		expressions	=> [ map { $_->as_hash } $self->ops ],
 	};
 }
 
@@ -229,28 +218,18 @@ sub referenced_variables {
 	return RDF::Query::_uniq( @aliases, $self->pattern->referenced_variables );
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	my @vars;
-#	push(@vars, map { $_->[0] } $self->ops);
-	foreach my $g ($self->groupby) {
-		if (blessed($g)) {
-			if ($g->isa('RDF::Query::Node::Variable')) {
-				push(@vars, $g->name);
-			} elsif ($g->isa('RDF::Query::Expression::Alias')) {
-				push(@vars, $g->name);
-			}
-		}
-	}
-	return RDF::Query::_uniq(@vars);
-#	return RDF::Query::_uniq( @aliases, $self->pattern->referenced_variables );
+	my @aliases	= map { $_->[0] } $self->ops;
+	throw Error; # XXX unimplemented
+	return RDF::Query::_uniq( @aliases, $self->pattern->referenced_variables );
 }
 
 =item C<< definite_variables >>
