@@ -7,7 +7,7 @@ RDF::Query::Algebra::BasicGraphPattern - Algebra class for BasicGraphPattern pat
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::BasicGraphPattern version 2.919.
+This document describes RDF::Query::Algebra::BasicGraphPattern version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -20,7 +20,7 @@ use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
 use Log::Log4perl;
-use Scalar::Util qw(blessed refaddr reftype);
+use Scalar::Util qw(refaddr reftype);
 use Carp qw(carp croak confess);
 use Time::HiRes qw(gettimeofday tv_interval);
 use RDF::Trine::Iterator qw(smap swatch);
@@ -30,16 +30,13 @@ use RDF::Trine::Iterator qw(smap swatch);
 our ($VERSION);
 my %AS_SPARQL;
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -84,37 +81,9 @@ sub triples {
 	return @$self;
 }
 
-=item C<< quads >>
-
-Returns a list of the (implicit) quads belonging to this BGP.
-
-=cut
-
-sub quads {
-	my $self	= shift;
-	my @triples	= $self->triples;
-	my @quads;
-	foreach my $t (@triples) {
-		my @nodes	= $t->nodes;
-		foreach my $i (0 .. 3) {
-			my $n	= $nodes[ $i ];
-			if (not blessed($n)) {
-				if ($i == 3) {
-					$nodes[ $i ]	= RDF::Trine::Node::Nil->new();
-				} else {
-					$nodes[ $i ]	= RDF::Query::Node::Variable->new();
-				}
-			}
-		}
-		my $st	= RDF::Trine::Statement::Quad->new( @nodes );
-		push(@quads, $st);
-	}
-	return @quads;
-}
-
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -131,30 +100,9 @@ sub sse {
 	);
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the algebra appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $string	= "${indent}basic graph pattern\n";
-	
-	foreach my $t ($self->triples) {
-		$string	.= "${indent}${s}" . $t->as_sparql . "\n";
-	}
-	return $string;
-}
-
-
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -193,21 +141,6 @@ sub as_hash {
 	};
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my @t		= $self->triples;
-	my @nodes	= map { $_->as_spin( $model ) } @t;
-	return @nodes;
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -229,16 +162,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq(map { $_->referenced_variables } $self->triples);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq(map { $_->potentially_bound } $self->triples);
+	return RDF::Query::_uniq(map { $_->binding_variables } $self->triples);
 }
 
 =item C<< definite_variables >>
@@ -252,7 +185,14 @@ sub definite_variables {
 	return RDF::Query::_uniq(map { $_->definite_variables } $self->triples);
 }
 
-sub _referenced_blanks {
+=item C<< check_duplicate_blanks >>
+
+Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
+across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
+
+=cut
+
+sub _check_duplicate_blanks {
 	my $self	= shift;
 	my %seen;
 	foreach my $t ($self->triples) {
@@ -266,7 +206,7 @@ sub _referenced_blanks {
 
 =item C<< connected >>
 
-Returns true if the pattern is connected through shared variables, false otherwise.
+Returns true if the pattern is connected through shared variables, fase otherwise.
 
 =cut
 
