@@ -7,7 +7,7 @@ RDF::Query::Algebra::Construct - Algebra class for construct query results
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Construct version 2.919.
+This document describes RDF::Query::Algebra::Construct version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -28,16 +28,13 @@ use RDF::Trine::Iterator qw(sgrep);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -99,7 +96,7 @@ sub triples {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -107,45 +104,32 @@ sub sse {
 	my $self	= shift;
 	my $context	= shift;
 	my $prefix	= shift || '';
-	my $indent	= $context->{indent} || '  ';
-	my $triples	= join("\n${prefix}${indent}${indent}", map { $_->sse( $context, "${prefix}${indent}${indent}" ) } @{$self->triples});
+	my $indent	= $context->{indent};
 	
 	return sprintf(
-		"(construct\n${prefix}${indent}(\n${prefix}${indent}${indent}%s\n${prefix}${indent})\n${prefix}${indent}%s)",
-		$triples,
+		'(construct\n${prefix}${indent}%s)',
 		$self->pattern->sse( $context, "${prefix}${indent}" ),
 	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift;
 	my $triples	= $self->triples;
 	my $bgp		= RDF::Query::Algebra::BasicGraphPattern->new( @$triples );
 	my $ggp		= RDF::Query::Algebra::GroupGraphPattern->new( $bgp );
-	my $force	= $context->{ force_ggp_braces } || 0;
-	
-	my ($template, $pattern);
-	{
-		$context->{ force_ggp_braces }	= $force + 1;
-		$template	= $ggp->as_sparql( $context, $indent );
-	}
-	{
-		$context->{ force_ggp_braces }	= $force + 1;
-		$pattern		= $self->pattern->as_sparql( $context, $indent );
-	}
-	
+
 	my $string	= sprintf(
 		"CONSTRUCT %s\n${indent}WHERE %s",
-		$template,
-		$pattern,
+		$ggp->as_sparql( $context, $indent ),
+		$self->pattern->as_sparql( $context, $indent ),
 	);
 	return $string;
 }
@@ -188,16 +172,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq($self->pattern->referenced_variables);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return $self->pattern->potentially_bound;
+	return RDF::Query::_uniq($self->pattern->binding_variables);
 }
 
 =item C<< definite_variables >>
