@@ -7,7 +7,7 @@ RDF::Query::Algebra::Distinct - Algebra class for distinct query results
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Distinct version 2.919.
+This document describes RDF::Query::Algebra::Distinct version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -28,16 +28,13 @@ use RDF::Trine::Iterator qw(sgrep);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -83,7 +80,7 @@ sub pattern {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -94,14 +91,14 @@ sub sse {
 	my $indent	= $context->{indent} || '  ';
 	
 	return sprintf(
-		"(distinct\n${prefix}${indent}%s)",
+		'(distinct\n${prefix}${indent}%s)',
 		$self->pattern->sse( $context, "${prefix}${indent}" ),
 	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -128,25 +125,6 @@ sub as_hash {
 	};
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my $spin	= RDF::Trine::Namespace->new('http://spinrdf.org/spin#');
-	my $xsd		= RDF::Trine::Namespace->new('http://www.w3.org/2001/XMLSchema#');
-	my $q		= $self->pattern->as_spin( $model );
-	
-	$model->add_statement( RDF::Trine::Statement->new($q, $spin->distinct, RDF::Query::Node::Literal->new('true', undef, $xsd->boolean)) );
-	
-	return $q;
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -168,16 +146,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq($self->pattern->referenced_variables);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return $self->pattern->potentially_bound;
+	return RDF::Query::_uniq($self->pattern->binding_variables);
 }
 
 =item C<< definite_variables >>
