@@ -7,7 +7,7 @@ RDF::Query::Algebra::Filter - Algebra class for Filter expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Filter version 2.919.
+This document describes RDF::Query::Algebra::Filter version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -29,7 +29,7 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -42,9 +42,6 @@ BEGIN {
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -109,7 +106,7 @@ sub pattern {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -128,28 +125,19 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift || '';
 	
-	if ($context->{ skip_filter }) {
-		$context->{ skip_filter }--;
-		return $self->pattern->as_sparql( $context, $indent );
-	}
-	
 	my $expr	= $self->expr;
 	my $filter_sparql	= $expr->as_sparql( $context, $indent );
 	my $pattern_sparql	= $self->pattern->as_sparql( $context, $indent );
-	if ($pattern_sparql =~ m#}\s*$#) {
-		$pattern_sparql		=~ s#}\s*$#${indent}\tFILTER( ${filter_sparql} ) .\n${indent}}#;
-	} else {
-		$pattern_sparql		= "${pattern_sparql}\n${indent}FILTER( ${filter_sparql} )";
-	}
+	$pattern_sparql		=~ s#}\s*$#${indent}\tFILTER( ${filter_sparql} ) .\n${indent}}#;
 	return $pattern_sparql;
 }
 
@@ -169,19 +157,6 @@ sub as_hash {
 	};
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	return $self->pattern->as_spin($model);
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -212,16 +187,16 @@ sub referenced_variables {
 	}
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return $self->pattern->potentially_bound;
+	return $self->pattern->binding_variables;
 }
 
 =item C<< definite_variables >>
