@@ -7,7 +7,7 @@ RDF::Query::Algebra::GroupGraphPattern - Algebra class for GroupGraphPattern pat
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::GroupGraphPattern version 2.918.
+This document describes RDF::Query::Algebra::GroupGraphPattern version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -19,7 +19,7 @@ no warnings 'redefine';
 use base qw(RDF::Query::Algebra);
 
 use Log::Log4perl;
-use Scalar::Util qw(blessed refaddr);
+use Scalar::Util qw(blessed);
 use Data::Dumper;
 use List::Util qw(first);
 use Carp qw(carp croak confess);
@@ -32,7 +32,7 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 	our %SERVICE_BLOOM_IGNORE	= ('http://dbpedia.org/sparql' => 1);	# by default, assume dbpedia doesn't implement k:bloom().
 }
 
@@ -40,9 +40,6 @@ BEGIN {
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -101,32 +98,9 @@ sub add_pattern {
 	push( @{ $self }, $pattern );
 }
 
-=item C<< quads >>
-
-Returns a list of the quads belonging to this GGP.
-
-=cut
-
-sub quads {
-	my $self	= shift;
-	my @quads;
-	my %bgps;
-	foreach my $p ($self->subpatterns_of_type('RDF::Query::Algebra::NamedGraph')) {
-		push(@quads, $p->quads);
-		foreach my $bgp ($p->subpatterns_of_type('RDF::Query::Algebra::BasicGraphPattern')) {
-			$bgps{ refaddr($bgp) }++;
-		}
-	}
-	foreach my $p ($self->subpatterns_of_type('RDF::Query::Algebra::BasicGraphPattern')) {
-		next if ($bgps{ refaddr($p) });
-		push(@quads, $p->quads);
-	}
-	return @quads;
-}
-
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -134,7 +108,7 @@ sub sse {
 	my $self	= shift;
 	my $context	= shift;
 	my $prefix	= shift || '';
-	my $indent	= ($context->{indent} ||= "\t");
+	my $indent	= $context->{indent} || "\t";
 	
 	my @patterns	= $self->patterns;
 	if (scalar(@patterns) == 1) {
@@ -147,68 +121,25 @@ sub sse {
 	}
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the algebra appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $string	= "${indent}group graph pattern\n";
-
-	my @patterns	= $self->patterns;
-	if (scalar(@patterns) == 1) {
-		$string	.= $patterns[0]->explain( $s, $count+1 );
-	} else {
-		foreach my $p (@patterns) {
-			if ($p->can('explain')) {
-				$string	.= $p->explain( $s, $count+1 );
-			} else {
-				my $str	= $p->sse;
-				$str	.= "\n" unless (substr($str,-1) eq "\n");
-				$string	.= $str;
-			}
-		}
-	}
-	return $string;
-}
-
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift || '';
-	my $force	= $context->{force_ggp_braces};
-	$force		= 0 unless (defined($force));
-	if ($force) {
-		$context->{force_ggp_braces}--;
-	}
 	
 	my @patterns;
-	my @p	= $self->patterns;
-	
-	if (scalar(@p) == 0) {
-		return "{}";
-	} elsif (scalar(@p) == 1 and not($force)) {
-		return $p[0]->as_sparql($context, $indent);
-	} else {
-		foreach my $p (@p) {
-			push(@patterns, $p->as_sparql( $context, "$indent\t" ));
-		}
-		my $patterns	= join("\n${indent}\t", @patterns);
-		my $string		= sprintf("{\n${indent}\t%s\n${indent}}", $patterns);
-		return $string;
+	foreach my $p ($self->patterns) {
+		push(@patterns, $p->as_sparql( $context, "$indent\t" ));
 	}
+	return "{}" unless (@patterns);
+	my $patterns	= join("\n${indent}\t", @patterns);
+	my $string		= sprintf("{\n${indent}\t%s\n${indent}}", $patterns);
+	return $string;
 }
 
 =item C<< as_hash >>
@@ -226,20 +157,6 @@ sub as_hash {
 	};
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	return map { $_->as_spin($model) } $self->patterns;
-	
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -261,16 +178,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq(map { $_->referenced_variables } $self->patterns);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq(map { $_->potentially_bound } $self->patterns);
+	return RDF::Query::_uniq(map { $_->binding_variables } $self->patterns);
 }
 
 =item C<< definite_variables >>
@@ -284,34 +201,6 @@ sub definite_variables {
 	return RDF::Query::_uniq(map { $_->definite_variables } $self->patterns);
 }
 
-=item C<< check_duplicate_blanks >>
-
-Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
-across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
-
-=cut
-
-sub check_duplicate_blanks {
-	my $self	= shift;
-	my @data;
-	foreach my $arg ($self->construct_args) {
-		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@data, $arg->_referenced_blanks());
-		}
-	}
-	
-	my %seen;
-	foreach my $d (@data) {
-		foreach my $b (@$d) {
-			if ($seen{ $b }++) {
-				throw RDF::Query::Error::QueryPatternError -text => "Same blank node identifier ($b) used in more than one BasicGraphPattern.";
-			}
-		}
-	}
-	
-	return 1;
-}
-
 1;
 
 __END__
