@@ -7,7 +7,7 @@ RDF::Query::Algebra::Load - Algebra class for LOAD operations
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Load version 2.918.
+This document describes RDF::Query::Algebra::Load version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -32,16 +32,13 @@ our ($VERSION);
 my %TRIPLE_LABELS;
 my @node_methods	= qw(subject predicate object);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -56,8 +53,7 @@ sub new {
 	my $class	= shift;
 	my $url		= shift;
 	my $graph	= shift;
-	my $silent	= shift;
-	return bless([$url, $graph, $silent], $class);
+	return bless([$url, $graph], $class);
 }
 
 =item C<< construct_args >>
@@ -69,12 +65,12 @@ will produce a clone of this algebra pattern.
 
 sub construct_args {
 	my $self	= shift;
-	return ($self->url, $self->graph, $self->silent);
+	return ($self->url, $self->graph);
 }
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -86,18 +82,15 @@ sub sse {
 	my $url		= $self->url;
 	my $graph	= $self->graph;
 	my $string;
-	my $s		= $self->silent ? "SILENT " : '';
 	if ($graph) {
 		$string	= sprintf(
-			"(load %s<%s> <%s>)",
-			$s,
+			"(load <%s> <%s>)",
 			$url->uri_value,
 			$graph->uri_value,
 		);
 	} else {
 		$string	= sprintf(
-			"(load %s<%s>)",
-			$s,
+			"(load <%s>)",
 			$url->uri_value,
 		);
 	}
@@ -106,7 +99,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -117,19 +110,16 @@ sub as_sparql {
 	
 	my $url		= $self->url;
 	my $graph	= $self->graph;
-	my $s		= $self->silent ? "SILENT " : '';
 	my $string;
 	if ($graph) {
 		$string	= sprintf(
-			"LOAD %s<%s> INTO GRAPH <%s>",
-			$s,
+			"LOAD <%s> INTO GRAPH <%s>",
 			$url->uri_value,
 			$graph->uri_value,
 		);
 	} else {
 		$string	= sprintf(
-			"LOAD %s<%s>",
-			$s,
+			"LOAD <%s>",
 			$url->uri_value,
 		);
 	}
@@ -174,14 +164,6 @@ sub graph {
 	return $self->[1];
 }
 
-=item C<< silent >>
-
-=cut
-
-sub silent {
-	my $self	= shift;
-	return $self->[2];
-}
 
 1;
 
