@@ -7,7 +7,7 @@ RDF::Query::Algebra::Minus - Algebra class for Minus patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Minus version 2.919.
+This document describes RDF::Query::Algebra::Minus version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -26,16 +26,13 @@ use RDF::Trine::Iterator qw(smap sgrep swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -89,7 +86,7 @@ sub minus {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -108,7 +105,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -161,16 +158,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq($self->pattern->referenced_variables, $self->minus->referenced_variables);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return $self->pattern->potentially_bound;
+	return RDF::Query::_uniq($self->pattern->binding_variables, $self->minus->binding_variables);
 }
 
 =item C<< definite_variables >>
