@@ -7,7 +7,7 @@ RDF::Query::Algebra::NamedGraph - Algebra class for NamedGraph patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::NamedGraph version 2.919.
+This document describes RDF::Query::Algebra::NamedGraph version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -29,16 +29,13 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -95,34 +92,9 @@ sub pattern {
 	return $self->[2];
 }
 
-=item C<< quads >>
-
-Returns a list of the quads belonging to this NamedGraph.
-
-=cut
-
-sub quads {
-	my $self	= shift;
-	my @quads;
-	foreach my $p ($self->subpatterns_of_type('RDF::Query::Algebra::BasicGraphPattern')) {
-		push(@quads, $p->quads);
-	}
-	my @graphquads;
-	foreach my $q (@quads) {
-		my $st	= RDF::Trine::Statement::Quad->new(
-					$q->subject,
-					$q->predicate,
-					$q->object,
-					$self->graph,
-				);
-		push(@graphquads, $st);
-	}
-	return @graphquads;
-}
-
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -139,40 +111,20 @@ sub sse {
 	);
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the algebra appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $string	= "${indent}named graph pattern\n"
-				. "${indent}${s}graph: " . $self->graph->as_string . "\n"
-				. $self->pattern->explain( $s, $count+1 );
-	return $string;
-}
-
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift;
-	my $pcontext	= { %$context, force_ggp_braces => 1 };
-	
 	my $string	= sprintf(
 		"GRAPH %s %s",
 		$self->graph->as_sparql( $context, $indent ),
-		$self->pattern->as_sparql( $pcontext, $indent ),
+		$self->pattern->as_sparql( $context, $indent ),
 	);
 	return $string;
 }
@@ -193,28 +145,6 @@ sub as_hash {
 	};
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my $spin	= RDF::Trine::Namespace->new('http://spinrdf.org/spin#');
-	my $rdf		= RDF::Trine::Namespace->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#');
-	my @t		= $self->pattern->as_spin( $model );
-	
-	my $ng		= RDF::Query::Node::Blank->new();
-	my $list	= $model->add_list( @t );
-	$model->add_statement( RDF::Trine::Statement->new($ng, $rdf->type, $spin->NamedGraph) );
-	$model->add_statement( RDF::Trine::Statement->new($ng, $spin->elements, $list) );
-	
-	return $ng;
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -240,17 +170,17 @@ sub referenced_variables {
 	return @list;
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
 	my @list	= RDF::Query::_uniq(
-		$self->pattern->potentially_bound,
+		$self->pattern->binding_variables,
 		(map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph)),
 	);
 	return @list;
@@ -265,13 +195,13 @@ Returns a list of the variable names that will be bound after evaluating this al
 sub definite_variables {
 	my $self	= shift;
 	return RDF::Query::_uniq(
-		$self->pattern->definite_variables,
 		map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph),
+		$self->pattern->definite_variables,
 	);
 }
 
 
-=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
+=item C<< qualify_uris ( \%namespaces, $base ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -282,9 +212,9 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base_uri	= shift;
+	my $base	= shift;
 	
-	my $pattern	= $self->pattern->qualify_uris( $ns, $base_uri );
+	my $pattern	= $self->pattern->qualify_uris( $ns, $base );
 	my $graph	= $self->graph;
 	if (blessed($graph) and $graph->isa('RDF::Query::Node::Resource')) {
 		my $uri	= $graph->uri;
@@ -294,39 +224,12 @@ sub qualify_uris {
 				throw RDF::Query::Error::QuerySyntaxError -text => "Namespace $n is not defined";
 			}
 			my $resolved	= join('', $ns->{ $n }, $l);
-			$graph			= RDF::Query::Node::Resource->new( $resolved, $base_uri );
+			$graph			= RDF::Query::Node::Resource->new( $resolved, $base );
 		}
 	}
 	return $class->new( $graph, $pattern );
 }
 
-=item C<< check_duplicate_blanks >>
-
-Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
-across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
-
-=cut
-
-sub check_duplicate_blanks {
-	my $self	= shift;
-	my @data;
-	foreach my $arg ($self->construct_args) {
-		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@data, $arg->_referenced_blanks());
-		}
-	}
-	
-	my %seen;
-	foreach my $d (@data) {
-		foreach my $b (@$d) {
-			if ($seen{ $b }++) {
-				throw RDF::Query::Error::QueryPatternError -text => "Same blank node identifier ($b) used in more than one BasicGraphPattern.";
-			}
-		}
-	}
-	
-	return 1;
-}
 
 1;
 
