@@ -7,7 +7,7 @@ RDF::Query::Algebra::Optional - Algebra class for Optional patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Optional version 2.919.
+This document describes RDF::Query::Algebra::Optional version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -26,16 +26,13 @@ use RDF::Trine::Iterator qw(smap sgrep swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -89,7 +86,7 @@ sub optional {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -97,7 +94,7 @@ sub sse {
 	my $self	= shift;
 	my $context	= shift;
 	my $prefix	= shift || '';
-	my $indent	= $context->{indent} || '  ';
+	my $indent	= $context->{indent};
 	
 	return sprintf(
 		"(leftjoin\n${prefix}${indent}%s\n${prefix}${indent}%s)",
@@ -108,7 +105,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -119,32 +116,11 @@ sub as_sparql {
 	my $string	= sprintf(
 		"%s\n${indent}OPTIONAL %s",
 		$self->pattern->as_sparql( $context, $indent ),
-		$self->optional->as_sparql( { %$context, force_ggp_braces => 1 }, $indent ),
+		$self->optional->as_sparql( $context, $indent ),
 	);
 	return $string;
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my $spin	= RDF::Trine::Namespace->new('http://spinrdf.org/spin#');
-	my $rdf		= RDF::Trine::Namespace->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#');
-	my @lhs		= $self->pattern->as_spin($model);
-	my @rhs		= $self->optional->as_spin($model);
-	my $opt		= RDF::Query::Node::Blank->new();
-	my $list	= $model->add_list( @rhs );
-	$model->add_statement( RDF::Trine::Statement->new($opt, $rdf->type, $spin->Optional) );
-	$model->add_statement( RDF::Trine::Statement->new($opt, $spin->elements, $list) );
-	return (@lhs, $opt);
-}
-
 =item C<< as_hash >>
 
 Returns the query as a nested set of plain data structures (no objects).
@@ -182,16 +158,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq($self->pattern->referenced_variables, $self->optional->referenced_variables);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq($self->pattern->potentially_bound, $self->optional->potentially_bound);
+	return RDF::Query::_uniq($self->pattern->binding_variables, $self->optional->binding_variables);
 }
 
 =item C<< definite_variables >>
