@@ -7,7 +7,7 @@ RDF::Query::Algebra::Path - Algebra class for path patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Path version 2.919.
+This document describes RDF::Query::Algebra::Path version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -27,21 +27,18 @@ use Carp qw(carp croak confess);
 our ($VERSION, $debug, $lang, $languri);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
 
-=item C<new ( $start, [ $op, @paths ], $end, $graph )>
+=item C<new ( $start, [ $op, @paths ], $end )>
 
 Returns a new Path structure.
 
@@ -52,8 +49,7 @@ sub new {
 	my $start	= shift;
 	my $path	= shift;
 	my $end		= shift;
-	my $graph	= shift;
-	return bless( [ $start, $path, $end, $graph ], $class );
+	return bless( [ $start, $path, $end ], $class );
 }
 
 =item C<< construct_args >>
@@ -65,7 +61,7 @@ will produce a clone of this algebra pattern.
 
 sub construct_args {
 	my $self	= shift;
-	return ($self->start, $self->path, $self->end, $self->graph);
+	return ($self->start, $self->path, $self->end);
 }
 
 =item C<< path >>
@@ -101,17 +97,6 @@ sub end {
 	return $self->[2];
 }
 
-=item C<< graph >>
-
-Returns the named graph.
-
-=cut
-
-sub graph {
-	my $self	= shift;
-	return $self->[3];
-}
-
 =item C<< distinguish_bnode_variables >>
 
 Returns a new Path object with blank nodes replaced by distinguished variables.
@@ -161,7 +146,7 @@ sub _bounded_length {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -174,17 +159,12 @@ sub sse {
 	my $end		= $self->end->sse( $context, $prefix );
 	my $path	= $self->path;
 	my $psse	= $self->_expand_path( $path, 'sse' );
-	if ($self->graph) {
-		my $graph	= $self->graph->sse( $context, $prefix );
-		return sprintf( '(path %s %s %s %s)', $start, $psse, $end, $graph );
-	} else {
-		return sprintf( '(path %s %s %s)', $start, $psse, $end );
-	}
+	return sprintf( '(path %s %s %s)', $start, $psse, $end );
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -215,9 +195,6 @@ sub _expand_path {
 		my ($op, @nodes)	= @$array;
 		my @nodessse	= map { $self->_expand_path($_, $method) } @nodes;
 		my $psse;
-# 		if ($op eq 'DISTINCT') {
-# 			$psse	= 'DISTINCT(' . join('/', @nodessse) . ')';
-# 		}
 		if ($op eq '+') {
 			$psse	= (scalar(@nodessse) == 1) ? $nodessse[0] . $op : '(' . join('/', @nodessse) . ')' . $op;
 		} elsif ($op eq '*') {
@@ -239,7 +216,7 @@ sub _expand_path {
 		} elsif ($op =~ /^(\d+)-$/) {
 			$psse	= join('/', @nodessse) . "{$1,}";
 		} else {
-			confess "Serialization of unknown path type $op";
+			die "Serialization of unknown path type $op";
 		}
 		return $psse;
 	}
@@ -267,14 +244,14 @@ sub referenced_variables {
 	return RDF::Query::_uniq(map { $_->name } @vars);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
 	my @vars	= grep { $_->isa('RDF::Query::Node::Variable') } ($self->start, $self->end);
 	return RDF::Query::_uniq(map { $_->name } @vars);
