@@ -7,7 +7,7 @@ RDF::Query::Algebra::Project - Algebra class for projection
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Project version 2.919.
+This document describes RDF::Query::Algebra::Project version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -20,7 +20,7 @@ use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
 use Set::Scalar;
-use Scalar::Util qw(reftype blessed refaddr);
+use Scalar::Util qw(reftype blessed);
 use Carp qw(carp croak confess);
 use RDF::Trine::Iterator qw(sgrep);
 
@@ -28,16 +28,13 @@ use RDF::Trine::Iterator qw(sgrep);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -52,9 +49,6 @@ sub new {
 	my $class	= shift;
 	my $pattern	= shift;
 	my $vars	= shift;
-	unless (blessed($pattern)) {
-		throw RDF::Query::Error::MethodInvocationError -text => "Sub-pattern in RDF::Query::Algebra::Project constructor must be a valid algebra object";
-	}
 	unless (reftype($vars) eq 'ARRAY' and not(blessed($vars))) {
 		throw RDF::Query::Error::MethodInvocationError -text => "Variable list in RDF::Query::Algebra::Project constructor must be an ARRAY reference";
 	}
@@ -110,7 +104,7 @@ sub vars {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -165,17 +159,16 @@ sub _from_sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift;
 	
 	my $pattern	= $self->pattern;
-	$context->{ force_ggp_braces }++;
 	
 	my ($vars, $_sparql);
 	my $vlist	= $self->vars;
@@ -189,55 +182,7 @@ sub as_sparql {
 			push(@vars, $k);
 		}
 	}
-	
-	my $aggregate	= 0;
 	my $group	= '';
-	my $having	= '';
-	my $order	= '';
-	my %agg_projections;
-	my @aggs	= $pattern->subpatterns_of_type( 'RDF::Query::Algebra::Aggregate' );
-	if (@aggs) {
-		# aggregate check
-		my $p	= $pattern;
-		if ($p->isa('RDF::Query::Algebra::Sort')) {
-			$context->{ skip_sort }++;
-			$order	= $p->_as_sparql_order_exprs( $context, $indent );
-			$p	= $p->pattern
-		}
-		if ($p->isa('RDF::Query::Algebra::Filter')) {
-			$context->{ skip_filter }++;
-			$having	= $p->expr->as_sparql( $context, $indent );
-			$p		= $p->pattern;
-		}
-		$p	= ($p->patterns)[0] if ($p->isa('RDF::Query::Algebra::GroupGraphPattern') and scalar(@{[$p->patterns]}) == 1);
-		if ($p->isa('RDF::Query::Algebra::Extend') and $p->pattern->isa('RDF::Query::Algebra::Aggregate')) {
-			my $pp	= $p->pattern;
-			$context->{ skip_extend }++;
-			my $vlist	= $p->vars;
-			foreach my $k (@$vlist) {
-				if ($k->isa('RDF::Query::Expression::Alias')) {
-					my $var		= $k->name;
-					my $expr	= $k->expression;
-					my $exprstr;
-					if ($expr->isa('RDF::Query::Expression::Binary')) {
-						$exprstr	= $expr->as_sparql( $context, $indent );
-					} else {
-						$exprstr	= $k->expression->name;
-					}
-					my $str		= "($exprstr AS ?$var)";
-					$agg_projections{ '?' . $var }	= $str;
-				} else {
-					warn Dumper($k) . ' ';
-				}
-			}
-			
-			my @groups	= $pp->groupby;
-			if (@groups) {
-				$group	= join(' ', map { $_->as_sparql($context, $indent) } @groups);
-			}
-		}
-	}
-	
 	if ($pattern->isa('RDF::Query::Algebra::Extend')) {
 		my %seen;
 		my $vlist	= $pattern->vars;
@@ -265,21 +210,15 @@ sub as_sparql {
 			$_sparql	= $pp->as_sparql( $context, $indent );
 		}
 	} else {
-		my $pvars	= join(' ', map { my $agg = $agg_projections{ "?$_" }; defined($agg) ? $agg : "?$_" } sort $self->pattern->referenced_variables);
-		my $svars	= join(' ', map { my $agg = $agg_projections{ $_ }; defined($agg) ? $agg : $_ } sort @vars);
-		$vars		= ($pvars eq $svars) ? '*' : join(' ', map { my $agg = $agg_projections{ $_ }; defined($agg) ? $agg : $_ } @vars);
+		my $pvars	= join(' ', map { '?' . $_ } sort $self->pattern->referenced_variables);
+		my $svars	= join(' ', sort @vars);
+		$vars	= ($pvars eq $svars) ? '*' : join(' ', @vars);
 		$_sparql	= $pattern->as_sparql( $context, $indent );
 	}
 	my $sparql	= sprintf("%s WHERE %s", $vars, $_sparql);
 	if ($group) {
 		$sparql	.= "\n${indent}GROUP BY $group";
 	}
-	if ($having) {
-		$sparql	.= "\n${indent}HAVING $having";
-	}
-	if ($order) {
-		$sparql	.= "\n${indent}ORDER BY $order";
-	}
 	return $sparql;
 }
 
@@ -299,32 +238,6 @@ sub as_hash {
 	};
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my $spin	= RDF::Trine::Namespace->new('http://spinrdf.org/spin#');
-	my $rdf		= RDF::Trine::Namespace->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#');
-	my $q		= RDF::Query::Node::Blank->new();
-	my @nodes	= $self->pattern->as_spin( $model );
-	
-	$model->add_statement( RDF::Trine::Statement->new($q, $rdf->type, $spin->Select) );
-	
-	my @vars	= map { RDF::Query::Node::Blank->new( "variable_" . $_->name ) } @{ $self->vars };
-	my $vlist	= $model->add_list( @vars );
-	$model->add_statement( RDF::Trine::Statement->new($q, $spin->resultVariables, $vlist) );
-	
-	my $list	= $model->add_list( @nodes );
-	$model->add_statement( RDF::Trine::Statement->new($q, $spin->where, $list) );
-	return $q;
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -354,45 +267,21 @@ sub referenced_variables {
 	return RDF::Query::_uniq(@vars);
 }
 
-=item C<< bind_variables ( \%bound ) >>
-
-Returns a new algebra pattern with variables named in %bound replaced by their corresponding bound values.
-
-=cut
-
-sub bind_variables {
-	my $self	= shift;
-	my $class	= ref($self);
-	my $bound	= shift;
-	my $pattern	= $self->pattern->bind_variables( $bound );
-	my $vars	= $self->vars;
-	my @vars;
-	foreach my $v (@$vars) {
-		if (blessed($v) and $v->isa('RDF::Query::Node::Variable') and exists $bound->{ $v->name }) {
-			push(@vars, $bound->{ $v->name });
-		} else {
-			push(@vars, $v);
-		}
-	}
-	return $class->new( $pattern, \@vars );
-}
-
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	my @vars;
-#	push(@vars, $self->pattern->potentially_bound);
+	my @vars	= $self->pattern->binding_variables;
 	foreach my $v (@{ $self->vars }) {
 		if ($v->isa('RDF::Query::Node::Variable')) {
 			push(@vars, $v->name);
 		} else {
-			push(@vars, $v->potentially_bound);
+			push(@vars, $v->binding_variables);
 		}
 	}
 	return RDF::Query::_uniq(@vars);
