@@ -7,7 +7,7 @@ RDF::Query::Algebra::Quad - Algebra class for Quad patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Quad version 2.919.
+This document describes RDF::Query::Algebra::Quad version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -28,48 +28,20 @@ use RDF::Trine::Iterator qw(smap sgrep swatch);
 my %QUAD_LABELS;
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
 
-=item C<new ( $s, $p, $o, $g )>
-
-Returns a new Quad structure.
-
-=cut
-
-sub new {
-	my $class	= shift;
-	my @nodes	= @_;
-	unless (scalar(@nodes) == 4) {
-		throw RDF::Query::Error::MethodInvocationError -text => "Quad constructor must have four node arguments";
-	}
-	my @names	= qw(subject predicate object context);
-	foreach my $i (0 .. 3) {
-		unless (defined($nodes[ $i ]) and blessed($nodes[ $i ])) {
-			$nodes[ $i ]	= RDF::Query::Node::Variable->new($names[ $i ]);
-		}
-		unless ($nodes[ $i ]->isa('RDF::Query::Node')) {
-			$nodes[ $i ]	= RDF::Query::Node->from_trine( $nodes[ $i ] );
-		}
-	}
-	
-	return $class->SUPER::new( @nodes );
-}
-
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -122,7 +94,7 @@ sub referenced_blanks {
 	return map { $_->blank_identifier } @blanks;
 }
 
-=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
+=item C<< qualify_uris ( \%namespaces, $base ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -133,7 +105,7 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base_uri	= shift;
+	my $base	= shift;
 	my @nodes;
 	foreach my $n ($self->nodes) {
 		my $blessed	= blessed($n);
@@ -144,7 +116,7 @@ sub qualify_uris {
 				unless (exists($ns->{ $n })) {
 					throw RDF::Query::Error::QuerySyntaxError -text => "Namespace $n is not defined";
 				}
-				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base_uri );
+				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base );
 				push(@nodes, $resolved);
 			} else {
 				push(@nodes, $n);
@@ -157,7 +129,7 @@ sub qualify_uris {
 				unless (exists($ns->{ $n })) {
 					throw RDF::Query::Error::QuerySyntaxError -text => "Namespace $n is not defined";
 				}
-				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base_uri );
+				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base );
 				my $lit			= RDF::Query::Node::Literal->new( $node->literal_value, undef, $resolved->uri_value );
 				push(@nodes, $lit);
 			} else {
