@@ -7,7 +7,7 @@ RDF::Query::Algebra::Sequence - Algebra class for a sequence of algebra operatio
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Sequence version 2.919.
+This document describes RDF::Query::Algebra::Sequence version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -20,7 +20,7 @@ use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
 use Log::Log4perl;
-use Scalar::Util qw(refaddr reftype blessed);
+use Scalar::Util qw(refaddr reftype);
 use Carp qw(carp croak confess);
 use Time::HiRes qw(gettimeofday tv_interval);
 use RDF::Trine::Iterator qw(smap swatch);
@@ -30,16 +30,13 @@ use RDF::Trine::Iterator qw(smap swatch);
 our ($VERSION);
 my %AS_SPARQL;
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -81,7 +78,7 @@ sub patterns {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -91,7 +88,7 @@ sub sse {
 	my $prefix	= shift || '';
 	my $indent	= $context->{indent} || '  ';
 	
-	my @patterns	= map { $_->sse( $context ) } $self->patterns;
+	my @patterns	= sort map { $_->sse( $context ) } $self->patterns;
 	return sprintf(
 		"(sequence\n${prefix}${indent}%s\n${prefix})",
 		join("\n${prefix}${indent}", @patterns)
@@ -100,7 +97,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -160,17 +157,17 @@ sub referenced_variables {
 	return RDF::Query::_uniq(map { $_->referenced_variables } $self->patterns);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
 	my @patterns	= $self->patterns;
-	return $patterns[ $#patterns ]->potentially_bound;
+	return $patterns[ $#patterns ]->binding_variables;
 }
 
 =item C<< definite_variables >>
@@ -182,7 +179,7 @@ Returns a list of the variable names that will be bound after evaluating this al
 sub definite_variables {
 	my $self	= shift;
 	my @patterns	= $self->patterns;
-	return $patterns[ $#patterns ]->potentially_bound;
+	return $patterns[ $#patterns ]->binding_variables;
 }
 
 =item C<< clone >>
@@ -208,45 +205,6 @@ sub bind_variables {
 	return $class->new( map { $_->bind_variables( $bound ) } $self->patterns );
 }
 
-=item C<< check_duplicate_blanks >>
-
-Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
-across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
-
-=cut
-
-sub check_duplicate_blanks {
-	my $self	= shift;
-	my @data;
-	foreach my $arg (grep { blessed($_) and $_->isa('RDF::Query::Algebra::Update') and $_->data_only } $self->construct_args) {
-		push(@data, [$arg, $arg->_referenced_blanks()]);
-	}
-	
-	my %seen;
-	foreach my $d (@data) {
-		my ($pat, $data)	= @$d;
-		foreach my $b (@$data) {
-			if ($seen{ $b }) {
-				throw RDF::Query::Error::QueryPatternError -text => "Same blank node identifier ($b) used in more than one BasicGraphPattern.";
-			}
-			$seen{ $b }	= $pat;
-		}
-	}
-	
-	return 1;
-}
-
-sub _referenced_blanks {
-	my $self	= shift;
-	my @data;
-	foreach my $arg ($self->pattern) {
-		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push( @data, $arg->_referenced_blanks );
-		}
-	}
-	return @data;
-}
-
 sub DESTROY {
 	my $self	= shift;
 	delete $AS_SPARQL{ refaddr( $self ) };
