@@ -7,7 +7,7 @@ RDF::Query::Algebra::Service - Algebra class for SERVICE (federation) patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Service version 2.919.
+This document describes RDF::Query::Algebra::Service version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -32,21 +32,18 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 our ($VERSION, $BLOOM_FILTER_ERROR_RATE);
 BEGIN {
 	$BLOOM_FILTER_ERROR_RATE	= 0.1;
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
 
-=item C<new ( $endpoint, $pattern, $silent )>
+=item C<new ( $endpoint, $pattern )>
 
 Returns a new Service structure.
 
@@ -56,9 +53,7 @@ sub new {
 	my $class		= shift;
 	my $endpoint	= shift;
 	my $pattern		= shift;
-	my $silent		= shift || 0;
-	my $ggp			= shift;
-	return bless( [ 'SERVICE', $endpoint, $pattern, $silent, $ggp ], $class );
+	return bless( [ 'SERVICE', $endpoint, $pattern ], $class );
 }
 
 =item C<< construct_args >>
@@ -70,7 +65,7 @@ will produce a clone of this algebra pattern.
 
 sub construct_args {
 	my $self	= shift;
-	return ($self->endpoint, $self->pattern, $self->silent, $self->lhs);
+	return ($self->endpoint, $self->pattern);
 }
 
 =item C<< endpoint >>
@@ -104,33 +99,38 @@ sub pattern {
 	return $self->[2];
 }
 
-=item C<< silent >>
+=item C<< add_bloom ( $variable, $filter ) >>
 
-Returns true if the service operation is to ignore errors during execution.
+Adds a FILTER to the enclosed GroupGraphPattern to restrict values of the named
+C<< $variable >> to the values encoded in the C<< $filter >> (a
+L<Bloom::Filter|Bloom::Filter> object).
 
 =cut
 
-sub silent {
+sub add_bloom {
 	my $self	= shift;
-	return $self->[3];
-}
-
-=item C<< lhs >>
-
-If the SERVCE operation uses a variable endpoint, then it is considered a binary
-operator, executing the left-hand-side pattern first, and using results from it
-to bind endpoint URL values to use in SERVICE evaluation.
-
-=cut
-
-sub lhs {
-	my $self	= shift;
-	return $self->[4];
+	my $class	= ref($self);
+	my $var		= shift;
+	my $bloom	= shift;
+	my $l		= Log::Log4perl->get_logger("rdf.query.algebra.service");
+	
+	unless (blessed($var)) {
+		$var	= RDF::Query::Node::Variable->new( $var );
+	}
+	
+	my $pattern	= $self->pattern;
+	my $iri		= RDF::Query::Node::Resource->new('http://kasei.us/code/rdf-query/functions/bloom/filter');
+	$l->debug("Adding a bloom filter (with " . $bloom->key_count . " items) function to a remote query");
+	my $frozen	= $bloom->freeze;
+	my $literal	= RDF::Query::Node::Literal->new( $frozen );
+	my $expr	= RDF::Query::Expression::Function->new( $iri, $var, $literal );
+	my $filter	= RDF::Query::Algebra::Filter->new( $expr, $pattern );
+	return $class->new( $self->endpoint, $filter );
 }
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -140,25 +140,16 @@ sub sse {
 	my $prefix	= shift || '';
 	my $indent	= $context->{indent};
 	
-	if (my $ggp = $self->lhs) {
-		return sprintf(
-			"(service\n${prefix}${indent}%s\n${prefix}${indent}%s\n${prefix}${indent}%s)",
-			$self->lhs->sse( $context, "${prefix}${indent}" ),
-			$self->endpoint->sse( $context, "${prefix}${indent}" ),
-			$self->pattern->sse( $context, "${prefix}${indent}" )
-		);
-	} else {
-		return sprintf(
-			"(service\n${prefix}${indent}%s\n${prefix}${indent}%s)",
-			$self->endpoint->sse( $context, "${prefix}${indent}" ),
-			$self->pattern->sse( $context, "${prefix}${indent}" )
-		);
-	}
+	return sprintf(
+		"(service\n${prefix}${indent}%s\n${prefix}${indent}%s)",
+		$self->endpoint->sse( $context, "${prefix}${indent}" ),
+		$self->pattern->sse( $context, "${prefix}${indent}" )
+	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -166,26 +157,12 @@ sub as_sparql {
 	my $self	= shift;
 	my $context	= shift;
 	my $indent	= shift;
-	my $op		= ($self->silent) ? 'SERVICE SILENT' : 'SERVICE';
-	if (my $ggp = $self->lhs) {
-		local($context->{skip_filter})	= 0;
-		my $string	= sprintf(
-			"%s\n${indent}%s %s %s",
-			$ggp->as_sparql( $context, $indent ),
-			$op,
-			$self->endpoint->as_sparql( $context, $indent ),
-			$self->pattern->as_sparql( { %$context, force_ggp_braces => 1 }, $indent ),
-		);
-		return $string;
-	} else {
-		my $string	= sprintf(
-			"%s %s %s",
-			$op,
-			$self->endpoint->as_sparql( $context, $indent ),
-			$self->pattern->as_sparql( { %$context, force_ggp_braces => 1 }, $indent ),
-		);
-		return $string;
-	}
+	my $string	= sprintf(
+		"SERVICE %s %s",
+		$self->endpoint->as_sparql( $context, $indent ),
+		$self->pattern->as_sparql( $context, $indent ),
+	);
+	return $string;
 }
 
 =item C<< as_hash >>
@@ -201,7 +178,6 @@ sub as_hash {
 		type 		=> lc($self->type),
 		endpoint	=> $self->endpoint,
 		pattern		=> $self->pattern->as_hash,
-		lhs			=> $self->lhs->as_hash,
 	};
 }
 
@@ -224,24 +200,19 @@ Returns a list of the variable names used in this algebra expression.
 sub referenced_variables {
 	my $self	= shift;
 	my @list	= $self->pattern->referenced_variables;
-	push(@list, $self->lhs->referenced_variables) if ($self->lhs);
-	return RDF::Query::_uniq(@list);
+	return @list;
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	my @list	= RDF::Query::_uniq($self->pattern->potentially_bound);
-	if ($self->lhs) {
-		push(@list, $self->lhs->potentially_bound);
-	}
-	return @list;
+	return $self->pattern->binding_variables;
 }
 
 =item C<< definite_variables >>
@@ -255,12 +226,11 @@ sub definite_variables {
 	return RDF::Query::_uniq(
 		map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph),
 		$self->pattern->definite_variables,
-		($self->lhs ? $self->lhs->definite_variables : ()),
 	);
 }
 
 
-=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
+=item C<< qualify_uris ( \%namespaces, $base ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -271,17 +241,12 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base_uri	= shift;
+	my $base	= shift;
 	
-	my $pattern		= $self->pattern->qualify_uris( $ns, $base_uri );
+	my $pattern	= $self->pattern->qualify_uris( $ns, $base );
 	my $endpoint	= $self->endpoint;
-	my $silent		= $self->silent;
 	my $uri	= $endpoint->uri;
-	if (my $ggp = $self->lhs) {
-		return $class->new( $endpoint, $pattern, $silent, $ggp->qualify_uris($ns, $base_uri) );
-	} else {
-		return $class->new( $endpoint, $pattern, $silent );
-	}
+	return $class->new( $endpoint, $pattern );
 }
 
 1;
