@@ -7,7 +7,7 @@ RDF::Query::Algebra::Sort - Algebra class for sorting
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Sort version 2.919.
+This document describes RDF::Query::Algebra::Sort version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -29,16 +29,13 @@ use Time::HiRes qw(gettimeofday tv_interval);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -98,7 +95,7 @@ sub orderby {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -124,34 +121,14 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
-	my $self	= shift;
-	my $context	= shift || {};
-	my $indent	= shift;
-	
-	if ($context->{ skip_sort }) {
-		$context->{ skip_sort }--;
-		return $self->pattern->as_sparql( $context, $indent );
-	}
-	
-	my $order_exprs	= $self->_as_sparql_order_exprs($context, $indent);
-	
-	my $string	= sprintf(
-		"%s\nORDER BY %s",
-		$self->pattern->as_sparql( $context, $indent ),
-		$order_exprs,
-	);
-	return $string;
-}
-
-sub _as_sparql_order_exprs {
 	my $self	= shift;
 	my $context	= shift;
-	my $intent	= shift;
+	my $indent	= shift;
 	
 	my @order_sparql;
 	my @orderby	= $self->orderby;
@@ -163,7 +140,13 @@ sub _as_sparql_order_exprs {
 						: sprintf("%s(%s)", $dir, $val->as_sparql( $context ));
 		push(@order_sparql, $str);
 	}
-	return join(' ', @order_sparql);
+	
+	my $string	= sprintf(
+		"%s\nORDER BY %s",
+		$self->pattern->as_sparql( $context, $indent ),
+		join(' ', @order_sparql),
+	);
+	return $string;
 }
 
 =item C<< as_hash >>
@@ -175,17 +158,10 @@ Returns the query as a nested set of plain data structures (no objects).
 sub as_hash {
 	my $self	= shift;
 	my $context	= shift;
-	
-	my @order	= $self->orderby;
-	my @expressions;
-	foreach my $o (@order) {
-		push(@expressions, { type => 'comparator', direction => $o->[0], expression => $o->[1]->as_hash });
-	}
-	
 	return {
 		type 		=> lc($self->type),
 		pattern		=> $self->pattern->as_hash,
-		order		=> \@expressions,
+		order		=> [ map { $_->as_hash } $self->orderby ],
 	};
 }
 
@@ -210,16 +186,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq($self->pattern->referenced_variables);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq($self->pattern->potentially_bound);
+	return RDF::Query::_uniq($self->pattern->binding_variables);
 }
 
 =item C<< definite_variables >>
