@@ -7,7 +7,7 @@ RDF::Query::Algebra::TimeGraph - Algebra class for temporal patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::TimeGraph version 2.919.
+This document describes RDF::Query::Algebra::TimeGraph version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -25,16 +25,13 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -102,7 +99,7 @@ sub time_triples {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -122,7 +119,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -164,19 +161,19 @@ sub referenced_variables {
 	);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
 	return RDF::Query::_uniq(
 		map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph),
-		$self->pattern->potentially_bound,
-		$self->time_triples->potentially_bound,
+		$self->pattern->binding_variables,
+		$self->time_triples->binding_variables,
 	);
 }
 
