@@ -7,7 +7,7 @@ RDF::Query::Algebra::Triple - Algebra class for Triple patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Triple version 2.919.
+This document describes RDF::Query::Algebra::Triple version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -32,16 +32,13 @@ our ($VERSION);
 my %TRIPLE_LABELS;
 my @node_methods	= qw(subject predicate object);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -60,11 +57,7 @@ sub new {
 			$nodes[ $i ]	= RDF::Query::Node::Variable->new($node_methods[ $i ]);
 		}
 		if (blessed($nodes[ $i ]) and not($nodes[ $i ]->isa('RDF::Query::Node'))) {
-			if ($nodes[ $i ]->isa('RDF::Trine::Node')) {
-				$nodes[ $i ]	= RDF::Query::Node->from_trine( $nodes[ $i ] );
-			} elsif ($nodes[ $i ]->does('Attean::API::TermOrVariable')){
-				$nodes[ $i ]	= RDF::Query::Node->from_attean( $nodes[ $i ] );
-			}
+			$nodes[ $i ]	= RDF::Query::Node->from_trine( $nodes[ $i ] );
 		}
 	}
 	return $class->_new( @nodes );
@@ -77,7 +70,7 @@ sub _new {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -119,31 +112,6 @@ sub as_hash {
 	};
 }
 
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my $spin	= RDF::Trine::Namespace->new('http://spinrdf.org/spin#');
-	my $t		= RDF::Query::Node::Blank->new();
-	my @nodes	= $self->nodes;
-	foreach (@nodes) {
-		if (blessed($_) and $_->isa('RDF::Trine::Node::Variable')) {
-			$_	= RDF::Query::Node::Blank->new( "variable_" . $_->name );
-		}
-	}
-	
-	$model->add_statement( RDF::Trine::Statement->new($t, $spin->subject, $nodes[0]) );
-	$model->add_statement( RDF::Trine::Statement->new($t, $spin->predicate, $nodes[1]) );
-	$model->add_statement( RDF::Trine::Statement->new($t, $spin->object, $nodes[2]) );
-	return $t;
-}
-
 =item C<< referenced_blanks >>
 
 Returns a list of the blank node names used in this algebra expression.
