@@ -7,7 +7,7 @@ RDF::Query::Algebra::Union - Algebra class for Union patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Union version 2.919.
+This document describes RDF::Query::Algebra::Union version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -28,16 +28,13 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -103,7 +100,7 @@ sub second {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -122,7 +119,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -132,8 +129,8 @@ sub as_sparql {
 	my $indent	= shift;
 	my $string	= sprintf(
 		"%s\n${indent}UNION\n${indent}%s",
-		$self->first->as_sparql( { %$context, force_ggp_braces => 1 }, $indent ),
-		$self->second->as_sparql( { %$context, force_ggp_braces => 1 }, $indent ),
+		$self->first->as_sparql( $context, $indent ),
+		$self->second->as_sparql( $context, $indent ),
 	);
 	return $string;
 }
@@ -174,16 +171,16 @@ sub referenced_variables {
 	return RDF::Query::_uniq($self->first->referenced_variables, $self->second->referenced_variables);
 }
 
-=item C<< potentially_bound >>
+=item C<< binding_variables >>
 
 Returns a list of the variable names used in this algebra expression that will
 bind values during execution.
 
 =cut
 
-sub potentially_bound {
+sub binding_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq($self->first->potentially_bound, $self->second->potentially_bound);
+	return RDF::Query::_uniq($self->first->binding_variables, $self->second->binding_variables);
 }
 
 =item C<< definite_variables >>
