@@ -7,7 +7,7 @@ RDF::Query::Algebra::Update - Algebra class for UPDATE operations
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Update version 2.918.
+This document describes RDF::Query::Algebra::Update version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -32,21 +32,18 @@ our ($VERSION);
 my %TRIPLE_LABELS;
 my @node_methods	= qw(subject predicate object);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
 
-=item C<new ( $delete_template, $insert_template, $pattern, \%dataset, $data_only_flag )>
+=item C<new ( $delete_template, $insert_template, $pattern [, \%dataset] )>
 
 Returns a new UPDATE structure.
 
@@ -58,8 +55,7 @@ sub new {
 	my $insert	= shift;
 	my $pat		= shift;
 	my $dataset	= shift;
-	my $data	= shift;
-	return bless([$delete, $insert, $pat, $dataset, $data], $class);
+	return bless([$delete, $insert, $pat, $dataset], $class);
 }
 
 =item C<< construct_args >>
@@ -76,7 +72,7 @@ sub construct_args {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -117,17 +113,18 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift || '';
 	my $delete	= $self->delete_template;
 	my $insert	= $self->insert_template;
 	my $ggp		= $self->pattern;
+	my @pats	= $ggp->patterns;
 	
 	my $dataset	= $self->dataset;
 	my @ds_keys	= keys %{ $dataset || {} };
@@ -141,37 +138,7 @@ sub as_sparql {
 		$ds_string	= join("\n${indent}", @strings);
 	}
 	
-	if ($insert or $delete) {
-		# TODO: $(delete|insert)->as_sparql here isn't properly serializing GRAPH blocks, because even though they contain Quad objects inside of BGPs, there's no containing NamedGraph object...
-		if ($ds_string) {
-			$ds_string	= "\n${indent}$ds_string";
-		}
-		
-		if ($insert and $delete) {
-			return sprintf(
-				"DELETE {\n${indent}	%s\n${indent}}\n${indent}INSERT {\n${indent}	%s\n${indent}}\n${indent}%s\n${indent}WHERE %s",
-				$delete->as_sparql( $context, "${indent}  " ),
-				$insert->as_sparql( $context, "${indent}  " ),
-				$ds_string,
-				$ggp->as_sparql( { %$context, force_ggp_braces => 1 }, ${indent} ),
-			);
-		} elsif ($insert) {
-			return sprintf(
-				"INSERT {\n${indent}	%s\n${indent}}\n${indent}%s\n${indent}WHERE %s",
-				$insert->as_sparql( $context, "${indent}  " ),
-				$ds_string,
-				$ggp->as_sparql( { %$context, force_ggp_braces => 1 }, ${indent} ),
-			);
-		} else {
-			return sprintf(
-				"DELETE {\n${indent}	%s\n${indent}}\n${indent}%s\n${indent}WHERE %s",
-				$delete->as_sparql( $context, "${indent}  " ),
-				$ds_string,
-				$ggp->as_sparql( { %$context, force_ggp_braces => 1 }, ${indent} ),
-			);
-		}
-	} else {
-		my @pats	= $ggp->patterns;
+	if (not($insert) or not($delete)) {
 		my $op		= ($delete) ? 'DELETE' : 'INSERT';
 		my $temp	= ($delete) ? $delete : $insert;
 		my $temps	= ($temp->isa('RDF::Query::Algebra::GroupGraphPattern'))
@@ -192,9 +159,21 @@ sub as_sparql {
 				"${op} %s%sWHERE %s",
 				$temps,
 				$ds_string,
-				$ggp->as_sparql( { %$context, force_ggp_braces => 1 }, "${indent}" ),
+				$ggp->as_sparql( $context, "${indent}" ),
 			);
 		}
+	} else {
+		if ($ds_string) {
+			$ds_string	= "\n${indent}$ds_string";
+		}
+# 		my @ds_string	= ($ds_string) ? $ds_string : ();
+		return sprintf(
+			"DELETE {\n${indent}	%s\n${indent}}\n${indent}INSERT {\n${indent}	%s\n${indent}}\n${indent}%s\n${indent}WHERE %s",
+			$delete->as_sparql( $context, "${indent}  " ),
+			$insert->as_sparql( $context, "${indent}  " ),
+			$ds_string,
+			$ggp->as_sparql( $context, ${indent} ),
+		);
 	}
 }
 
@@ -254,36 +233,6 @@ sub dataset {
 	return $self->[3];
 }
 
-=item C<< data_only >>
-
-=cut
-
-sub data_only {
-	my $self	= shift;
-	return $self->[4];
-}
-
-=item C<< check_duplicate_blanks >>
-
-Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
-across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
-
-=cut
-
-sub check_duplicate_blanks {
-	my $self	= shift;
-	unless ($self->data_only) {
-		# if self isn't an INSERT/DELETE DATA operation, then we need to check the template patterns, too
-		if ($self->delete_template) {
-			$self->delete_template->check_duplicate_blanks;
-		}
-		
-		if ($self->insert_tempalte) {
-			$self->insert_tempalte->check_duplicate_blanks;
-		}
-	}
-	return $self->pattern->check_duplicate_blanks;
-}
 
 1;
 
