@@ -7,14 +7,7 @@ RDF::Query::BGPOptimizer - Optimizer for ordering the joins of triple patterns i
 
 =head1 VERSION
 
-This document describes RDF::Query::BGPOptimizer version 2.919.
-
-=head1 STATUS
-
-This module's API and functionality should be considered unstable.
-In the future, this module may change in backwards-incompatible ways,
-or be removed entirely. If you need functionality that this module provides,
-please L<get in touch|http://www.perlrdf.org/>.
+This document describes RDF::Query::BGPOptimizer version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
@@ -35,7 +28,7 @@ use RDF::Query::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
