@@ -7,7 +7,7 @@ RDF::Query::Error - Error classes for RDF::Query.
 
 =head1 VERSION
 
-This document describes RDF::Query::Error version 2.919.
+This document describes RDF::Query::Error version 3.000_01, released 30 January 2010.
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,7 @@ use base qw(Error);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -102,10 +102,6 @@ package RDF::Query::Error::PermissionError;
 
 use base qw(RDF::Query::Error);
 
-package RDF::Query::Error::UnimplementedError;
-
-use base qw(RDF::Query::Error);
-
 
 
 1;
