@@ -7,7 +7,7 @@ RDF::Query::ExecutionContext - Query execution context
 
 =head1 VERSION
 
-This document describes RDF::Query::ExecutionContext version 2.918.
+This document describes RDF::Query::ExecutionContext version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
@@ -24,7 +24,7 @@ use warnings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -96,15 +96,6 @@ sub query {
 	return $self->_get_value( 'query', @_ );
 }
 
-=item C<< options >>
-
-=cut
-
-sub options {
-	my $self	= shift;
-	return $self->_get_value( 'options', @_ );
-}
-
 =item C<< bound >>
 
 =cut
@@ -114,26 +105,13 @@ sub bound {
 	return $self->_get_value( 'bound', @_ ) || {};
 }
 
-=item C<< bind_variable ( $varname => $node ) >>
+=item C<< base >>
 
 =cut
 
-sub bind_variable {
+sub base {
 	my $self	= shift;
-	my $var		= shift;
-	my $term	= shift;
-	my $bound	= $self->_get_value( 'bound', @_ ) || {};
-	$bound->{$var}	= $term;
-	return $self->_get_value('bound', $bound);
-}
-
-=item C<< base_uri >>
-
-=cut
-
-sub base_uri {
-	my $self	= shift;
-	return $self->_get_value( 'base_uri', @_ ) || {};
+	return $self->_get_value( 'base', @_ ) || {};
 }
 
 =item C<< ns >>
@@ -199,21 +177,11 @@ sub optimistic_threshold_time {
 	return $self->_get_value( 'optimistic_threshold_time', @_ );
 }
 
-=item C<< delegate >>
-
-=cut
-
-sub delegate {
-	my $self	= shift;
-	return $self->_get_value( 'delegate', @_ );
-}
-
 sub _get_value {
 	my $self	= shift;
 	my $key		= shift;
 	if (@_) {
 		$self->[0]{ $key }	= shift;
-		return $self->[0]{ $key };
 	}
 	foreach my $i (0 .. $#{ $self }) {
 		if (exists($self->[ $i ]{ $key })) {
