@@ -7,7 +7,7 @@ RDF::Query::Expression::Alias - Class for aliasing expressions with variable nam
 
 =head1 VERSION
 
-This document describes RDF::Query::Expression::Alias version 2.919.
+This document describes RDF::Query::Expression::Alias version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -26,16 +26,13 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Expression> class.
-
 =over 4
 
 =cut
@@ -76,7 +73,7 @@ sub expression {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -93,7 +90,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -106,7 +103,7 @@ sub as_sparql {
 	return sprintf("(%s AS %s)", $expr->as_sparql, $alias->as_sparql);
 }
 
-=item C<< evaluate ( $query, \%bound, $context ) >>
+=item C<< evaluate ( $query, \%bound ) >>
 
 Evaluates the expression using the supplied bound variables.
 Will return a RDF::Query::Node object.
@@ -117,28 +114,11 @@ sub evaluate {
 	my $self	= shift;
 	my $query	= shift;
 	my $bound	= shift;
-	my $ctx		= shift;
 	my $expr	= $self->expression;
-	my $value	= $query->var_or_expr_value( $bound, $expr, $ctx );
+	my $value	= $query->var_or_expr_value( $bound, $expr );
 	return $value;
 }
 
-=item C<< as_hash >>
-
-Returns the alias as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> 'alias',
-		alias		=> $self->alias->as_hash,
-		expression	=> $self->expression->as_hash,
-	};
-}
-
 
 1;
 
