@@ -7,7 +7,7 @@ RDF::Query::Expression::Binary - Algebra class for binary expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Expression::Binary version 2.919.
+This document describes RDF::Query::Expression::Binary version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -27,23 +27,20 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Expression> class.
-
 =over 4
 
 =cut
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -60,7 +57,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -69,10 +66,10 @@ sub as_sparql {
 	my $context	= shift;
 	my $indent	= shift;
 	my $op		= $self->op;
- 	$op			= '=' if ($op eq '==');
 	return sprintf("(%s $op %s)", map { $_->as_sparql( $context, $indent ) } $self->operands);
 }
 
+
 =item C<< evaluate ( $query, \%bound ) >>
 
 Evaluates the expression using the supplied bound variables.
@@ -99,68 +96,21 @@ sub evaluate {
 	
 	$l->debug("Binary Operator '$op': " . Dumper($lhs, $rhs));
 	
-### This does overloading of infix<+> on literal values to perform string concatenation
-# 	if ($op eq '+') {
-# 		if (blessed($lhs) and $lhs->isa('RDF::Query::Node::Literal') and blessed($rhs) and $rhs->isa('RDF::Query::Node::Literal')) {
-# 			if (not($lhs->has_datatype) and not($rhs->has_datatype)) {
-# 				my $value	= $lhs->literal_value . $rhs->literal_value;
-# 				return RDF::Query::Node::Literal->new( $value );
-# 			}
-# 		}
-# 	}
-	
 	if ($op =~ m#^[-+/*]$#) {
-		if (blessed($lhs) and blessed($rhs) and $lhs->isa('RDF::Query::Node::Literal') and $rhs->isa('RDF::Query::Node::Literal') and $lhs->is_numeric_type and $rhs->is_numeric_type) {
-			my $type	= $self->promote_type( $op, $lhs->literal_datatype, $rhs->literal_datatype );
-			my $value;
-			if ($op eq '+') {
-				my $lhsv	= $lhs->numeric_value;
-				my $rhsv	= $rhs->numeric_value;
-				if (defined($lhsv) and defined($rhsv)) {
-					$value		= $lhsv + $rhsv;
-				} else {
-					throw RDF::Query::Error::ComparisonError -text => "Cannot evaluate infix:<+> on non-numeric types";
-				}
-			} elsif ($op eq '-') {
-				my $lhsv	= $lhs->numeric_value;
-				my $rhsv	= $rhs->numeric_value;
-				if (defined($lhsv) and defined($rhsv)) {
-					$value		= $lhsv - $rhsv;
-				} else {
-					throw RDF::Query::Error::ComparisonError -text => "Cannot evaluate infix:<-> on non-numeric types";
-				}
-			} elsif ($op eq '*') {
-				my $lhsv	= $lhs->numeric_value;
-				my $rhsv	= $rhs->numeric_value;
-				if (defined($lhsv) and defined($rhsv)) {
-					$value		= $lhsv * $rhsv;
-				} else {
-					throw RDF::Query::Error::ComparisonError -text => "Cannot evaluate infix:<*> on non-numeric types";
-				}
-			} elsif ($op eq '/') {
-				my $lhsv	= $lhs->numeric_value;
-				my $rhsv	= $rhs->numeric_value;
-				
-				my ($lt, $rt)	= ($lhs->literal_datatype, $rhs->literal_datatype);
-				if ($lt eq $rt and $lt eq 'http://www.w3.org/2001/XMLSchema#integer') {
-					$type	= 'http://www.w3.org/2001/XMLSchema#decimal';
-				}
-				
-				if (defined($lhsv) and defined($rhsv)) {
-					if ($rhsv == 0) {
-						throw RDF::Query::Error::FilterEvaluationError -text => "Illegal division by zero";
-					}
-					$value		= $lhsv / $rhsv;
-				} else {
-					throw RDF::Query::Error::ComparisonError -text => "Cannot evaluate infix:</> on non-numeric types";
-				}
-			} else {
-				throw RDF::Query::Error::ExecutionError -text => "Unrecognized binary operator '$op'";
-			}
-			return RDF::Query::Node::Literal->new( $value, undef, $type, 1 );
+		my $type	= $self->promote_type( $op, $lhs, $rhs );
+		my $value;
+		if ($op eq '+') {
+			$value	= $lhs->numeric_value + $rhs->numeric_value;
+		} elsif ($op eq '-') {
+			$value	= $lhs->numeric_value - $rhs->numeric_value;
+		} elsif ($op eq '*') {
+			$value	= $lhs->numeric_value * $rhs->numeric_value;
+		} elsif ($op eq '/') {
+			$value	= $lhs->numeric_value / $rhs->numeric_value;
 		} else {
-			throw RDF::Query::Error::ExecutionError -text => "Numeric binary operator '$op' with non-numeric data";
+			die;
 		}
+		return RDF::Query::Node::Literal->new( $value, undef, $type );
 	} elsif ($op =~ m#^([<>]=?)|!?=$#) {
 		my @types	= qw(RDF::Query::Node::Literal RDF::Query::Node::Resource RDF::Query::Node::Blank);
 		
@@ -190,14 +140,14 @@ sub evaluate {
 		} elsif ($op eq '!=') {
 			$bool	= ($lhs != $rhs);
 		} else {
-			throw RDF::Query::Error::ExecutionError -text => "Unrecognized binary operator '$op'";
+			die;
 		}
 		
 		my $value	= ($bool) ? 'true' : 'false';
 		$l->debug("-> $value");
 		return RDF::Query::Node::Literal->new( $value, undef, 'http://www.w3.org/2001/XMLSchema#boolean' );
 	} else {
-		$l->logdie("Unknown operator: $op");
+		die
 	}
 }
 
@@ -222,10 +172,10 @@ my %rel	= (
 	"${xsd}double"				=> 15,
 );
 
-=item C<< promote_type ( $op, $lhs_datatype, $rhs_datatype ) >>
+=item C<< promote_type ( $op, $lhs, $rhs ) >>
 
 Returns the XSD type URI (as a string) for the resulting value of performing the
-supplied operation on arguments of the indicated XSD types.
+supplied operation on the arguments.
 
 =cut
 
@@ -233,7 +183,7 @@ sub promote_type {
 	my $self	= shift;
 	my $op		= shift;
 	no warnings 'uninitialized';
-	my @types	= sort { $rel{$b} <=> $rel{$a} } @_;
+	my @types	= sort { $rel{$b} <=> $rel{$a} } map { $_->literal_datatype } @_;
 	
 	my $type	= $types[0];
 	$type		= "${xsd}integer" if ($integer_types{ $type });
