@@ -7,7 +7,7 @@ RDF::Query::Expression::Function - Class for Function expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Expression::Function version 2.918.
+This document describes RDF::Query::Expression::Function version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -27,7 +27,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -52,15 +52,10 @@ our %FUNCTION_MAP	= (
 	in			=> "IN",
 	notin		=> "NOT IN",
 	if			=> "IF",
-	'logical-or'	=> "||",
-	'logical-and'	=> "&&",
 );
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Expression> class.
-
 =over 4
 
 =cut
@@ -105,7 +100,7 @@ sub arguments {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -114,7 +109,7 @@ sub sse {
 	my $context	= shift;
 	
 	my $uri		= $self->uri->uri_value;
-	if ($uri =~ m/^(sop|sparql):(in|notin|str(dt|lang)?|if|iri|uri|bnode|lang(matches)?|sameTerm|datatype|regex|bound|is(URI|IRI|Blank|Literal))/i) {
+	if ($uri =~ m/^(sop|sparql):(in|notin|str|strdt|strlang|if|iri|uri|bnode|lang|langmatches|sameTerm|datatype|regex|bound|is(URI|IRI|Blank|Literal))/i) {
 		my $func	= $2;
 		return sprintf(
 			'(%s %s)',
@@ -132,7 +127,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -142,7 +137,7 @@ sub as_sparql {
 	my $indent	= shift;
 	my @args	= $self->arguments;
 	my $uri		= $self->uri->uri_value;
-	my $func	= ($uri =~ m/^(sop|sparql):(logical-and|logical-or|in|notin|str(dt|lang)?|if|iri|uri|bnode|lang(matches)?|sameTerm|datatype|regex|bound|is(URI|IRI|Blank|Literal))/i)
+	my $func	= ($uri =~ m/^(sop|sparql):(in|notin|str|strdt|strlang|if|iri|uri|bnode|lang|langmatches|sameTerm|datatype|regex|bound|is(URI|IRI|Blank|Literal))/i)
 				? $FUNCTION_MAP{ lc($2) }
 				: $self->uri->as_sparql( $context, $indent );
 	if ($func eq 'IN' or $func eq 'NOT IN') {
@@ -154,12 +149,6 @@ sub as_sparql {
 			join(', ', map { $_->as_sparql( $context, $indent ) } @args),
 		);
 		return $string;
-	} elsif ($func eq '||' or $func eq '&&') {
-		my $string	= sprintf(
-			"(%s) $func (%s)",
-			(map { $_->as_sparql( $context, $indent ) } @args),
-		);
-		return $string;
 	} else {
 		my $string	= sprintf(
 			"%s(%s)",
@@ -180,7 +169,7 @@ sub type {
 	return 'FUNCTION';
 }
 
-=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
+=item C<< qualify_uris ( \%namespaces, $base ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -191,11 +180,11 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base_uri	= shift;
+	my $base	= shift;
 	my @args;
 	foreach my $arg ($self->construct_args) {
 		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@args, $arg->qualify_uris( $ns, $base_uri ));
+			push(@args, $arg->qualify_uris( $ns, $base ));
 		} elsif (blessed($arg) and $arg->isa('RDF::Query::Node::Resource')) {
 			my $uri	= $arg->uri;
 			if (ref($uri)) {
@@ -203,7 +192,7 @@ sub qualify_uris {
 				unless (exists($ns->{ $n })) {
 					throw RDF::Query::Error::QuerySyntaxError -text => "Namespace $n is not defined";
 				}
-				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base_uri );
+				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base );
 				push(@args, $resolved);
 			} else {
 				push(@args, $arg);
@@ -227,12 +216,11 @@ sub evaluate {
 	my $query	= shift || 'RDF::Query';
 	my $bound	= shift;
 	my $context	= shift;
-	my $active_graph	= shift;
 	my $uri		= $self->uri;
 	
 	no warnings 'uninitialized';
 	my $uriv	= $uri->uri_value;
-	if ($uriv =~ /^sparql:logical-(.+)$/ or $uriv =~ /^sparql:(not)?in$/ or $uriv eq 'sparql:coalesce') {
+	if ($uriv =~ /^sparql:logical-(.+)$/ or $uriv =~ /^sparql:(not)?in$/) {
 		# logical operators must have their arguments passed lazily, because
 		# some of them can still succeed even if some of their arguments throw
 		# TypeErrors (e.g. true || fail ==> true).
@@ -243,12 +231,12 @@ sub evaluate {
 						my $val	= 0;
 						try {
 							$val	= $value->isa('RDF::Query::Expression')
-								? $value->evaluate( $query, $bound, $context, $active_graph )
+								? $value->evaluate( $query, $bound )
 								: ($value->isa('RDF::Trine::Node::Variable'))
 									? $bound->{ $value->name }
 									: $value;
 						} otherwise {};
-						return $val || 0;
+						return $val;
 					};
 		my $func	= $query->get_function( $uri );
 		my $value	= $func->( $query, $args );
@@ -258,59 +246,30 @@ sub evaluate {
 		my $ebv		= RDF::Query::Node::Resource->new( "sparql:ebv" );
 		my $expr	= shift(@args);
 		my $index	= 1;
-		my $ok		= 1;
 		try {
-			my $exprval	= $query->var_or_expr_value( $bound, $expr, $context );
+			my $exprval	= $query->var_or_expr_value( $bound, $expr );
 			my $func	= RDF::Query::Expression::Function->new( $ebv, $exprval );
-			my $value	= $func->evaluate( $query, {}, $context, $active_graph );
+			my $value	= $func->evaluate( $query, {} );
 			my $bool	= ($value->literal_value eq 'true') ? 1 : 0;
 			if ($bool) {
 				$index	= 0;
 			}
-		} catch RDF::Query::Error::TypeError with {
-			$ok	= 0;
-		};
-		if ($ok) {
-			my $expr2	= $args[$index];
-			return $query->var_or_expr_value( $bound, $expr2, $context );
-		} else {
-			return;
-		}
+		} catch RDF::Query::Error::TypeError with {};
+		my $expr2	= $args[$index];
+		return $query->var_or_expr_value( $bound, $expr2 );
 	} elsif ($uriv eq 'sparql:exists') {
 		my $func	= $query->get_function($uri);
 		my ($ggp)	= $self->arguments;
-		return $func->( $query, $context, $bound, $ggp, $active_graph );
+		return $func->( $query, $context, $bound, $ggp );
 	} else {
-		my $model	= ref($query) ? $query->{model} : undef;
-		if (blessed($context)) {
-			$model	= $context->model;
-		}
-		
-		my @args;
-		if (ref($query)) {
-			# localize the model in the query object (legacy code wants the model accessible from the query object)
-			local($query->{model})	= $model;
-			@args	= map {
-							$_->isa('RDF::Query::Algebra')
-								? $_->evaluate( $query, $bound, $context, $active_graph )
-								: ($_->isa('RDF::Trine::Node::Variable'))
-									? $bound->{ $_->name }
-									: $_
-						} $self->arguments;
-		} else {
-			@args	= map {
-							$_->isa('RDF::Query::Algebra')
-								? $_->evaluate( $query, $bound, $context, $active_graph )
-								: ($_->isa('RDF::Trine::Node::Variable'))
-									? $bound->{ $_->name }
-									: $_
-						} $self->arguments;
-		}
-		
+		my @args	= map {
+						$_->isa('RDF::Query::Algebra')
+							? $_->evaluate( $query, $bound, $context )
+							: ($_->isa('RDF::Trine::Node::Variable'))
+								? $bound->{ $_->name }
+								: $_
+					} $self->arguments;
 		my $func	= $query->get_function($uri);
-		unless ($func) {
-			throw RDF::Query::Error::ExecutionError -text => "Failed to get function for IRI $uri";
-		}
 		my $value	= $func->( $query, @args );
 		return $value;
 	}
