@@ -7,7 +7,7 @@ RDF::Query::Expression::Nary - Class for n-ary expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Expression::Nary version 2.919.
+This document describes RDF::Query::Expression::Nary version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -26,23 +26,20 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Expression> class.
-
 =over 4
 
 =cut
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -59,7 +56,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
