@@ -7,7 +7,7 @@ RDF::Query::Expression::Unary - Class for unary expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Expression::Unary version 2.918.
+This document describes RDF::Query::Expression::Unary version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -26,23 +26,20 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Expression> class.
-
 =over 4
 
 =cut
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -59,7 +56,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -82,12 +79,11 @@ sub evaluate {
 	my $self	= shift;
 	my $query	= shift;
 	my $bound	= shift;
-	my $context	= shift;
 	my $op		= $self->op;
 	my ($data)	= $self->operands;
 	if ($op eq '+' or $op eq '-') {
 		my $l		= $data->isa('RDF::Query::Algebra')
-					? $data->evaluate( $query, $bound, $context, @_ )
+					? $data->evaluate( $query, $bound, @_ )
 					: ($data->isa('RDF::Query::Node::Variable'))
 						? $bound->{ $data->name }
 						: $data;
@@ -101,7 +97,7 @@ sub evaluate {
 		return RDF::Query::Node::Literal->new( $value, undef, $l->literal_datatype );
 	} elsif ($op eq '!') {
 		my $alg		= RDF::Query::Expression::Function->new( "sparql:ebv", $data );
-		my $bool	= $alg->evaluate( $query, $bound, $context, @_ );
+		my $bool	= $alg->evaluate( $query, $bound, @_ );
 		if ($bool->literal_value eq 'true') {
 			return RDF::Query::Node::Literal->new( 'false', undef, 'http://www.w3.org/2001/XMLSchema#boolean' );
 		} else {
@@ -109,7 +105,7 @@ sub evaluate {
 		}
 	} else {
 		warn "unknown unary op: $op";
-		throw RDF::Query::Error::ExecutionError -text => "Unknown unary op '$op'";
+		die;
 	}
 }
 
