@@ -7,13 +7,7 @@ RDF::Query::Federate::Plan - Executable query plan nodes.
 
 =head1 VERSION
 
-This document describes RDF::Query::Federate::Plan version 2.919.
-
-=head1 STATUS
-
-This module's API and functionality should be considered deprecated.
-If you need functionality that this module provides,
-please L<get in touch|http://www.perlrdf.org/>.
+This document describes RDF::Query::Federate::Plan version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
@@ -37,7 +31,7 @@ use RDF::Query::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -277,7 +271,7 @@ __END__
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2009 Gregory Todd Williams. This
+Copyright (c) 2005-2009 Gregory Todd Williams. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
