@@ -7,7 +7,7 @@ RDF::Query::Node - Base class for RDF Nodes
 
 =head1 VERSION
 
-This document describes RDF::Query::Node version 2.919.
+This document describes RDF::Query::Node version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
@@ -27,14 +27,13 @@ use RDF::Query::Node::Literal;
 use RDF::Query::Node::Resource;
 use RDF::Query::Node::Variable;
 
-our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS);
+our ($VERSION, @ISA, @EXPORT_OK);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
 	@EXPORT_OK	= qw(iri blank literal variable);
-	%EXPORT_TAGS	= ( 'all' => [qw(iri blank literal variable)] );
 }
 
 =item C<< is_variable >>
@@ -90,53 +89,13 @@ sub from_trine {
 	} elsif ($n->isa('RDF::Trine::Node::Blank')) {
 		return RDF::Query::Node::Blank->new( $n->blank_identifier );
 	} elsif ($n->isa('RDF::Trine::Node::Nil')) {
-		return $n;
+		return;
 	} else {
 		use Data::Dumper;
 		Carp::confess "from_trine called with unrecognized node type:" . Dumper($n);
 	}
 }
 
-=item C<< from_attean ( $node ) >>
-
-Likewise, but from L<Attean>.
-
-=cut
-
-sub from_attean {
-	my $class	= shift;
-	my $n		= shift;
-	if ($n->does('Attean::API::Variable')) {
-		return RDF::Query::Node::Variable->new( $n->value );
-	} elsif ($n->does('Attean::API::Literal')) {
-		return RDF::Query::Node::Literal->new( $n->value, $n->language, $n->datatype );
-	} elsif ($n->does('Attean::API::IRI')) {
-		return RDF::Query::Node::Resource->new( $n->as_string );
-	} elsif ($n->does('Attean::API::Blank')) {
-		return RDF::Query::Node::Blank->new( $n->value );
-	} else {
-		use Data::Dumper;
-		Carp::confess "from_attean called with unrecognized node type:" . Dumper($n);
-	}
-}
-
-=item C<< explain >>
-
-Returns a string serialization of the node appropriate for display on the
-command line. This method is primarily used by the C<< explain >> method of
-the subclasses of RDF::Query::Plan.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $string	= "${indent}" . $self->as_sparql . "\n";
-	return $string;
-}
-
 =back
 
 =head1 FUNCTIONS
