@@ -7,13 +7,10 @@ RDF::Query::Node::Blank - RDF Node class for blank nodes
 
 =head1 VERSION
 
-This document describes RDF::Query::Node::Blank version 2.919.
+This document describes RDF::Query::Node::Blank version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Node> and L<RDF::Trine::Node::Blank> classes.
-
 =over 4
 
 =cut
@@ -33,7 +30,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -54,7 +51,6 @@ sub _cmp {
 	my $l		= Log::Log4perl->get_logger("rdf.query.node.blank");
 	$l->debug("blank comparison: " . Dumper($nodea, $nodeb));
 	return 1 unless blessed($nodeb);
-	return -1 if ($nodeb->isa('RDF::Trine::Node::Nil'));
 	return -1 if ($nodeb->isa('RDF::Query::Node::Literal'));
 	return -1 if ($nodeb->isa('RDF::Query::Node::Resource'));
 	return 1 unless ($nodeb->isa('RDF::Query::Node::Blank'));
