@@ -7,7 +7,7 @@ RDF::Query::Node::Literal - RDF Node class for literals
 
 =head1 VERSION
 
-This document describes RDF::Query::Node::Literal version 2.919.
+This document describes RDF::Query::Node::Literal version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -19,7 +19,7 @@ no warnings 'redefine';
 use base qw(RDF::Query::Node RDF::Trine::Node::Literal);
 
 use DateTime;
-use DateTime::Format::W3CDTF;
+use RDF::Query;
 use RDF::Query::Error;
 use Data::Dumper;
 use Log::Log4perl;
@@ -30,7 +30,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION, $LAZY_COMPARISONS);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -49,9 +49,6 @@ my %INSIDE_OUT_DATES;
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Node> and L<RDF::Trine::Node::Literal> classes.
-
 =over 4
 
 =cut
@@ -59,13 +56,12 @@ L<RDF::Query::Node> and L<RDF::Trine::Node::Literal> classes.
 sub _cmp {
 	my $nodea	= shift;
 	my $nodeb	= shift;
-	my $op		= shift;
+	my $op	= shift;
 	
 	my $l		= Log::Log4perl->get_logger("rdf.query.node.literal");
 	$l->debug('literal comparison: ' . Dumper($nodea, $nodeb));
 	
 	return 1 unless blessed($nodeb);
-	return -1 if ($nodeb->isa('RDF::Trine::Node::Nil'));
 	return 1 if ($nodeb->isa('RDF::Query::Node::Blank'));
 	return 1 if ($nodeb->isa('RDF::Query::Node::Resource'));
 	return 1 unless ($nodeb->isa('RDF::Query::Node::Literal'));
@@ -75,24 +71,17 @@ sub _cmp {
 	my $datetype	= '^http://www.w3.org/2001/XMLSchema#dateTime';
 	my $datecmp		= ($dta =~ $datetype and $dtb =~ $datetype);
 	my $numericcmp	= ($nodea->is_numeric_type and $nodeb->is_numeric_type);
-	
+
 	if ($datecmp) {
 		$l->trace('datecmp');
 		my $datea	= $nodea->datetime;
 		my $dateb	= $nodeb->datetime;
-		if ($datea and $dateb) {
-			my $cmp		= eval { DateTime->compare_ignore_floating( $datea, $dateb ) };
-			return $cmp unless ($@);
-		}
-	}
-	
-	if ($numericcmp) {
+		return DateTime->compare( $datea, $dateb );
+	} elsif ($numericcmp) {
 		$l->trace('both numeric cmp');
 		return 0 if ($nodea->equal( $nodeb ));	# if the nodes are identical, return true (even if the lexical values don't appear to be numeric). i.e., "xyz"^^xsd:integer should equal itself, even though it's not a valid integer.
 		return $nodea->numeric_value <=> $nodeb->numeric_value;
-	}
-	
-	{
+	} else {
 		$l->trace('other cmp');
 		
 		if ($nodea->has_language and $nodeb->has_language) {
@@ -126,8 +115,6 @@ sub _cmp {
 				$c	= -1;
 			} elsif (not($nb->has_datatype) or $nb->literal_datatype eq 'http://www.w3.org/2001/XMLSchema#string') {
 				$c	= $nodea->literal_value cmp $nodeb->literal_value;
-			} elsif ($LAZY_COMPARISONS) {
-				return $nodea->as_string cmp $nodeb->as_string;
 			} else {
 				throw RDF::Query::Error::TypeError -text => "Attempt to compare typed-literal with xsd:string.";
 			}
@@ -155,13 +142,19 @@ sub _cmp {
 			}
 		} elsif ($nodea->has_language or $nodeb->has_language) {
 			$l->trace("one has language");
-			my $c	= ($nodea->has_language) ? 1 : -1;
-			$l->trace("-> $c");
-			return $c;
+			if ($LAZY_COMPARISONS) {
+				my $c	= refaddr($nodea) <=> refaddr($nodeb);	# not equal, but will make the sort stable
+				$l->trace("-> $c");
+				return $c;
+			} else {
+				my $c	= refaddr($nodea) <=> refaddr($nodeb);	# not equal, but stable sorting
+				$l->trace("-> $c");
+				return $c;
+			}
 		} elsif ($nodea->has_datatype or $nodeb->has_datatype) {
 			$l->trace("one has datatype");
 			if ($LAZY_COMPARISONS) {
-				my $c	= ($nodea->has_datatype) ? 1 : -1;
+				my $c	= refaddr($nodea) <=> refaddr($nodeb);	# not equal, but will make the sort stable
 				$l->trace("-> $c");
 				return $c;
 			} else {
@@ -230,17 +223,6 @@ sub as_hash {
 	return $hash;
 }
 
-=item C<< is_simple_literal >>
-
-Returns true if the literal is "simple" -- is a literal without datatype or language.
-
-=cut
-
-sub is_simple_literal {
-	my $self	= shift;
-	return not($self->has_language or $self->has_datatype);
-}
-
 =item C<< is_numeric_type >>
 
 Returns true if the literal is a known (xsd) numeric type.
@@ -269,8 +251,7 @@ sub numeric_value {
 	if ($self->is_numeric_type) {
 		my $value	= $self->literal_value;
 		if (looks_like_number($value)) {
-			my $v	= 0 + eval "$value";
-			return $v;
+			return 0 + $value;
 		} else {
 			throw RDF::Query::Error::TypeError -text => "Literal with numeric type does not appear to have numeric value.";
 		}
@@ -287,19 +268,6 @@ sub numeric_value {
 	}
 }
 
-=item C<< type_list >>
-
-Returns a two-item list suitable for use as the second and third arguments to
-RDF::Query::Node::Literal constructor. The two returned values correspond to
-literal language tag and literal datatype URI, respectively.
-
-=cut
-
-sub type_list {
-	my $self	= shift;
-	return ($self->literal_value_language, $self->literal_datatype);
-}
-
 sub DESTROY {
 	my $self	= shift;
 	my $addr	= refaddr($self);
