@@ -7,7 +7,7 @@ RDF::Query::Node::Resource - RDF Node class for resources
 
 =head1 VERSION
 
-This document describes RDF::Query::Node::Resource version 2.917.
+This document describes RDF::Query::Node::Resource version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -19,9 +19,7 @@ no warnings 'redefine';
 use base qw(RDF::Query::Node RDF::Trine::Node::Resource);
 
 use URI;
-use Encode;
 use Data::Dumper;
-use RDF::Query::Parser::SPARQL;
 use Scalar::Util qw(blessed reftype);
 use Carp qw(carp croak confess);
 
@@ -29,7 +27,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -37,9 +35,6 @@ BEGIN {
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Node> and L<RDF::Trine::Node::Resource> classes.
-
 =over 4
 
 =cut
@@ -59,7 +54,6 @@ sub _cmp {
 	my $b	= shift;
 	return 1 unless blessed($b);
 	return -1 if ($b->isa('RDF::Query::Node::Literal'));
-	return -1 if ($b->isa('RDF::Trine::Node::Nil'));
 	return 1 if ($b->isa('RDF::Query::Node::Blank'));
 	return 0 unless ($b->isa('RDF::Query::Node::Resource'));
 	my $cmp	= $a->uri_value cmp $b->uri_value;
@@ -74,32 +68,10 @@ Returns the SPARQL string for this node.
 
 sub as_sparql {
 	my $self	= shift;
-	my $PNLOCAL	= $RDF::Query::Parser::SPARQL::r_PN_LOCAL;
 	my $context	= shift || {};
-	if ($context) {
-		my $uri		= $self->uri_value;
-		my $ns		= $context->{namespaces} || {};
-		my %ns		= %$ns;
-		foreach my $k (keys %ns) {
-			no warnings 'uninitialized';
-			if ($k eq '__DEFAULT__') {
-				$k	= '';
-			}
-			my $v	= $ns{ $k };
-			if (index($uri, $v) == 0) {
-				my $local	= substr($uri, length($v));
-				
-				if ($local =~ /^(?:$PNLOCAL)$/) {
-					my $qname	= join(':', $k, $local);
-					return $qname;
-				}
-			}
-		}
-	}
-	
-	my $string	= URI->new( encode_utf8($self->uri_value) )->canonical;
-	my $sparql		= '<' . $string . '>';
-	return $sparql;
+	my $ns		= $context->{ namespaces } || {};
+	my %ns		= %$ns;
+	return $self->sse( { namespaces => \%ns } );
 }
 
 =item C<< as_hash >>
