@@ -7,7 +7,7 @@ RDF::Query::Node::Variable - RDF Node class for variables
 
 =head1 VERSION
 
-This document describes RDF::Query::Node::Variable version 2.919.
+This document describes RDF::Query::Node::Variable version 3.000_01, released 30 January 2010.
 
 =cut
 
@@ -26,24 +26,17 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-=head1 METHODS
-
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Node> and L<RDF::Trine::Node::Variable> classes.
-
 =over 4
 
 =cut
 
-use overload	'""'	=> sub { $_[0]->sse };
-
 =item C<< new ( $name ) >>
 
 Returns a new variable object.
@@ -91,7 +84,6 @@ package RDF::Query::Node::Variable::ExpressionProxy;
 use strict;
 use warnings;
 use base qw(RDF::Query::Node::Variable);
-use Scalar::Util qw(blessed refaddr);
 
 =begin private
 
@@ -99,15 +91,10 @@ use Scalar::Util qw(blessed refaddr);
 
 =cut
 
-{my %vars;
 sub new {
 	my $class	= shift;
 	my $name	= shift;
-	my @vars	= @_;
 	my $self	= $class->SUPER::new( $name );
-	if (@vars) {
-		$vars{ refaddr($self) }	= [map {blessed($_) ? $_ : RDF::Query::Node::Variable->new($_)} @vars];
-	}
 	return $self;
 }
 
@@ -120,26 +107,6 @@ sub as_sparql {
 	return $self->name;
 }
 
-=item C<< referenced_variables >>
-
-=cut
-
-sub referenced_variables {
-	my $self	= shift;
-	my @vars	= map { blessed($_) ? $_->name : $_ } @{ $vars{ refaddr($self) } || [] };
-	return RDF::Query::_uniq(@vars);
-}
-
-sub nonaggregated_referenced_variables {
-	return;
-}
-
-sub DESTROY {
-	my $self	= shift;
-	delete $vars{ refaddr($self) };
-}
-}
-
 =end private
 
 =cut
