@@ -7,12 +7,12 @@ RDF::Query::Parser::SPARQL - SPARQL Parser.
 
 =head1 VERSION
 
-This document describes RDF::Query::Parser::SPARQL version 2.918.
+This document describes RDF::Query::Parser::SPARQL version 3.000_01, released 30 January 2010.
 
 =head1 SYNOPSIS
 
  use RDF::Query::Parser::SPARQL;
- my $parser	= RDF::Query::Parser::SPARQL->new();
+ my $parser	= RDF::Query::Parse::SPARQL->new();
  my $iterator = $parser->parse( $query, $base_uri );
 
 =head1 DESCRIPTION
@@ -21,9 +21,6 @@ This document describes RDF::Query::Parser::SPARQL version 2.918.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Parser> class.
-
 =over 4
 
 =cut
@@ -47,7 +44,7 @@ use Scalar::Util qw(blessed looks_like_number);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -55,30 +52,30 @@ BEGIN {
 my $rdf			= RDF::Trine::Namespace->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#');
 my $xsd			= RDF::Trine::Namespace->new('http://www.w3.org/2001/XMLSchema#');
 
-our $r_ECHAR				= qr/\\([tbnrf\\"'])/o;
-our $r_STRING_LITERAL1		= qr/'(([^\x{27}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*'/o;
-our $r_STRING_LITERAL2		= qr/"(([^\x{22}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*"/o;
-our $r_STRING_LITERAL_LONG1	= qr/'''(('|'')?([^'\\]|${r_ECHAR}))*'''/o;
-our $r_STRING_LITERAL_LONG2	= qr/"""(("|"")?([^"\\]|${r_ECHAR}))*"""/o;
-our $r_LANGTAG				= qr/@[a-zA-Z]+(-[a-zA-Z0-9]+)*/o;
-our $r_IRI_REF				= qr/<([^<>"{}|^`\\\x{00}-\x{20}])*>/o;
-our $r_PN_CHARS_BASE		= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/o;
-our $r_PN_CHARS_U			= qr/(_|${r_PN_CHARS_BASE})/o;
-our $r_VARNAME				= qr/((${r_PN_CHARS_U}|[0-9])(${r_PN_CHARS_U}|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}])*)/o;
-our $r_VAR1					= qr/[?]${r_VARNAME}/o;
-our $r_VAR2					= qr/[\$]${r_VARNAME}/o;
-our $r_PN_CHARS				= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/o;
-our $r_PN_PREFIX			= qr/(${r_PN_CHARS_BASE}((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
-our $r_PN_LOCAL				= qr/((${r_PN_CHARS_U}|[0-9])((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
-our $r_PNAME_NS				= qr/((${r_PN_PREFIX})?:)/o;
-our $r_PNAME_LN				= qr/(${r_PNAME_NS}${r_PN_LOCAL})/o;
-our $r_EXPONENT				= qr/[eE][-+]?\d+/o;
-our $r_DOUBLE				= qr/\d+[.]\d*${r_EXPONENT}|[.]\d+${r_EXPONENT}|\d+${r_EXPONENT}/o;
-our $r_DECIMAL				= qr/(\d+[.]\d*)|([.]\d+)/o;
-our $r_INTEGER				= qr/\d+/o;
-our $r_BLANK_NODE_LABEL		= qr/_:${r_PN_LOCAL}/o;
-our $r_ANON					= qr/\[[\t\r\n ]*\]/o;
-our $r_NIL					= qr/\([\n\r\t ]*\)/o;
+our $r_ECHAR				= qr/\\([tbnrf\\"'])/;
+our $r_STRING_LITERAL1		= qr/'(([^\x{27}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*'/;
+our $r_STRING_LITERAL2		= qr/"(([^\x{22}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*"/;
+our $r_STRING_LITERAL_LONG1	= qr/'''(('|'')?([^'\\]|${r_ECHAR}))*'''/;
+our $r_STRING_LITERAL_LONG2	= qr/"""(("|"")?([^"\\]|${r_ECHAR}))*"""/;
+our $r_LANGTAG				= qr/@[a-zA-Z]+(-[a-zA-Z0-9]+)*/;
+our $r_IRI_REF				= qr/<([^<>"{}|^`\\\x{00}-\x{20}])*>/;
+our $r_PN_CHARS_BASE		= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/;
+our $r_PN_CHARS_U			= qr/(_|${r_PN_CHARS_BASE})/;
+our $r_VARNAME				= qr/((${r_PN_CHARS_U}|[0-9])(${r_PN_CHARS_U}|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}])*)/;
+our $r_VAR1					= qr/[?]${r_VARNAME}/;
+our $r_VAR2					= qr/[\$]${r_VARNAME}/;
+our $r_PN_CHARS				= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/;
+our $r_PN_PREFIX			= qr/(${r_PN_CHARS_BASE}((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/;
+our $r_PN_LOCAL				= qr/((${r_PN_CHARS_U}|[0-9])((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/;
+our $r_PNAME_NS				= qr/((${r_PN_PREFIX})?:)/;
+our $r_PNAME_LN				= qr/(${r_PNAME_NS}${r_PN_LOCAL})/;
+our $r_EXPONENT				= qr/[eE][-+]?\d+/;
+our $r_DOUBLE				= qr/\d+[.]\d*${r_EXPONENT}|[.]\d+${r_EXPONENT}|\d+${r_EXPONENT}/;
+our $r_DECIMAL				= qr/(\d+[.]\d*)|([.]\d+)/;
+our $r_INTEGER				= qr/\d+/;
+our $r_BLANK_NODE_LABEL		= qr/_:${r_PN_LOCAL}/;
+our $r_ANON					= qr/\[[\t\r\n ]*\]/;
+our $r_NIL					= qr/\([\n\r\t ]*\)/;
 
 =item C<< new >>
 
@@ -290,8 +287,8 @@ sub _eat {
 # 	}
 	
 	if (blessed($thing) and $thing->isa('Regexp')) {
-		if ($self->{tokens} =~ /^($thing)/) {
-			my $match	= $1;
+		if ($self->{tokens} =~ /^$thing/) {
+			my $match	= $&;
 			substr($self->{tokens}, 0, length($match))	= '';
 			return $match;
 		}
@@ -436,7 +433,7 @@ sub _Query {
 	
 	my $remaining	= $self->{tokens};
 	if ($remaining =~ m/\S/) {
-		throw RDF::Query::Error::ParseError -text => "Syntax error: Remaining input after query: $remaining";
+		throw RDF::Query::Error::ParseError -text => "Remaining input after query: $remaining";
 	}
 	
 # 	my %query	= (%p, %body);
@@ -574,7 +571,6 @@ sub _ConstructQuery {
 	$self->_DatasetClause();
 	$self->__consume_ws_opt;
 	$self->_WhereClause;
-	$self->__consume_ws_opt;
 	$self->_SolutionModifier();
 	
 	my $pattern		= $self->{build}{triples}[0];
@@ -609,7 +605,6 @@ sub _DescribeQuery {
 	$self->__consume_ws_opt;
 	if ($self->_WhereClause_test) {
 		$self->_WhereClause;
-		$self->__consume_ws_opt;
 	}
 	
 	$self->_SolutionModifier();
@@ -1707,7 +1702,7 @@ sub _RDFLiteral {
 	if ($self->_test('@')) {
 		my $lang	= $self->_eat( $r_LANGTAG );
 		substr($lang,0,1)	= '';	# remove '@'
-		push(@args, lc($lang));
+		push(@args, $lang);
 	} elsif ($self->_test('^^')) {
 		$self->_eat('^^');
 		push(@args, undef);
