@@ -7,7 +7,7 @@ RDF::Query::Plan - Executable query plan nodes.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan version 2.918.
+This document describes RDF::Query::Plan version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
@@ -21,7 +21,7 @@ use strict;
 use warnings;
 use Data::Dumper;
 use List::Util qw(reduce);
-use Scalar::Util qw(blessed reftype refaddr);
+use Scalar::Util qw(blessed reftype);
 use RDF::Query::Error qw(:try);
 use RDF::Query::BGPOptimizer;
 
@@ -34,12 +34,15 @@ use RDF::Query::Plan::Filter;
 use RDF::Query::Plan::Join::NestedLoop;
 use RDF::Query::Plan::Join::PushDownNestedLoop;
 use RDF::Query::Plan::Limit;
+use RDF::Query::Plan::Not;
+use RDF::Query::Plan::Exists;
 use RDF::Query::Plan::Offset;
 use RDF::Query::Plan::Project;
 use RDF::Query::Plan::Extend;
 use RDF::Query::Plan::Quad;
 use RDF::Query::Plan::Service;
 use RDF::Query::Plan::Sort;
+use RDF::Query::Plan::Triple;
 use RDF::Query::Plan::ComputedStatement;
 use RDF::Query::Plan::ThresholdUnion;
 use RDF::Query::Plan::Union;
@@ -51,9 +54,6 @@ use RDF::Query::Plan::Update;
 use RDF::Query::Plan::Minus;
 use RDF::Query::Plan::Sequence;
 use RDF::Query::Plan::Path;
-use RDF::Query::Plan::NamedGraph;
-use RDF::Query::Plan::Copy;
-use RDF::Query::Plan::Move;
 
 use RDF::Trine::Statement;
 use RDF::Trine::Statement::Quad;
@@ -64,12 +64,9 @@ use constant CLOSED		=> 0x04;
 
 ######################################################################
 
-our ($VERSION, %PLAN_CLASSES);
+our ($VERSION);
 BEGIN {
-	$VERSION		= '2.918';
-	%PLAN_CLASSES	= (
-		service	=> 'RDF::Query::Plan::Service',
-	);
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -147,52 +144,14 @@ sub logging_keys {
 	return $self->[0]{logging_keys} || {};
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the query plan appropriate for display
-on the command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-# 	warn 'Explaining query plan: ' . $self->serialize();
-	my ($s, $count)	= ('  ', 0);
-	if (@_) {
-		$s		= shift;
-		$count	= shift;
-	}
-	my $indent	= '' . ($s x $count);
-	my $type	= $self->plan_node_name;
-	my $string	= sprintf("%s%s (0x%x)\n", $indent, $type, refaddr($self));
-	foreach my $p ($self->plan_node_data) {
-		if (blessed($p)) {
-			if ($p->isa('RDF::Trine::Statement::Quad')) {
-				$string	.= "${indent}${s}" . join(' ', map { ($_->isa('RDF::Trine::Node::Nil')) ? "(nil)" : $_->as_sparql } $p->nodes) . "\n";
-			} elsif ($p->isa('RDF::Trine::Node::Nil')) {
-				$string	.= "${indent}${s}(nil)\n";
-			} else {
-				$string	.= $p->explain( $s, $count+1 );
-			}
-		} elsif (ref($p)) {
-			$string	.= "${indent}${s}" . Dumper($p);
-			Carp::cluck 'unexpected non-blessed ref in RDF::Query::Plan->explain: ' . Dumper($p);
-		} else {
-			no warnings 'uninitialized';
-			$string	.= "${indent}${s}$p\n";
-		}
-	}
-	return $string;
-}
-
 =item C<< sse >>
 
 =cut
 
 sub sse {
 	my $self	= shift;
-	my $context	= shift || {};
-	my $indent	= shift || '';
+	my $context	= shift;
+	my $indent	= shift;
 	my $more	= '    ';
 	my @proto	= $self->plan_prototype;
 	my @data	= $self->plan_node_data;
@@ -204,7 +163,7 @@ sub sse {
 		my $p	= $proto[ $i ];
 		push(@args, $self->_sse( $context, $indent, $more, $p, $list ));
 	}
-	return "(${name} " . join(' ', map { defined($_) ? $_ : '()' } @args) . ")";
+	return "(${name} " . join(' ', @args) . ")";
 }
 
 sub _sse {
@@ -214,7 +173,7 @@ sub _sse {
 	my $more	= shift;
 	my $p		= shift;
 	my $list	= shift;
-	if ($p =~ m/^[PQTNWEJVqibswu]$/) {
+	if ($p =~ m/^[PTNWEJVibswu]$/) {
 		my $v	= shift(@$list);
 		return $self->_sse_atom($context, $indent, $more, $p, $v);
 	} elsif ($p eq 'A') {
@@ -240,7 +199,7 @@ sub _sse {
 		}
 		no warnings 'uninitialized';
 		return join("\n${indent}${more}", '', @args);
-	} elsif ($p =~ m/^[PQTNWEJVqibswu\\*]{2,}$/) {
+	} elsif ($p =~ m/^[PTNWEJVibswu\\*]{2,}$/) {
 		my @args;
 		foreach my $p2 (split(//, $p)) {
 			my $v	= shift(@$list);
@@ -248,7 +207,7 @@ sub _sse {
 		}
 		return '(' . join(' ', @args) . ')';
 	} else {
-		Carp::confess "unrecognized plan node prototype '$p'";
+		die "unrecognized plan node prototype '$p'";
 	}
 }
 
@@ -288,8 +247,6 @@ sub _sse_atom {
 		}
 	} elsif ($p =~ m/^[PNETV]$/) {
 		if (blessed($v)) {
-		
-			Carp::cluck unless ($v->can('sse'));
 			return $v->sse( { namespaces => \%ns }, "${indent}${more}" );
 		} else {
 			return '()';
@@ -314,17 +271,6 @@ sub serialize {
 	
 }
 
-=item C<< delegate >>
-
-Returns the delegate object if available.
-
-=cut
-
-sub delegate {
-	my $self	= shift;
-	return $self->[0]{delegate};
-}
-
 =item C<< referenced_variables >>
 
 Returns a list of variable names that are referenced by this plan.
@@ -417,11 +363,7 @@ sub generate_plans {
 	my $class	= ref($self) || $self;
 	my $algebra	= shift;
 	my $context	= shift;
-	my $config	= $context->options || {};
-	
 	my %args	= @_;
-	my $active_graph	= $args{ active_graph } || RDF::Trine::Node::Nil->new();
-	
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan");
 	unless (blessed($algebra) and $algebra->isa('RDF::Query::Algebra')) {
 		throw RDF::Query::Error::MethodInvocationError (-text => "Cannot generate an execution plan with a non-algebra object $algebra");
@@ -445,7 +387,7 @@ sub generate_plans {
 							my $bgp	= $bgp[0];
 							my @triples	= $bgp->triples;
 							if (scalar(@triples) == 1) {
-								$l->debug("Optimizing for COUNT(*) on 1-triple BGP: " . $bgp->sse({ indent => '  ' }, ''));
+								$l->debug("TODO: Potential optimization for COUNT(*) on 1-triple BGP: " . $bgp->sse({ indent => '  ' }, ''));
 								my $vars	= $algebra->vars;
 								my $alias	= $vars->[0];
 								my $name	= $alias->name;
@@ -454,12 +396,9 @@ sub generate_plans {
 								my $code	= sub {
 									return if ($done);
 									$done	= 1;
-									#warn Dumper(\@triples); # XXX
 									my $count	= $model->count_statements( $triples[0]->nodes );
-									my $lit		= RDF::Query::Node::Literal->new($count, undef, 'http://www.w3.org/2001/XMLSchema#integer');
 									my $vb	= RDF::Query::VariableBindings->new( {
-										$name 		=> $lit,
-										'COUNT(*)'	=> $lit,	# this has to be kept around in case a HAVING clause needs it without the alias $name
+										$name => RDF::Query::Node::Literal->new($count, undef, 'http://www.w3.org/2001/XMLSchema#integer')
 									} );
 								};
 								my $iter	= RDF::Trine::Iterator::Bindings->new( $code, [] );
@@ -474,7 +413,7 @@ sub generate_plans {
 	############################################################################
 	
 	my ($project);
-	my $constant	= delete $args{ constants };
+	my $constant	= $args{ constants };
 	
 	if ($algebra->isa('RDF::Query::Algebra::Sort') or not($algebra->is_solution_modifier)) {
 		# projection has to happen *after* sorting, since a sort expr might reference a variable that we project away
@@ -503,38 +442,56 @@ sub generate_plans {
 		my @base	= $self->generate_plans( $algebra->pattern, $context, %args );
 		my @plans	= map { RDF::Query::Plan::Distinct->new( $_ ) } @base;
 		push(@return_plans, @plans);
+	} elsif ($type eq 'Not') {
+		my @patt	= $self->generate_plans( $algebra->pattern, $context, %args );
+		my @npatt	= $self->generate_plans( $algebra->not_pattern, $context, %args );
+		foreach my $p (@patt) {
+			foreach my $n (@npatt) {
+				push(@return_plans, RDF::Query::Plan::Not->new( $p, $n ));
+			}
+		}
+	} elsif ($type eq 'Exists') {
+		my @patt	= $self->generate_plans( $algebra->pattern, $context, %args );
+		my @npatt	= $self->generate_plans( $algebra->exists_pattern, $context, %args );
+		foreach my $p (@patt) {
+			foreach my $n (@npatt) {
+				push(@return_plans, RDF::Query::Plan::Exists->new( $p, $n, $algebra->not_flag ));
+			}
+		}
 	} elsif ($type eq 'Filter') {
-		my @base	= $self->generate_plans( $algebra->pattern, $context, %args, active_graph => $active_graph );
+		my @base	= $self->generate_plans( $algebra->pattern, $context, %args );
 		my $expr	= $algebra->expr;
-		my @plans	= map { RDF::Query::Plan::Filter->new( $expr, $_, $active_graph ) } @base;
+		my @plans	= map { RDF::Query::Plan::Filter->new( $expr, $_ ) } @base;
 		push(@return_plans, @plans);
 	} elsif ($type eq 'BasicGraphPattern') {
-		my @triples	= map {
-			($args{ prevent_distinguishing_bnodes })
-				? $_
-				: $_->distinguish_bnode_variables
-		} $algebra->triples;
+		my @triples	= map { $_->distinguish_bnode_variables } $algebra->triples;
 		my @normal_triples;
 		my @csg_triples;
 		foreach my $t (@triples) {
 			if (my @csg_plans = $self->_csg_plans( $context, $t )) {
 				push(@csg_triples, $t);
 			} else {
-				my @nodes	= $t->nodes;
-				$t	= RDF::Query::Algebra::Quad->new( @nodes[ 0..2 ], $active_graph );
-# 				if (my $g = $args{ named_graph }) {
-# 					my @nodes	= $t->nodes;
-# 					$t	= RDF::Query::Algebra::Quad->new( @nodes[0..2], $g );
-# 				}
 				push(@normal_triples, $t);
 			}
 		}
 		
 		my @plans;
 		if (scalar(@normal_triples) == 0) {
-			my $v		= RDF::Query::VariableBindings->new( {} );
-			my $plan	= RDF::Query::Plan::Constant->new( $v );
-			push(@plans, $plan);
+			if ($args{ named_graph }) {
+				my @nodes	= map { RDF::Query::Node::Variable->new($_) } qw(s p o);
+				push(@nodes, $args{ named_graph });
+				my $plan	= RDF::Query::Plan::Distinct->new( 
+								RDF::Query::Plan::Project->new(
+									RDF::Query::Plan::Quad->new( @nodes, { sparql => '{}' } ),
+									[ $args{ named_graph } ]
+								)
+							);
+				push(@plans, $plan);
+			} else {
+				my $v		= RDF::Query::VariableBindings->new( {} );
+				my $plan	= RDF::Query::Plan::Constant->new( $v );
+				push(@plans, $plan);
+			}
 		} elsif (scalar(@normal_triples) == 1) {
 			push(@plans, $self->generate_plans( @normal_triples, $context, %args ));
 		} else {
@@ -547,7 +504,7 @@ sub generate_plans {
 			foreach my $t (@csg_triples) {
 				push(@csg_plans, [ $self->generate_plans( $t, $context, %args ) ]);
 			}
-			my @join_types	= RDF::Query::Plan::Join->join_classes( $config );
+			my @join_types	= RDF::Query::Plan::Join->join_classes;
 			while (my $cps = shift(@csg_plans)) {
 				my @temp_plans	= @plans;
 				@plans			= ();
@@ -566,28 +523,25 @@ sub generate_plans {
 		}
 		
 	} elsif ($type eq 'GroupGraphPattern') {
-		my @input	= $algebra->patterns();
-		my @patterns;
-		while (my $a = shift(@input)) {
-			if ($a->isa('RDF::Query::Algebra::Service')) {
-				if (scalar(@input) and $input[0]->isa('RDF::Query::Algebra::Service') and $a->endpoint->value eq $input[0]->endpoint->value) {
-					my $b	= shift(@input);
-					if ($a->silent == $b->silent) {
-						my $p	= RDF::Query::Algebra::GroupGraphPattern->new( map { $_->pattern } ($a, $b) );
-						my $s	= RDF::Query::Algebra::Service->new( $a->endpoint, $p, $a->silent );
-						push(@patterns, $s);
-						next;
-					}
-				}
-			}
-			push(@patterns, $a);
-		}
+		my @patterns	= $algebra->patterns();
 		
 		my @plans;
 		if (scalar(@patterns) == 0) {
-			my $v		= RDF::Query::VariableBindings->new( {} );
-			my $plan	= RDF::Query::Plan::Constant->new( $v );
-			push(@plans, $plan);
+			if ($args{ named_graph }) {
+				my @nodes	= map { RDF::Query::Node::Variable->new($_) } qw(s p o);
+				push(@nodes, $args{ named_graph });
+				my $plan	= RDF::Query::Plan::Distinct->new( 
+								RDF::Query::Plan::Project->new(
+									RDF::Query::Plan::Quad->new( @nodes, { sparql => '{}' } ),
+									[ $args{ named_graph } ]
+								)
+							);
+				push(@plans, $plan);
+			} else {
+				my $v		= RDF::Query::VariableBindings->new( {} );
+				my $plan	= RDF::Query::Plan::Constant->new( $v );
+				push(@plans, $plan);
+			}
 		} elsif (scalar(@patterns) == 1) {
 			push(@plans, $self->generate_plans( @patterns, $context, %args ));
 		} else {
@@ -600,12 +554,11 @@ sub generate_plans {
 		my @plans	= map { RDF::Query::Plan::Limit->new( $algebra->limit, $_ ) } @base;
 		push(@return_plans, @plans);
 	} elsif ($type eq 'NamedGraph') {
-		my @plans;
-		if ($algebra->graph->isa('RDF::Query::Node::Resource')) {
-			@plans	= $self->generate_plans( $algebra->pattern, $context, %args, active_graph => $algebra->graph );
-		} else {
-			@plans	= map { RDF::Query::Plan::NamedGraph->new( $algebra->graph, $_ ) } $self->generate_plans( $algebra->pattern, $context, %args, active_graph => $algebra->graph );
-		}
+		# we push 'named_graph' down as part of %arg here so that empty BGPs ({}) can be \
+		# handled specially in named graphs -- namely, {} should be executed as an empty BGP \
+		# when in a GraphGraphPattern so GRAPH ?g {} ends up returning all the valid graph names, \
+		# instead of being optimized away into an empty variable binding.
+		my @plans	= $self->generate_plans( $algebra->pattern, $context, %args, named_graph => $algebra->graph );
 		push(@return_plans, @plans);
 	} elsif ($type eq 'Offset') {
 		my @base	= $self->generate_plans( $algebra->pattern, $context, %args );
@@ -615,7 +568,7 @@ sub generate_plans {
 		# just like a BGP or GGP, but we have to pass the optional flag to the join constructor
 		my @patterns	= ($algebra->pattern, $algebra->optional);
 		my @base_plans	= map { [ $self->generate_plans( $_, $context, %args ) ] } @patterns;
-		my @join_types	= RDF::Query::Plan::Join->join_classes( $config );
+		my @join_types	= RDF::Query::Plan::Join->join_classes;
 		# XXX this is currently only considering left-deep trees. maybe it should produce all trees?
 		my @plans;
 		my $base_a	= shift(@base_plans);
@@ -626,11 +579,10 @@ sub generate_plans {
 				my $b	= $base_b->[ $j ];
 				foreach my $join_type (@join_types) {
 					try {
-						my $plan	= $join_type->new( $a, $b, 1, {} );
+						my $plan	= $join_type->new( $a, $b, 1, {  } );
 						push( @plans, $plan );
 					} catch RDF::Query::Error::MethodInvocationError with {
-# 						my $e	= shift;
-# 						warn "caught MethodInvocationError: " . Dumper($e);
+#						warn "caught MethodInvocationError.";
 					};
 				}
 			}
@@ -660,7 +612,7 @@ sub generate_plans {
 			# if there's constant data to be joined, we better do it now in case
 			# the project gets rid of variables needed for the join
 			my @plans	= splice( @base );
-			@base		= $self->_add_constant_join( $context, $constant, @plans );
+			@base		= $self->_add_constant_join( $constant, @plans );
 			$constant	= undef;
 		}
 		
@@ -683,64 +635,17 @@ sub generate_plans {
 		my @base	= $self->generate_plans( $pattern, $context, %args );
 		my @plans;
 		foreach my $plan (@base) {
-			my $sparqlcb	= sub {
-				my $row		= shift;
-				my $p		= $pattern;
-				if ($row) {
-					$p		= $p->bind_variables( $row );
-				}
-				my $ns			= $context->ns;
-				my $pstr		= $p->as_sparql({namespaces => $ns}, '');
-				unless (substr($pstr, 0, 1) eq '{') {
-					$pstr	= "{ $pstr }";
-				}
-				my $sparql		= join("\n",
-									(map { sprintf("PREFIX %s: <%s>", ($_ eq '__DEFAULT__' ? '' : $_), $ns->{$_}) } (keys %$ns)),
-									sprintf("SELECT * WHERE %s", $pstr)
-								);
-				return $sparql;
-			};
-			
-# 			unless ($algebra->endpoint->can('uri_value')) {
-# 				throw RDF::Query::Error::UnimplementedError (-text => "Support for variable-endpoint SERVICE blocks is not implemented");
-# 			}
-			
-			if (my $ggp = $algebra->lhs) {
-				my @lhs_base	= $self->generate_plans( $ggp, $context, %args );
-				foreach my $lhs_plan (@lhs_base) {
-					my $splan	= RDF::Query::Plan::Service->new( $algebra->endpoint, $plan, $algebra->silent, $sparqlcb, $lhs_plan );
-					push(@plans, $splan);
-				}
-			} else {
-				push(@plans, $PLAN_CLASSES{'service'}->new( $algebra->endpoint, $plan, $algebra->silent, $sparqlcb ));
-			}
+			my $ns			= $context->ns;
+			my $sparql		= join("\n",
+								(map { sprintf("PREFIX %s: <%s>", $_, $ns->{$_}) } (keys %$ns)),
+								sprintf("SELECT * WHERE %s", $pattern->as_sparql({namespaces => $ns}, ''))
+							);
+			push(@plans, RDF::Query::Plan::Service->new( $algebra->endpoint->uri_value, $plan, $sparql ));
 		}
 		push(@return_plans, @plans);
 	} elsif ($type eq 'SubSelect') {
 		my $query	= $algebra->query;
-		my $model	= $context->model;
-		my %pargs	= %args;
-		my $ag		= $args{ active_graph };
-		if (blessed($ag) and $ag->isa('RDF::Query::Node::Variable')) {
-			my %vars	= map { $_ => 1 } $query->pattern->referenced_variables;
-			if ($vars{ $ag->name }) {
-				my $new_ag		= RDF::Query::Node::Variable->new();
-				my ($pattern)	= $query->pattern;
-				my $new_pattern	= $pattern->bind_variables( { $ag->name => $new_ag } );
-				my $apattern	= RDF::Query::Algebra::Extend->new(
-									$new_pattern,
-									[
-										RDF::Query::Expression::Alias->new( 'alias', $ag, $new_ag )
-									]
-								);
-				$query->{parsed}{triples}	= [$apattern];
-			}
-			my ($plan)	= $self->generate_plans( $query->pattern, $context, %args );
-			push(@return_plans, RDF::Query::Plan::SubSelect->new( $query, $plan ));
-		} else {
-			my ($plan)	= $query->prepare( $context->model, planner_args => \%pargs );
-			push(@return_plans, RDF::Query::Plan::SubSelect->new( $query, $plan ));
-		}
+		push(@return_plans, RDF::Query::Plan::SubSelect->new( $query ));
 	} elsif ($type eq 'Sort') {
 		my @base	= $self->generate_plans( $algebra->pattern, $context, %args );
 		my @order	= $algebra->orderby;
@@ -753,101 +658,50 @@ sub generate_plans {
 		my @plans	= map { RDF::Query::Plan::Sort->new( $_, @neworder ) } @base;
 		push(@return_plans, @plans);
 	} elsif ($type eq 'Triple' or $type eq 'Quad') {
-		my $st;
-		if ($args{ prevent_distinguishing_bnodes }) {
-			$st	= $algebra;
-		} else {
-			$st		= $algebra->distinguish_bnode_variables;
-		}
+		my $st		= $algebra->distinguish_bnode_variables;
 		my $pred    = $st->predicate;
-		my @nodes    = $st->nodes;
-		
 		if (my @csg_plans = $self->_csg_plans( $context, $st )) {
 			push(@return_plans, @csg_plans);
-		} elsif ($type eq 'Triple') {
-			my $plan    = RDF::Query::Plan::Quad->new( @nodes[0..2], $active_graph, { sparql => $algebra->as_sparql, bf => $algebra->bf } );
-			push(@return_plans, $plan);
 		} else {
+			my @nodes    = $st->nodes;
 			my $plan    = (scalar(@nodes) == 4)
 						? RDF::Query::Plan::Quad->new( @nodes, { sparql => $algebra->as_sparql } )
-						: RDF::Query::Plan::Quad->new( @nodes, RDF::Trine::Node::Nil->new(), { sparql => $algebra->as_sparql, bf => $algebra->bf } );
+						: RDF::Query::Plan::Triple->new( @nodes, { sparql => $algebra->as_sparql, bf => $algebra->bf } );
 			push(@return_plans, $plan);
 		}
 	} elsif ($type eq 'Path') {
-		my @plans	= $self->_path_plans( $algebra, $context, %args );
+		my @plans	= $self->_path_plans( $algebra, $context );
 		push(@return_plans, @plans);
 	} elsif ($type eq 'Union') {
 		my @plans	= map { [ $self->generate_plans( $_, $context, %args ) ] } $algebra->patterns;
 		my $plan	= RDF::Query::Plan::Union->new( map { $_->[0] } @plans );
 		push(@return_plans, $plan);
 	} elsif ($type eq 'Sequence') {
-		my @pat		= $algebra->patterns;
-		if (@pat) {
-			my @plans	= map { [ $self->generate_plans( $_, $context, %args ) ] } @pat;
-			my $plan	= RDF::Query::Plan::Sequence->new( map { $_->[0] } @plans );
-			push(@return_plans, $plan);
-		} else {
-			my $stream	= RDF::Trine::Iterator::Bindings->new( sub {} );
-			push(@return_plans, $stream);
-		}
+		my @plans	= map { [ $self->generate_plans( $_, $context, %args ) ] } $algebra->patterns;
+		my $plan	= RDF::Query::Plan::Sequence->new( map { $_->[0] } @plans );
+		push(@return_plans, $plan);
 	} elsif ($type eq 'Load') {
 		push(@return_plans, RDF::Query::Plan::Load->new( $algebra->url, $algebra->graph ));
 	} elsif ($type eq 'Update') {
-		my $ds		= $algebra->dataset || {};
-		my $default	= $ds->{'default'} || [];
-		my $named	= $ds->{'named'} || {};
-		my $dcount	= scalar(@$default);
-		my $ncount	= scalar(@{[ keys %$named ]});
-# 		warn 'Update dataset: ' . Dumper($algebra->dataset);
-		my @plans;
-		
-		my @dataset	= ($ds);
-		if ($dcount == 1 and $ncount == 0) {
-			# if it's just a single named graph to be used as the default graph,
-			# then rewrite the pattern to use the named graph (and check to make
-			# sure there aren't any GRAPH blocks)
-			@dataset	= ();
-			@plans		= $self->generate_plans( $algebra->pattern, $context, %args, active_graph => $default->[0] );
-		} elsif ($dcount == 0 and $ncount == 0) {
-			@dataset	= ();
-			@plans		= $self->generate_plans( $algebra->pattern, $context, %args );
-		} else {
-			@plans		= $self->generate_plans( $algebra->pattern, $context, %args );
-		}
+		my @plans	= $self->generate_plans( $algebra->pattern, $context, %args );
 		foreach my $p (@plans) {
-			push(@return_plans, RDF::Query::Plan::Update->new( $algebra->delete_template, $algebra->insert_template, $p, @dataset ));
+			push(@return_plans, RDF::Query::Plan::Update->new( $algebra->delete_template, $algebra->insert_template, $p ));
 		}
 	} elsif ($type eq 'Clear') {
 		push(@return_plans, RDF::Query::Plan::Clear->new( $algebra->graph ));
-	} elsif ($type eq 'Create') {
-		my $plan	= RDF::Query::Plan::Constant->new();
-		push(@return_plans, $plan);
- 	} elsif ($type eq 'Copy') {
- 		my $plan	= RDF::Query::Plan::Copy->new( $algebra->from, $algebra->to, $algebra->silent );
-		push(@return_plans, $plan);
- 	} elsif ($type eq 'Move') {
- 		my $plan	= RDF::Query::Plan::Move->new( $algebra->from, $algebra->to, $algebra->silent );
-		push(@return_plans, $plan);
-	} elsif ($type eq 'Table') {
-		my $plan	= RDF::Query::Plan::Constant->new( $algebra->rows );
-		push(@return_plans, $plan);
 	} else {
 		throw RDF::Query::Error::MethodInvocationError (-text => "Cannot generate an execution plan for unknown algebra class $aclass");
 	}
 	
 	if ($constant and scalar(@$constant)) {
 		my @plans		= splice( @return_plans );
-		@return_plans	= $self->_add_constant_join( $context, $constant, @plans );
+		@return_plans	= $self->_add_constant_join( $constant, @plans );
 	}
 	
 	foreach my $p (@return_plans) {
-		Carp::confess 'not a plan: ' . Dumper($p) unless ($p->isa('RDF::Query::Plan'));
 		$p->label( algebra => $algebra );
 	}
 	
-	unless (scalar(@return_plans)) {
-		throw RDF::Query::Error::CompilationError (-text => "Cannot generate an execution plan for algebra of type $type", -object => $algebra);
-	}
 	return @return_plans;
 }
 
@@ -856,7 +710,7 @@ sub _csg_plans {
 	my $context	= shift;
 	my $st		= shift;
 	my $pred	= $st->predicate;
-	return unless (blessed($context));
+	Carp::confess unless (blessed($context));
 	my $query    = $context->query;
 	my @return_plans;
 	if (blessed($query) and $pred->isa('RDF::Trine::Node::Resource') and scalar(@{ $query->get_computed_statement_generators( $st->predicate->uri_value ) })) {
@@ -874,10 +728,9 @@ sub _join_plans {
 	my $context	= shift;
 	my $triples	= shift;
 	my %args	= @_;
-	my $config	= $context->options || {};
 	
 	my $method		= $args{ method };
-	my @join_types	= RDF::Query::Plan::Join->join_classes( $config );
+	my @join_types	= RDF::Query::Plan::Join->join_classes;
 	
 	my @plans;
 	my $opt		= $context->optimize;
@@ -905,7 +758,6 @@ sub _join_plans {
 						}
 					}
 					foreach my $join_type (@join_types) {
-						next if ($join_type eq 'RDF::Query::Plan::Join::PushDownNestedLoop' and $b->subplans_of_type('RDF::Query::Plan::Service'));
 						try {
 							my @algebras;
 							foreach ($algebra_a, $algebra_b) {
@@ -951,11 +803,9 @@ sub _join_plans {
 
 sub _add_constant_join {
 	my $self		= shift;
-	my $context		= shift;
 	my $constant	= shift;
 	my @return_plans	= @_;
-	my $config		= $context->options || {};
-	my @join_types	= RDF::Query::Plan::Join->join_classes( $config );
+	my @join_types	= RDF::Query::Plan::Join->join_classes;
 	while (my $const = shift(@$constant)) {
 		my @plans	= splice(@return_plans);
 		foreach my $p (@plans) {
@@ -976,46 +826,15 @@ sub _path_plans {
 	my $self	= shift;
 	my $algebra	= shift;
 	my $context	= shift;
-	my %args	= @_;
 	my $path	= $algebra->path;
-	my $start	= $algebra->start;
-	my $end		= $algebra->end;
-	for ($start, $end) {
-		if ($_->isa('RDF::Query::Node::Blank')) {
-			$_	= $_->make_distinguished_variable;
-		}
-	}
-	
-	my $npath	= $self->_normalize_path( $path );
-	return $self->__path_plan( $start, $npath, $end, $args{ active_graph }, $context, %args );
-}
-
-sub _normalize_path {
-	my $self	= shift;
-	my $path	= shift;
-	if (blessed($path)) {
-		return $path;
-	}
-	
-	my $op		= $path->[0];
-	my @nodes	= map { $self->_normalize_path($_) } @{ $path }[ 1 .. $#{ $path } ];
-	if ($op	eq '0-') {
-		$op	= '*';
-	} elsif ($op eq '1-') {
-		$op	= '+';
-	} elsif ($op eq '0-1') {
-		$op	= '?';
-	} elsif ($op =~ /^-\d+$/) {
-		$op	= "0$op";
-	}
-	
-	if ($op eq '!') {
-		# re-order the nodes so that forward predicates come first, followed by backwards predicates
-		# !(:fwd1|:fwd2|:fwd3|^:bkw1|^:bkw2|^:bkw3)
-		@nodes	= sort { blessed($a) ? -1 : (($a->[0] eq '^') ? 1 : -1) } @nodes;
-	}
-	
-	return [$op, @nodes];
+# 	if ($algebra->bounded_length) {
+# 		warn "Fixed length path";
+		my $start	= $algebra->start;
+		my $end		= $algebra->end;
+		return $self->__path_plan( $start, $path, $end, $context );
+# 	} else {
+# 		throw RDF::Query::Error -text => "Unbounded paths not implemented yet";
+# 	}
 }
 
 sub __path_plan {
@@ -1023,77 +842,85 @@ sub __path_plan {
 	my $start	= shift;
 	my $path	= shift;
 	my $end		= shift;
-	my $graph	= shift;
 	my $context	= shift;
-	my %args	= @_;
-	my $distinct	= 1; #$args{distinct} ? 1 : 0;
-	my $config		= $context->options || {};
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.path");
-	
-	
-	# _simple_path will return an algebra object if the path can be expanded
-	# into a simple basic graph pattern (for fixed-length paths)
-	if (my $a = $self->_simple_path( $start, $path, $end, $graph )) {
-		my ($plan)	= $self->generate_plans( $a, $context, %args, prevent_distinguishing_bnodes => 1 );
-		$l->trace('expanded path to pattern: ' . $plan->sse);
-		return $plan;
-	}
-	
-	
 	if (blessed($path)) {
-### X iri Y
-		# $path is a resource object: this is a triple (a path of length 1)
-		my $s	= $start;
-		my $e	= $end;
-		my $algebra	= $graph
-					? RDF::Query::Algebra::Quad->new( $s, $path, $e, $graph )
-					: RDF::Query::Algebra::Triple->new( $s, $path, $e );
-		my ($plan)	= $self->generate_plans( $algebra, $context, %args, prevent_distinguishing_bnodes => 1 );
-		$l->trace('expanded path to pattern: ' . $plan->sse);
+		my $s		= ($start->isa('RDF::Query::Node::Blank')) ? $start->make_distinguished_variable : $start;
+		my $e		= ($end->isa('RDF::Query::Node::Blank')) ? $end->make_distinguished_variable : $end;
+		my $plan	= RDF::Query::Plan::Triple->new( $s, $path, $e );
+		$l->trace('expanded path to triple pattern: ' . $plan->sse);
 		return $plan;
 	}
 	
 	my ($op, @nodes)	= @$path;
-	
-# 	if ($op eq 'DISTINCT') {
-# 		return $self->__path_plan( $start, $nodes[0], $end, $graph, $context, %args, distinct => 1 );
-# 	}
 	if ($op eq '!') {
-		my $total	= scalar(@nodes);
-		my $neg		= scalar(@{ [ grep { not(blessed($_)) and $_->[0] eq '^' } @nodes ] });
-		my $pos		= $total - $neg;
-		if ($pos == $total) {
-### X !(:iri1|...|:irin) Y		
-			return RDF::Query::Plan::Path->new( 'NegatedPropertySet', $start, [@nodes], $end, $graph, $distinct, %args );
-		} elsif ($neg == $total) {
-### X !(^:iri1|...|^:irin)Y
-			my @preds	= map { $_->[1] } @nodes;
-			return $self->__path_plan($start, ['^', ['!', @preds]], $end, $graph, $context, %args);
-		} else {
-### X !(:iri1|...|:irii|^:irii+1|...|^:irim) Y 
-			my @fwd	= grep { blessed($_) } @nodes;
-			my @bwd	= grep { not(blessed($_)) } @nodes;
-			my $fplan	= $self->__path_plan($start, ['!', @fwd], $end, $graph, $context, %args);
-			my $bplan	= $self->__path_plan($start, ['!', @bwd], $end, $graph, $context, %args);
-			return RDF::Query::Plan::Union->new($fplan, $bplan);
+		my $model	= $context->model;
+		my $var		= RDF::Query::Node::Variable->new();
+		my $nvar	= RDF::Query::Node::Variable->new();
+		my $triple	= RDF::Query::Algebra::Triple->new( $start, $var, $end );
+		my $ntriple	= RDF::Query::Algebra::Triple->new( $end, $nvar, $start );
+		my @plans;
+		push(@plans, $self->generate_plans( $triple, $context ));
+		push(@plans, $self->generate_plans( $ntriple, $context ));
+		
+		my (%not, %revnot);
+		foreach my $n (@nodes) {
+			if (blessed($n)) {
+				$not{ $n->uri_value }++;
+			} else {
+				$revnot{ $n->[1]->uri_value }++;
+			}
 		}
+		
+		$_->execute( $context ) for (@plans);
+		my $code	= sub {
+			while (1) {
+				return unless (@plans);
+				my $row	= $plans[0]->next;
+				unless (blessed($row)) {
+					shift(@plans);
+					next;
+				}
+				if (my $p = $row->{ $var->name }) {
+					next if (exists $not{ $p->uri_value });
+				} else {
+					my $np	= $row->{ $nvar->name };
+					next if (exists $not{ $np->uri_value });
+				}
+				return $row;
+			}
+		};
+		my $iter	= RDF::Trine::Iterator::Bindings->new( $code, [] );
+		my $nplan	= RDF::Query::Plan::Iterator->new( $iter );
+# 		my $dnplan	= RDF::Query::Plan::Distinct->new( $nplan );
+		return $nplan;
+	} elsif ($op eq '*') {
+		return RDF::Query::Plan::Path->new( $op, $nodes[0], $start, $end );
+	} elsif ($op eq '+') {
+		return RDF::Query::Plan::Path->new( $op, $nodes[0], $start, $end );
+	} elsif ($op eq '?') {
+		my $node	= shift(@nodes);
+		my $plan	= $self->__path_plan( $start, $node, $end, $context );
+		my $zero	= $self->__zero_length_path_plan( $start, $end, $context );
+		my $union	= RDF::Query::Plan::Union->new( $zero, $plan );
+		return $union;
 	} elsif ($op eq '^') {
-### X ^path Y
-		return $self->__path_plan( $end, $nodes[0], $start, $graph, $context, %args);
+		my $node	= shift(@nodes);
+		return $self->__path_plan( $end, $node, $start, $context );
 	} elsif ($op eq '/') {
 		my $count	= scalar(@nodes);
 		if ($count == 1) {
-			return $self->__path_plan( $start, $nodes[0], $end, $graph, $context, %args );
+			return $self->__path_plan( $start, $nodes[0], $end, $context );
 		} else {
 			my $joinvar		= RDF::Query::Node::Variable->new();
-			my @plans		= $self->__path_plan( $start, $nodes[0], $joinvar, $graph, $context, %args );
+			my @plans		= $self->__path_plan( $start, $nodes[0], $joinvar, $context );
 			foreach my $i (2 .. $count) {
 				my $endvar	= ($i == $count) ? $end : RDF::Query::Node::Variable->new();
-				my ($rhs)		= $self->__path_plan( $joinvar, $nodes[$i-1], $endvar, $graph, $context, %args );
+				my ($rhs)		= $self->__path_plan( $joinvar, $nodes[$i-1], $endvar, $context );
 				push(@plans, $rhs);
 				$joinvar	= $endvar;
 			}
-			my @join_types	= RDF::Query::Plan::Join->join_classes( $config );
+			my @join_types	= RDF::Query::Plan::Join->join_classes;
 			my @jplans;
 			foreach my $jclass (@join_types) {
 				push(@jplans, $jclass->new( @plans[0,1], 0 ));
@@ -1102,48 +929,28 @@ sub __path_plan {
 			return $jplans[0];
 		}
 	} elsif ($op eq '|') {
-### X path1 | path2 Y
-		my @plans	= map { $self->__path_plan($start, $_, $end, $graph, $context, %args) } @nodes;
-		return RDF::Query::Plan::Union->new(@plans);
-	} elsif ($op eq '?') {
-### X path? Y
-		my $upath	= $nodes[0];
-		my $zplan	= $self->__path_plan($start, ['0', $upath], $end, $graph, $context, %args );
-		my $oplan	= $self->__path_plan($start, $upath, $end, $graph, $context, %args);
-		
-		# project away any non-distinguished variables introduced by plan-to-bgp expansion
-		my @vars	= grep { blessed($_) and $_->isa('RDF::Query::Node::Variable') } ($start, $end);
-		my $odplan	= RDF::Query::Plan::Project->new( $oplan, \@vars );
-		
-		my $pplan	= RDF::Query::Plan::Union->new($zplan, $odplan);
-		
-		# distinct the results
-		my $plan	= RDF::Query::Plan::Distinct->new( $pplan );
-		return $plan;
-	} elsif ($op eq '*') {
-### X path* Y
-		return RDF::Query::Plan::Path->new( 'ZeroOrMorePath', $start, $nodes[0], $end, $graph, $distinct, %args );
-	} elsif ($op eq '+') {
-### X path+ Y
-		return RDF::Query::Plan::Path->new( 'OneOrMorePath', $start, $nodes[0], $end, $graph, $distinct, %args );
-	} elsif ($op eq '0') {
-### X path{0} Y
-		return RDF::Query::Plan::Path->new( 'ZeroLengthPath', $start, $nodes[0], $end, $graph, $distinct, %args );
-	} elsif ($op =~ /^\d+$/) {
-### X path{n} Y where n > 0
-		my $count	= $op;
-		if ($count == 1) {
-			return $self->__path_plan( $start, $nodes[0], $end, $graph, $context, %args );
+		my $lhs		= $self->__path_plan( $start, $nodes[0], $end, $context );
+		my $rhs		= $self->__path_plan( $start, $nodes[1], $end, $context );
+		my $union	= RDF::Query::Plan::Union->new( $lhs, $rhs );
+		return $union;
+	} elsif ($op =~ /^(\d+)$/) {
+# 		warn "$1-length path";
+		my $count	= $1;
+		if ($count == 0) {
+			my $zero	= $self->__zero_length_path_plan( $start, $end, $context );
+			return $zero;
+		} elsif ($count == 1) {
+			return $self->__path_plan( $start, $nodes[0], $end, $context );
 		} else {
 			my $joinvar		= RDF::Query::Node::Variable->new();
-			my @plans		= $self->__path_plan( $start, $nodes[0], $joinvar, $graph, $context, %args );
+			my @plans		= $self->__path_plan( $start, $nodes[0], $joinvar, $context );
 			foreach my $i (2 .. $count) {
 				my $endvar	= ($i == $count) ? $end : RDF::Query::Node::Variable->new();
-				my ($rhs)		= $self->__path_plan( $joinvar, $nodes[0], $endvar, $graph, $context, %args );
+				my ($rhs)		= $self->__path_plan( $joinvar, $nodes[0], $endvar, $context );
 				push(@plans, $rhs);
 				$joinvar	= $endvar;
 			}
-			my @join_types	= RDF::Query::Plan::Join->join_classes( $config );
+			my @join_types	= RDF::Query::Plan::Join->join_classes;
 			my @jplans;
 			
 			my @plan	= shift(@plans);
@@ -1160,18 +967,17 @@ sub __path_plan {
 			return $plan[0];
 		}
 	} elsif ($op =~ /^(\d+)-(\d+)$/) {
-### X path{n,m} Y
-		my ($n,$m)	= split('-', $op, 2);
 # 		warn "$1- to $2-length path";
-		my @range	= sort { $a <=> $b } ($n, $m);
+		my @range	= sort { $a <=> $b } ($1, $2);
 		my $from	= $range[0];
 		my $to		= $range[1];
 		my @plans;
 		foreach my $i ($from .. $to) {
 			if ($i == 0) {
-				push(@plans, $self->__path_plan($start, ['0', []], $end, $graph, $context, %args ));
+				my $zero	= $self->__zero_length_path_plan( $start, $end, $context );
+				push(@plans, $zero);
 			} else {
-				push(@plans, $self->__path_plan( $start, [$i, $nodes[0]], $end, $graph, $context, %args ));
+				push(@plans, $self->__path_plan( $start, [$i, $nodes[0]], $end, $context ));
 			}
 		}
 		while (scalar(@plans) > 1) {
@@ -1181,51 +987,48 @@ sub __path_plan {
 		}
 		return $plans[0];
 	} elsif ($op =~ /^(\d+)-$/) {
-### X path{n,} Y where n > 0
-		my ($min)	= split('-', $op);
-		# expand :p{n,} into :p{n}/:p*
-		my $path		= [ '/', [ $1, @nodes ], [ '*', @nodes ] ];
-		my $plan		= $self->__path_plan( $start, $path, $end, $graph, $context, %args );
-		return $plan;
+		throw RDF::Query::Error -text => "Unbounded paths not implemented yet";
 	} else {
 		throw RDF::Query::Error -text => "Cannot generate plan for unknown path type $op";
 	}
 }
 
-sub _simple_path {
+sub __zero_length_path_plan {
 	my $self	= shift;
 	my $start	= shift;
-	my $path	= shift;
 	my $end		= shift;
-	my $graph	= shift;
-	if (blessed($path)) {
-		return ($graph)
-			? RDF::Query::Algebra::Quad->new( $start, $path, $end, $graph )
-			: RDF::Query::Algebra::Triple->new( $start, $path, $end );
-	}
-	return unless (reftype($path) eq 'ARRAY');
-	my $op	= $path->[0];
-	if ($op eq '/') {
-		my @patterns;
-		my @jvars	= map { RDF::Query::Node::Variable->new() } (2 .. $#{ $path });
-		foreach my $i (1 .. $#{ $path }) {
-			my $s		= ($i == 1) ? $start : $jvars[ $i-2 ];
-			my $e		= ($i == $#{ $path }) ? $end : $jvars[ $i-1 ];
-			my $triple	= $self->_simple_path( $s, $path->[ $i ], $e, $graph );
-			return unless ($triple);
-			push(@patterns, $triple);
-		}
-		my @triples	= map { $_->isa('RDF::Query::Algebra::BasicGraphPattern') ? $_->triples : $_ } @patterns;
-		return RDF::Query::Algebra::BasicGraphPattern->new( @triples );
-	} elsif ($op eq '^' and scalar(@$path) == 2 and blessed($path->[1])) {
-		return ($graph)
-			? RDF::Query::Algebra::Quad->new( $end, $path->[1], $start, $graph )
-			: RDF::Query::Algebra::Triple->new( $end, $path->[1], $start );
-	} elsif ($op =~ /^\d+$/ and $op == 1) {
-		return $self->_simple_path( $start, $path->[1], $end, $graph );
+	my $context	= shift;
+	my $model	= $context->model;
+	my @iters;
+	push(@iters, scalar($model->subjects));
+#	push(@iters, scalar($model->predicates));
+	push(@iters, scalar($model->objects));
+	my %vars;
+	my $no_literals	= 0;
+	if ($start->isa('RDF::Query::Node::Variable')) {
+		$vars{ $start->name }++;
+		$no_literals	= 1;
 	}
+	$vars{ $end->name }++ if ($end->isa('RDF::Query::Node::Variable'));
 	
-	return;
+	my $code	= sub {
+		while (1) {
+			return unless scalar(@iters);
+			my $node	= $iters[0]->next;
+			if ($node) {
+				if ($no_literals) {
+					next if ($node->isa('RDF::Query::Node::Literal'));
+				}
+				my $vb	= RDF::Query::VariableBindings->new( { map { $_ => $node } (keys %vars) } );
+				return $vb;
+			} else {
+				shift(@iters);
+			}
+		}
+	};
+	my $iter	= RDF::Trine::Iterator::Bindings->new( $code, [] );
+	my $nodes	= RDF::Query::Plan::Iterator->new( $iter );
+	my $plan	= RDF::Query::Plan::Distinct->new( $nodes );
 }
 
 =item C<< plan_node_name >>
@@ -1241,23 +1044,23 @@ sub plan_node_name;
 Returns a list of scalar identifiers for the type of the content (children)
 nodes of this plan node. These identifiers are recognized:
 
- * 'A' - An RDF::Query::Algebra object
- * 'b' - A boolean integer value (0 or 1)
- * 'E' - An expression (either an RDF::Query::Expression object or an RDF node)
- * 'i' - An integer
- * 'J' - A valid Project node (an RDF::Query::Expression object or an Variable node)
- * 'N' - An RDF node
  * 'P' - A RDF::Query::Plan object
- * 'q' - A RDF::Query object
- * 'Q' - An RDF::Trine::Statement::Quad object
- * 's' - A string
  * 'T' - An RDF::Trine::Statement object
- * 'u' - A valid URI string
- * 'V' - A variable binding set (an object of type RDF::Query::VariableBindings)
- * 'w' - A bareword string
+ * 'A' - An RDF::Query::Algebra object
+ * 'Q' - An RDF::Trine::Statement::Quad object
+ * 'N' - An RDF node
  * 'W' - An RDF node or wildcard ('*')
- * '*X' - A list of X nodes (where X is another identifier scalar)
+ * 'E' - An expression (either an RDF::Query::Expression object or an RDF node)
+ * 'J' - A valid Project node (an RDF::Query::Expression object or an Variable node)
+ * 'V' - A variable binding set (an object of type RDF::Query::VariableBindings)
+ * 'u' - A valid URI string
+ * 'i' - An integer
+ * 'b' - A boolean integer value (0 or 1)
+ * 's' - A string
+ * 'w' - A bareword string
  * '\X' - An array reference of X nodes (where X is another identifier scalar)
+ * '*X' - A list of X nodes (where X is another identifier scalar)
+ * 'Q' - A RDF::Query object
 
 =cut
 
@@ -1272,36 +1075,6 @@ the signature returned by C<< plan_prototype >>.
 
 sub plan_node_data;
 
-
-=item C<< subplans_of_type ( $type [, $block] ) >>
-
-Returns a list of Plan objects matching C<< $type >> (tested with C<< isa >>).
-If C<< $block >> is given, then matching stops descending a subtree if the current
-node is of type C<< $block >>, continuing matching on other subtrees.
-This list includes the current plan object if it matches C<< $type >>, and is
-generated in infix order.
-
-=cut
-
-sub subplans_of_type {
-	my $self	= shift;
-	my $type	= shift;
-	my $block	= shift;
-	
-	return if ($block and $self->isa($block));
-	
-	my @patterns;
-	push(@patterns, $self) if ($self->isa($type));
-	
-	
-	foreach my $p ($self->plan_node_data) {
-		if (blessed($p) and $p->isa('RDF::Query::Plan')) {
-			push(@patterns, $p->subplans_of_type($type, $block));
-		}
-	}
-	return @patterns;
-}
-
 1;
 
 __END__
