@@ -7,13 +7,10 @@ RDF::Query::Plan::BasicGraphPattern - Executable query plan for BasicGraphPatter
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::BasicGraphPattern version 2.919.
+This document describes RDF::Query::Plan::BasicGraphPattern version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -31,7 +28,7 @@ use RDF::Trine::Statement;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -44,7 +41,6 @@ sub new {
 	my $class	= shift;
 	my @triples	= map {
 					my @nodes	= $_->nodes;
-					$nodes[3]	||= RDF::Trine::Node::Nil->new();
 					(scalar(@nodes) == 4)
 						? RDF::Trine::Statement::Quad->new( @nodes )
 						: RDF::Trine::Statement->new( @nodes )
@@ -63,7 +59,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "BGP plan can't be executed twice";
 	}
@@ -93,18 +88,12 @@ sub execute ($) {
 		@bound_triples	= @{ $self->[1] };
 	}
 	
-	my @tmp		= grep { $_->isa('RDF::Trine::Statement::Quad') and $_->context->isa('RDF::Trine::Node::Variable') } @bound_triples;
-	my $quad	= scalar(@tmp) ? $tmp[0]->context : undef;
-	
 	my $model	= $context->model;
 	my $pattern	= RDF::Trine::Pattern->new( @bound_triples );
-	$l->trace( "BGP: " . $pattern->sse );
 	my $iter	= $model->get_pattern( $pattern );
 	
 	if (blessed($iter)) {
 		$self->[0]{iter}	= $iter;
-		$self->[0]{quad}	= $quad;
-		$self->[0]{nil}		= RDF::Trine::Node::Nil->new();
 		$self->state( $self->OPEN );
 	} else {
 		warn "no iterator in execute()";
@@ -122,30 +111,14 @@ sub next {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open BGP";
 	}
 	
-	my $q	= $self->[0]{quad};
-	
 	my $iter	= $self->[0]{iter};
-	return undef unless ($iter);
-	while (ref(my $row = $iter->next)) {
-		if (ref(my $bound = $self->[0]{bound})) {
-			@{ $row }{ keys %$bound }	= values %$bound;
-		}
-		if (blessed($q)) {
-			# skip results when we were matching over variable named graphs (GRAPH ?g {...})
-			# and where the graph variable is bound to the nil node
-			# (the nil node is used to represent the default graph, which should never match inside a GRAPH block).
-			my $node	= $row->{ $q->name };
-			if (blessed($node)) {
-				next if ($node->isa('RDF::Trine::Node::Nil'));
-			}
-		}
-		my $result	= RDF::Query::VariableBindings->new( $row );
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $result );
-		}
-		return $result;
+	my $row		= $iter->next;
+	return undef unless ($row);
+	if (my $bound = $self->[0]{bound}) {
+		@{ $row }{ keys %$bound }	= values %$bound;
 	}
-	return;
+	my $result	= RDF::Query::VariableBindings->new( $row );
+	return $result;
 }
 
 =item C<< close >>
