@@ -7,13 +7,10 @@ RDF::Query::Plan::Clear - Executable query plan for CLEAR operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Clear version 2.917.
+This document describes RDF::Query::Plan::Clear version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -36,7 +33,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -59,7 +56,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "CLEAR plan can't be executed while already open";
 	}
@@ -75,21 +71,7 @@ sub execute ($) {
 # 	warn "clearing graph " . $graph->as_string;
 	my $ok	= 0;
 	try {
-		if ($graph->is_nil) {
-			$context->model->remove_statements( undef, undef, undef, $graph );
-		} else {
-			my $uri	= $graph->uri_value;
-			if ($uri eq 'tag:gwilliams@cpan.org,2010-01-01:RT:ALL') {
-				$context->model->remove_statements( undef, undef, undef, undef );
-			} elsif ($uri eq 'tag:gwilliams@cpan.org,2010-01-01:RT:NAMED') {
-				my $citer	= $context->model->get_graphs;
-				while (my $graph = $citer->next) {
-					$context->model->remove_statements( undef, undef, undef, $graph );
-				}
-			} else {
-				$context->model->remove_statements( undef, undef, undef, $graph );
-			}
-		}
+		$context->model->remove_statements( undef, undef, undef, $graph );
 		$ok		= 1;
 	} catch RDF::Trine::Error with {};
 	$self->[0]{ok}	= $ok;
@@ -109,9 +91,6 @@ sub next {
 	
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.clear");
 	$self->close();
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $self->[0]{ok} );
-	}
 	return $self->[0]{ok};
 }
 
@@ -180,12 +159,7 @@ identifiers.
 
 sub plan_prototype {
 	my $self	= shift;
-	my $g	= $self->namedgraph;
-	if ($g->isa('RDF::Query::Node::Resource') and $g->uri_value =~ m'^tag:gwilliams@cpan[.]org,2010-01-01:RT:(NAMED|ALL)$') {
-		return qw(w);
-	} else {
-		return qw(N);
-	}
+	return qw(N);
 }
 
 =item C<< plan_node_data >>
@@ -197,12 +171,8 @@ the signature returned by C<< plan_prototype >>.
 
 sub plan_node_data {
 	my $self	= shift;
-	my $g	= $self->namedgraph;
-	if ($g->isa('RDF::Query::Node::Resource') and $g->uri_value =~ m'^tag:gwilliams@cpan[.]org,2010-01-01:RT:(NAMED|ALL)$') {
-		return $1;
-	} else {
-		return ($self->namedgraph);
-	}
+	Carp::cluck $self;
+	return ($self->namedgraph);
 }
 
 =item C<< graph ( $g ) >>
