@@ -7,13 +7,10 @@ RDF::Query::Plan::Constant - Executable query plan for Constants.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Constant version 2.919.
+This document describes RDF::Query::Plan::Constant version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -28,7 +25,7 @@ use base qw(RDF::Query::Plan);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -52,7 +49,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "CONSTANT plan can't be executed while already open";
 	}
@@ -62,32 +58,6 @@ sub execute ($) {
 	$self;
 }
 
-=item C<< bindings >>
-
-Returns a list of the variable bindings for this constant result set.
-
-=cut
-
-sub bindings {
-	my $self	= shift;
-	my $binds	= $self->[1] || [];
-	return @$binds;
-}
-
-=item C<< is_unit >>
-
-Returns true if this constant result set is comprised of a single, empty variable binding.
-
-=cut
-
-sub is_unit {
-	my $self	= shift;
-	my @binds	= $self->bindings;
-	return 0 unless scalar(@binds) == 1;
-	my @keys	= keys %{ $binds[0] };
-	return not(scalar(@keys));
-}
-
 =item C<< next >>
 
 =cut
@@ -98,19 +68,8 @@ sub next {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open CONSTANT";
 	}
 	my $binds	= $self->[1];
-	if ($self->[0]{'index'} > $#{ $binds }) {
-		return;
-	}
-	my $row	= $binds->[ $self->[0]{'index'}++ ];
-	if ($row) {
-		my $bindings	= RDF::Query::VariableBindings->new( $row );
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $bindings );
-		}
-		return $bindings;
-	} else {
-		return;
-	}
+	return undef if ($self->[0]{'index'} > $#{ $binds });
+	return $binds->[ $self->[0]{'index'}++ ];
 }
 
 =item C<< close >>
