@@ -7,13 +7,10 @@ RDF::Query::Plan::Construct - Executable query plan for constructing a graph fro
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Construct version 2.918.
+This document describes RDF::Query::Plan::Construct version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -25,13 +22,13 @@ use warnings;
 use base qw(RDF::Query::Plan);
 
 use Log::Log4perl;
-use Scalar::Util qw(blessed refaddr);
+use Scalar::Util qw(blessed);
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -61,7 +58,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "CONSTRUCT plan can't be executed while already open";
 	}
@@ -96,15 +92,10 @@ sub next {
 	my $plan	= $self->[1];
 	while (1) {
 		while (scalar(@{ $self->[0]{triples} })) {
-			my $t	= shift(@{ $self->[0]{triples} });
-			if (my $d = $self->delegate) {
-				$d->log_result( $self, $t );
-			}
-			return $t;
+			return shift(@{ $self->[0]{triples} });
 		}
 		my $row	= $plan->next;
 		return undef unless ($row);
-		$self->[0]{blank_map}	= {};
 		
 		if ($l->is_debug) {
 			$l->debug( "- got construct bindings from pattern: " . $row->as_string );
@@ -136,9 +127,7 @@ sub next {
 			}
 			next unless ($ok);
 			my $st	= RDF::Trine::Statement->new( @triple );
-			unless ($self->[0]{seen}{ $st->as_string }++) {
-				push(@{ $self->[0]{triples} }, $st);
-			}
+			push(@{ $self->[0]{triples} }, $st);
 		}
 	}
 }
@@ -239,31 +228,6 @@ sub plan_node_data {
 	return ($self->pattern, [ @{ $self->triples } ]);
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the query plan appropriate for display
-on the command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my ($s, $count)	= ('  ', 0);
-	if (@_) {
-		$s		= shift;
-		$count	= shift;
-	}
-	my $indent	= '' . ($s x $count);
-	my $type	= $self->plan_node_name;
-	my $string	= sprintf("%s%s (0x%x)\n", $indent, $type, refaddr($self));
-	$string		.= $self->pattern->explain( $s, $count+1 );
-	$string		.= "${indent}${s}pattern\n";
-	foreach my $t (@{ $self->triples }) {
-		$string		.= "${indent}${s}${s}" . $t->as_sparql . "\n";
-	}
-	return $string;
-}
-
 =item C<< graph ( $g ) >>
 
 =cut
