@@ -7,13 +7,10 @@ RDF::Query::Plan::Distinct - Executable query plan for Distincts.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Distinct version 2.919.
+This document describes RDF::Query::Plan::Distinct version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -28,7 +25,7 @@ use base qw(RDF::Query::Plan);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -52,7 +49,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "DISTINCT plan can't be executed while already open";
 	}
@@ -82,9 +78,6 @@ sub next {
 		my $row	= $plan->next;
 		return undef unless ($row);
 		if (not $self->[0]{seen}{ $row->as_string }++) {
-			if (my $d = $self->delegate) {
-				$d->log_result( $self, $row );
-			}
 			return $row;
 		}
 	}
