@@ -7,13 +7,10 @@ RDF::Query::Plan::Filter - Executable query plan for Filters.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Filter version 2.917.
+This document describes RDF::Query::Plan::Filter version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -24,18 +21,17 @@ use strict;
 use warnings;
 use base qw(RDF::Query::Plan);
 use RDF::Query::Error qw(:try);
-use Scalar::Util qw(blessed);
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
-=item C<< new ( $plan, $expr, $active_graph ) >>
+=item C<< new ( $plan, $expr ) >>
 
 =cut
 
@@ -43,8 +39,7 @@ sub new {
 	my $class	= shift;
 	my $expr	= shift;
 	my $plan	= shift;
-	my $graph	= shift;
-	my $self	= $class->SUPER::new( $expr, $plan, $graph );
+	my $self	= $class->SUPER::new( $expr, $plan );
 	$self->[0]{referenced_variables}	= [ $plan->referenced_variables ];
 	return $self;
 }
@@ -56,7 +51,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "FILTER plan can't be executed while already open";
 	}
@@ -86,7 +80,7 @@ sub execute ($) {
 					# undef it if it wasn't defined before the local() call.
 					$query	= undef;
 				}
-				my $value	= $filter->evaluate( $query, $row, $context, $self->active_graph );
+				my $value	= $filter->evaluate( $query, $row, $context );
 				$bool	= ($value->literal_value eq 'true') ? 1 : 0;
 			} catch RDF::Query::Error with {
 				my $e	= shift;
@@ -117,7 +111,7 @@ sub next {
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.filter");
 	while (1) {
 		my $row	= $plan->next;
-		unless (defined($row)) {
+		unless ($row) {
 			$l->debug("no remaining rows in filter");
 			return;
 		}
@@ -126,9 +120,6 @@ sub next {
 		}
 		if ($filter->( $row )) {
 			$l->trace( "- filter returned true on row" );
-			if (my $d = $self->delegate) {
-				$d->log_result( $self, $row );
-			}
 			return $row;
 		} else {
 			$l->trace( "- filter returned false on row" );
@@ -146,9 +137,7 @@ sub close {
 		throw RDF::Query::Error::ExecutionError -text => "close() cannot be called on an un-open FILTER";
 	}
 	delete $self->[0]{filter};
-	if (blessed($self->pattern)) {
-		$self->pattern->close();
-	}
+	$self->[2]->close();
 	$self->SUPER::close();
 }
 
@@ -163,17 +152,6 @@ sub pattern {
 	return $self->[2];
 }
 
-=item C<< active_graph >>
-
-Returns the active graph.
-
-=cut
-
-sub active_graph {
-	my $self	= shift;
-	return $self->[3];
-}
-
 =item C<< distinct >>
 
 Returns true if the pattern is guaranteed to return distinct results.
