@@ -7,13 +7,10 @@ RDF::Query::Plan::Iterator - Executable query plan for result-generating iterato
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Iterator version 2.919.
+This document describes RDF::Query::Plan::Iterator version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -24,21 +21,17 @@ use strict;
 use warnings;
 use base qw(RDF::Query::Plan);
 
-use Scalar::Util qw(blessed reftype);
-
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
 
 =item C<< new ( $iter, \&execute_cb ) >>
 
-=item C<< new ( \&create_iterator_cb ) >>
-
 =cut
 
 sub new {
@@ -57,7 +50,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "ITERATOR plan can't be executed while already open";
 	}
@@ -66,11 +58,6 @@ sub execute ($) {
 		$self->[2]->( $context );
 	}
 	
-	# if we don't have an actual iterator, but only a promise of one, construct it now
-	if (reftype($self->[1]) eq 'CODE' and not(blessed($self->[1]) and $self->[1]->isa('RDF::Trine::Iterator'))) {
-		$self->[1]	= $self->[1]->( $context );
-	}
-	
 	$self->state( $self->OPEN );
 	$self;
 }
@@ -85,11 +72,7 @@ sub next {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open ITERATOR";
 	}
 	my $iter	= $self->[1];
-	my $bindings	= $iter->next;
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $bindings );
-	}
-	return $bindings;
+	return $iter->next;
 }
 
 =item C<< close >>
