@@ -7,13 +7,10 @@ RDF::Query::Plan::Join - Join query plan base class.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Join version 2.919.
+This document describes RDF::Query::Plan::Join version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -31,7 +28,7 @@ use RDF::Query::ExecutionContext;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -138,17 +135,8 @@ Returns the class names of all available join algorithms.
 
 sub join_classes {
 	my $class	= shift;
-	my $config	= shift || {};
 	our %JOIN_CLASSES;
-	my @classes	= reverse sort keys %JOIN_CLASSES;
-	my @ok	= grep { 
-		my $name	= lc($_);
-		$name	=~ s/::/./g;
-		(exists $config->{ $name } and not($config->{ $name }))
-			? 0
-			: 1
-	} @classes;
-	return @ok;
+	return reverse sort keys %JOIN_CLASSES;
 }
 
 =item C<< distinct >>
