@@ -7,13 +7,10 @@ RDF::Query::Plan::Join::PushDownNestedLoop - Executable query plan for nested lo
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Join::PushDownNestedLoop version 2.919.
+This document describes RDF::Query::Plan::Join::PushDownNestedLoop version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan::Join> class.
-
 =over 4
 
 =cut
@@ -23,14 +20,14 @@ package RDF::Query::Plan::Join::PushDownNestedLoop;
 use strict;
 use warnings;
 use base qw(RDF::Query::Plan::Join);
-use Scalar::Util qw(blessed refaddr);
+use Scalar::Util qw(blessed);
 use Data::Dumper;
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 	$RDF::Query::Plan::Join::JOIN_CLASSES{ 'RDF::Query::Plan::Join::PushDownNestedLoop' }++;
 }
 
@@ -47,10 +44,6 @@ sub new {
 	my $lhs		= shift;
 	my $rhs		= shift;
 	
-	if ($rhs->isa('RDF::Query::Plan::SubSelect')) {
-		throw RDF::Query::Error::MethodInvocationError -text => "Subselects cannot be the RHS of a PushDownNestedLoop join";
-	}
-	
 	my $opt		= shift || 0;
 	if (not($opt) and $rhs->isa('RDF::Query::Plan::Join') and $rhs->optional) {
 		# we can't push down results to an optional pattern because of the
@@ -58,12 +51,6 @@ sub new {
 		# for example.
 		throw RDF::Query::Error::MethodInvocationError -text => "PushDownNestedLoop join does not support optional patterns as RHS due to bottom-up variable scoping rules (use NestedLoop instead)";
 	}
-	
-	my @aggs = $rhs->subplans_of_type('RDF::Query::Plan::Aggregate');
-	if (scalar(@aggs)) {
-		throw RDF::Query::Error::MethodInvocationError -text => "PushDownNestedLoop join does not support aggregates in the RHS due to aggregate group fragmentation";
-	}
-	
 	my $self	= $class->SUPER::new( $lhs, $rhs, $opt );
 	return $self;
 }
@@ -75,19 +62,15 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "PushDownNestedLoop join plan can't be executed while already open";
 	}
 	
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.join.pushdownnestedloop");
-	$l->trace("executing bind join with plans:");
-	$l->trace($self->lhs->sse);
-	$l->trace($self->rhs->sse);
+	$l->trace("executing bind join");
 	
 	$self->lhs->execute( $context );
 	if ($self->lhs->state == $self->OPEN) {
-		delete $self->[0]{stats};
 		$self->[0]{context}			= $context;
 		$self->[0]{outer}			= $self->lhs;
 		$self->[0]{needs_new_outer}	= 1;
@@ -119,7 +102,6 @@ sub next {
 			$self->[0]{outer_row}	= $outer->next;
 			my $outer	= $self->[0]{outer_row};
 			if (ref($outer)) {
-				$self->[0]{stats}{outer_rows}++;
 				my $context	= $self->[0]{context};
 				$self->[0]{needs_new_outer}	= 0;
 				$self->[0]{inner_count}		= 0;
@@ -136,34 +118,25 @@ sub next {
 				$self->[0]{inner}			= $inner->execute( $copy );
 			} else {
 				# we've exhausted the outer iterator. we're now done.
-				$l->trace("exhausted outer plan in bind join");
+				$l->trace("exhausted");
 				return undef;
 			}
 		}
 		
 		while (defined(my $inner_row = $self->[0]{inner}->next)) {
-			$self->[0]{stats}{inner_rows}++;
-			$l->trace( "using inner row: " . $inner_row->as_string );
+			$l->trace( "using inner row: " . Dumper($inner_row) );
 			if (defined(my $joined = $inner_row->join( $self->[0]{outer_row} ))) {
-				$self->[0]{stats}{results}++;
 				if ($l->is_trace) {
-					$l->trace("joined bindings: $inner_row ⋈ $self->[0]{outer_row}");
+					$l->trace("joined bindings: $inner_row |><| $self->[0]{outer_row}");
 				}
 #				warn "-> joined\n";
 				$self->[0]{inner_count}++;
-				if (my $d = $self->delegate) {
-					$d->log_result( $self, $joined );
-				}
 				return $joined;
 			} else {
-				$l->trace("failed to join bindings: $inner_row |><| $self->[0]{outer_row}");
 				if ($opt) {
-					$l->trace( "--> but operation is OPTIONAL, so returning $self->[0]{outer_row}" );
-					if (my $d = $self->delegate) {
-						$d->log_result( $self, $self->[0]{outer_row} );
-					}
 					return $self->[0]{outer_row};
 				}
+				$l->trace("failed to join bindings: $inner_row |><| $self->[0]{outer_row}");
 			}
 		}
 		
@@ -173,9 +146,6 @@ sub next {
 		}
 		delete $self->[0]{inner};
 		if ($opt and $self->[0]{inner_count} == 0) {
-			if (my $d = $self->delegate) {
-				$d->log_result( $self, $self->[0]{outer_row} );
-			}
 			return $self->[0]{outer_row};
 		}
 	}
@@ -194,7 +164,7 @@ sub close {
 	delete $self->[0]{outer};
 	delete $self->[0]{needs_new_outer};
 	delete $self->[0]{inner_count};
-	if (blessed($self->lhs) and $self->lhs->state == $self->lhs->OPEN) {
+	if ($self->lhs->state == $self->lhs->OPEN) {
 		$self->lhs->close();
 	}
 	$self->SUPER::close();
@@ -227,30 +197,6 @@ sub graph {
 	return "$self";
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the plan appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $type	= $self->plan_node_name;
-	my $stats	= '';
-	if ($self->[0]{stats}) {
-		$stats	= sprintf(' [%d/%d/%d]', @{ $self->[0]{stats} }{qw(outer_rows inner_rows results)});
-	}
-	my $string	= sprintf("%s%s%s (0x%x)\n", $indent, $type, $stats, refaddr($self));
-	foreach my $p ($self->plan_node_data) {
-		$string	.= $p->explain( $s, $count+1 );
-	}
-	return $string;
-}
-
 
 package RDF::Query::Plan::Join::PushDownNestedLoop::Left;
 
