@@ -7,13 +7,10 @@ RDF::Query::Plan::Limit - Executable query plan for Limits.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Limit version 2.919.
+This document describes RDF::Query::Plan::Limit version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -28,7 +25,7 @@ use base qw(RDF::Query::Plan);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -53,7 +50,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "LIMIT plan can't be executed while already open";
 	}
@@ -78,14 +74,11 @@ sub next {
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open LIMIT";
 	}
-	return undef if ($self->[0]{count} >= $self->limit);
+	return undef if ($self->[0]{count} >= $self->[1]);
 	my $plan	= $self->[2];
 	my $row		= $plan->next;
 	return undef unless ($row);
 	$self->[0]{count}++;
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $row );
-	}
 	return $row;
 }
 
@@ -190,8 +183,7 @@ sub graph {
 	my $self	= shift;
 	my $g		= shift;
 	my $c		= $self->pattern->graph( $g );
-	my $limit	= $self->limit;
-	$g->add_node( "$self", label => "Limit ($limit)" . $self->graph_labels );
+	$g->add_node( "$self", label => "Limit ($self->[1])" . $self->graph_labels );
 	$g->add_edge( "$self", $c );
 	return "$self";
 }
