@@ -7,13 +7,10 @@ RDF::Query::Plan::Load - Executable query plan for LOAD operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Load version 2.917.
+This document describes RDF::Query::Plan::Load version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -36,7 +33,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -60,7 +57,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "LOAD plan can't be executed while already open";
 	}
@@ -91,9 +87,6 @@ sub next {
 	
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.load");
 	$self->close();
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $self->[0]{ok} );
-	}
 	return $self->[0]{ok};
 }
 
