@@ -7,13 +7,10 @@ RDF::Query::Plan::Minus - Executable query plan for minus operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Minus version 2.918.
+This document describes RDF::Query::Plan::Minus version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -35,7 +32,7 @@ use RDF::Query::ExecutionContext;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -67,7 +64,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "Minus plan can't be executed while already open";
 	}
@@ -131,12 +127,10 @@ sub next {
 	#		warn "using inner row: " . Dumper($inner_row);
 			my @shared	= grep { exists $self->[0]{outer_row_vars}{ $_ } } $inner_row->variables;
 			if (scalar(@shared) == 0) {
-				if ($l->is_trace) {
-					$l->trace("no intersection of domains in minus: $inner_row ⋈ $self->[0]{outer_row}");
-				}
+				$l->trace("no intersection of domains in minus: $inner_row |><| $self->[0]{outer_row}");
 			} elsif (my $joined = $inner_row->join( $self->[0]{outer_row} )) {
 				if ($l->is_trace) {
-					$l->trace("joined bindings in minus: $inner_row ⋈ $self->[0]{outer_row}");
+					$l->trace("joined bindings in minus: $inner_row |><| $self->[0]{outer_row}");
 				}
 #				warn "-> joined\n";
 				$self->[0]{inner_count}++;
@@ -144,19 +138,13 @@ sub next {
 				$ok	= 0;
 				last;
 			} else {
-				if ($l->is_trace) {
-					$l->trace("failed to join bindings in minus: $inner_row ⋈ $self->[0]{outer_row}");
-				}
+				$l->trace("failed to join bindings in minus: $inner_row |><| $self->[0]{outer_row}");
 			}
 		}
 		
 		$self->[0]{needs_new_outer}	= 1;
 		if ($ok) {
-			my $bindings	= $self->[0]{outer_row};
-			if (my $d = $self->delegate) {
-				$d->log_result( $self, $bindings );
-			}
-			return $bindings;
+			return $self->[0]{outer_row};
 		}
 	}
 }
