@@ -7,13 +7,10 @@ RDF::Query::Plan::Offset - Executable query plan for Offsets.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Offset version 2.917.
+This document describes RDF::Query::Plan::Offset version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -28,7 +25,7 @@ use base qw(RDF::Query::Plan);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.917';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -53,7 +50,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "OFFSET plan can't be executed while already open";
 	}
@@ -94,9 +90,6 @@ sub next {
 		$self->[0]{exhausted}	= 1;
 		return undef;
 	}
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $row );
-	}
 	return $row;
 }
 
