@@ -7,13 +7,10 @@ RDF::Query::Plan::Project - Executable query plan for Projects.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Project version 2.919.
+This document describes RDF::Query::Plan::Project version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -22,14 +19,15 @@ package RDF::Query::Plan::Project;
 
 use strict;
 use warnings;
-use Scalar::Util qw(blessed refaddr);
 use base qw(RDF::Query::Plan);
 
+use Scalar::Util qw(blessed);
+
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -60,7 +58,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "PROJECT plan can't be executed while already open";
 	}
@@ -82,7 +79,6 @@ sub execute ($) {
 
 sub next {
 	my $self	= shift;
-	my $ctx		= $self->[0]{context};
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open PROJECT";
 	}
@@ -92,9 +88,9 @@ sub next {
 	my $row		= $plan->next;
 	unless (defined($row)) {
 		$l->trace("no remaining rows in project");
-# 		if ($self->[1]->state == $self->[1]->OPEN) {
-# 			$self->[1]->close();
-# 		}
+		if ($self->[1]->state == $self->[1]->OPEN) {
+			$self->[1]->close();
+		}
 		return;
 	}
 	if ($l->is_trace) {
@@ -110,17 +106,13 @@ sub next {
 	foreach my $e (@$exprs) {
 		my $name		= $e->sse;
 		my $var_or_expr	= $e;
-		my $value		= $query->var_or_expr_value( $bridge, $row, $var_or_expr, $ctx );
+		my $value		= $query->var_or_expr_value( $bridge, $row, $var_or_expr );
 		if ($l->is_trace) {
 			$l->trace( "- project value $name -> $value" );
 		}
 		$proj->{ $name }	= $value;
 	}
 	
-	$l->trace( "- projected row: $proj" );
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $proj );
-	}
 	return $proj;
 }
 
@@ -224,26 +216,6 @@ sub graph {
 	return "$self";
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the plan appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift || '  ';
-	my $count	= shift || 0;
-	my $indent	= $s x $count;
-	my $type	= $self->plan_node_name;
-	my $string	= sprintf("%s%s (0x%x)\n", $indent, $type, refaddr($self));
-	my @vars	= map { RDF::Query::Node::Variable->new( $_ ) } @{$self->[2]};
-	my @exprs	= @{$self->[3]};
-	$string		.= "${indent}${s}" . join(' ', @vars, @exprs) . "\n";
-	$string		.= $self->pattern->explain( $s, $count+1 );
-	return $string;
-}
 
 
 1;
