@@ -7,13 +7,10 @@ RDF::Query::Plan::Quad - Executable query plan for Quads.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Quad version 2.918.
+This document describes RDF::Query::Plan::Quad version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -24,7 +21,7 @@ use strict;
 use warnings;
 use base qw(RDF::Query::Plan);
 
-use Scalar::Util qw(blessed refaddr);
+use Scalar::Util qw(blessed);
 
 use RDF::Query::ExecutionContext;
 use RDF::Query::VariableBindings;
@@ -33,7 +30,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.918';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -105,14 +102,9 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "QUAD plan can't be executed while already open";
 	}
-	
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.quad");
-	$l->trace( "executing RDF::Query::Plan::Quad:" );
-	
 	my @quad	= @{ $self }[ 1..4 ];
 	my $bound	= $context->bound;
 	if (%$bound) {
@@ -124,15 +116,9 @@ sub execute ($) {
 	}
 	
 	my $model	= $context->model;
-	
-	my @names	= qw(subject predicate object context);
-	foreach my $i (0 .. 3) {
-		$l->trace( sprintf("- quad %10s: %s", $names[$i], $quad[$i]) );
-	}
-	
 	my $iter	= $model->get_statements( @quad[0..3] );
+	
 	if (blessed($iter)) {
-		$l->trace("got quad iterator");
 		$self->[0]{iter}	= $iter;
 		$self->[0]{bound}	= $bound;
 		$self->state( $self->OPEN );
@@ -152,11 +138,7 @@ sub next {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open QUAD";
 	}
 	my $iter	= $self->[0]{iter};
-	
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.quad");
-	$l->trace("next() called on Quad plan");
 	LOOP: while (my $row = $iter->next) {
-		$l->trace("got quad: " . $row->as_string);
 		if (my $data = $self->[0]{dups}) {
 			foreach my $pos (values %$data) {
 				my @pos	= @$pos;
@@ -164,17 +146,15 @@ sub next {
 				my $first			= $row->$first_method();
 				foreach my $p (@pos) {
 					unless ($first->equal( $row->$p() )) {
-						use Data::Dumper;
-						$l->trace("Quad $first_method and $p didn't match: " . Dumper($first, $row->$p()));
 						next LOOP;
 					}
 				}
 			}
 		}
 		
-# 		if ($row->context->isa('RDF::Trine::Node::Nil')) {
-# 			next;
-# 		}
+		if ($row->context->isa('RDF::Trine::Node::Nil')) {
+			next;
+		}
 		
 		my $binding	= {};
 		foreach my $key (keys %{ $self->[0]{mappings} }) {
@@ -189,12 +169,8 @@ sub next {
 			}
 		}
 		@{ $bindings }{ keys %$pre_bound }	= values %$pre_bound;
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $bindings );
-		}
 		return $bindings;
 	}
-	$l->trace("No more quads");
 	return;
 }
 
@@ -205,7 +181,6 @@ sub next {
 sub close {
 	my $self	= shift;
 	unless ($self->state == $self->OPEN) {
-		Carp::cluck;
 		throw RDF::Query::Error::ExecutionError -text => "close() cannot be called on an un-open QUAD";
 	}
 	delete $self->[0]{iter};
@@ -303,28 +278,6 @@ sub plan_node_data {
 	return ($self->nodes);
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the query plan appropriate for display
-on the command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my ($s, $count)	= ('  ', 0);
-	if (@_) {
-		$s		= shift;
-		$count	= shift;
-	}
-	my $indent	= '' . ($s x $count);
-	my $type	= $self->plan_node_name;
-	my $string	= sprintf("%s%s (0x%x)\n", $indent, $type, refaddr($self))
-				. "${indent}${s}"
-				. join(' ', map { ($_->isa('RDF::Trine::Node::Nil')) ? "(nil)" : $_->as_sparql } $self->plan_node_data) . "\n";
-	return $string;
-}
-
 =item C<< graph ( $g ) >>
 
 =cut
@@ -344,6 +297,7 @@ sub graph {
 	return "$self";
 }
 
+
 1;
 
 __END__
