@@ -7,13 +7,10 @@ RDF::Query::Plan::Sequence - Executable query plan for a sequence of operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Sequence version 2.919.
+This document describes RDF::Query::Plan::Sequence version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -31,7 +28,7 @@ use RDF::Trine::Statement;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -54,7 +51,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "SEQUENCE plan can't be executed twice";
 	}
@@ -91,9 +87,6 @@ sub next {
 	
 	my $iter	= $self->[0]{iter};
 	my $row		= $iter->next;
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $row );
-	}
 	return $row;
 }
 
