@@ -7,13 +7,10 @@ RDF::Query::Plan::Service - Executable query plan for remote SPARQL queries.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Service version 2.919.
+This document describes RDF::Query::Plan::Service version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -25,7 +22,7 @@ use warnings;
 use base qw(RDF::Query::Plan);
 
 use Data::Dumper;
-use Scalar::Util qw(blessed refaddr);
+use Scalar::Util qw(blessed);
 use Storable qw(store_fd fd_retrieve);
 use URI::Escape;
 
@@ -37,15 +34,15 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION		= '2.919';
+	$VERSION		= '3.000_01';
 }
 
 ######################################################################
 
-=item C<< new ( $endpoint, $plan, $silent, $sparql, [ \%logging_keys ] ) >>
+=item C<< new ( $endpoint, $plan, $sparql, [ \%logging_keys ] ) >>
 
 Returns a new SERVICE (remote endpoint call) query plan object. C<<$endpoint>>
-is the URL of the endpoint (as a node object). C<<$plan>> is the query plan
+is the URL of the endpoint (as a string). C<<$plan>> is the query plan
 representing the query to be sent to the remote endpoint (needed for cost
 estimates). C<<$sparql>> is the serialized SPARQL query to be sent to the remote
 endpoint. Finally, if present, C<<%logging_keys>> is a HASH containing the keys
@@ -56,23 +53,15 @@ to use in logging the execution of this plan. Valid HASH keys are:
 =cut
 
 sub new {
-	my $class		= shift;
-	my $endpoint	= shift;
-	my $plan		= shift;
-	my $silent		= shift;
-	my $sparql		= shift;
+	my $class	= shift;
+	my $url		= shift;
+	my $plan	= shift;
+	my $sparql	= shift;
 	unless ($sparql) {
 		throw RDF::Query::Error::MethodInvocationError -text => "SERVICE plan constructor requires a serialized SPARQL query argument";
 	}
-	my $keys	= {};
-	my $self;
-	if ($endpoint->isa('RDF::Query::Node::Variable')) {
-		my $lhs		= shift;
-		Carp::confess "no lhs to binary SERVICE plan" unless ($lhs);
-		$self	= $class->SUPER::new( $endpoint, $plan, $silent, $sparql, $lhs );
-	} else {
-		$self	= $class->SUPER::new( $endpoint, $plan, $silent, $sparql );
-	}
+	my $keys	= shift || {};
+	my $self	= $class->SUPER::new( $url, $plan, $sparql );
 	$self->[0]{referenced_variables}	= [ $plan->referenced_variables ];
 	$self->[0]{logging_keys}	= $keys;
 # 	if (@_) {
@@ -104,7 +93,7 @@ sub new_from_plan {
 	}
 	my $ns		= $context->ns;
 	my $sparql	= join("\n",
-						(map { sprintf("PREFIX %s: <%s>", ($_ eq '__DEFAULT__' ? '' : $_), $ns->{$_}) } (keys %$ns)),
+						(map { sprintf("PREFIX %s: <%s>", $_, $ns->{$_}) } (keys %$ns)),
 						sprintf("SELECT * WHERE %s", $pattern->as_sparql({namespaces => $ns}, ''))
 					);
 	my $service	= $class->new( $url, $plan, $sparql, @_ );
@@ -118,46 +107,73 @@ sub new_from_plan {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "SERVICE plan can't be executed while already open";
 	}
 	my $l			= Log::Log4perl->get_logger("rdf.query.plan.service");
 	my $endpoint	= $self->endpoint;
-	
-	my $bound		= $context->bound || {};
-	my $sparql		= $self->sparql( $bound );
+	my $sparql		= $self->sparql;
+	my $url			= $endpoint . '?query=' . uri_escape($sparql);
 	my $query		= $context->query;
 	
-	if ($self->lhs) {
-		$self->lhs->execute( $context );
-		$self->[0]{context}	= $context;
+	if ($ENV{RDFQUERY_THROW_ON_SERVICE}) {
+		my $l	= Log::Log4perl->get_logger("rdf.query.plan.service");
+		$l->warn("SERVICE REQUEST $endpoint:{{{\n$sparql\n}}}\n");
+		$l->warn("QUERY LENGTH: " . length($sparql) . "\n");
+		$l->warn("QUERY URL: $url\n");
+		throw RDF::Query::Error::RequestedInterruptError -text => "Won't execute SERVICE block. Unset RDFQUERY_THROW_ON_SERVICE to continue.";
+	}
+	
+	{
+		$l->debug('SERVICE execute');
+		my $printable	= $sparql;
+		$l->debug("SERVICE <$endpoint> pattern: $printable");
+		$l->trace( 'SERVICE URL: ' . $url );
+	}
+	
+# 	my $serial	= 0;
+# 	my ($fh, $write);
+# 	if ($serial) {
+# 		pipe($fh, $write);
+# 		my $stdout	= select();
+# 		select($write);
+# 		$self->_get_and_parse_url( $context, $url, $write, $$ );
+# 		warn '*********';
+# 		select($stdout);
+# 		warn '*********';
+# 	} else {
+# 		my $pid = open $fh, "-|";
+# 		die unless defined $pid;
+# 		unless ($pid) {
+# 			$RDF::Trine::Store::DBI::IGNORE_CLEANUP	= 1;
+# 			$self->_get_and_parse_url( $context, $url, $fh, $pid );
+# 			exit 0;
+# 		}
+# 	}
+# 		warn '*********';
+# 	
+# 	my $count	= 0;
+# 	my $open	= 1;
+# 	warn '<<<<';
+# 	my $args	= fd_retrieve $fh or die "I can't read args from file descriptor\n";
+# 	warn '>>>>';
+# 	if (ref($args)) {
+	
+	my $iter	= $self->_get_iterator( $context, $url );
+	if ($iter) {
+# 		$self->[0]{args}	= $args;
+# 		$self->[0]{fh}		= $fh;
+# 		$self->[0]{'write'}	= $write;
+		$self->[0]{iter}	= $iter;
 		$self->[0]{'open'}	= 1;
 		$self->[0]{'count'}	= 0;
 		$self->[0]{logger}	= $context->logger;
+		if (my $log = $self->[0]{logger}) {
+			$log->push_value( service_endpoints => $endpoint );
+		}
 		$self->state( $self->OPEN );
 	} else {
-		{
-			$l->debug('SERVICE execute');
-			my $printable	= $sparql;
-			$l->debug("SERVICE <$endpoint> pattern: $printable");
-		}
-		my $iter	= $self->_get_iterator( $context, $endpoint->uri_value, $sparql );
-		if ($iter) {
-	# 		$self->[0]{args}	= $args;
-	# 		$self->[0]{fh}		= $fh;
-	# 		$self->[0]{'write'}	= $write;
-			$self->[0]{iter}	= $iter;
-			$self->[0]{'open'}	= 1;
-			$self->[0]{'count'}	= 0;
-			$self->[0]{logger}	= $context->logger;
-			if (my $log = $self->[0]{logger}) {
-				$log->push_value( service_endpoints => $endpoint );
-			}
-			$self->state( $self->OPEN );
-		} else {
-			warn "no iterator in execute()";
-		}
+		warn "no iterator in execute()";
 	}
 	$self;
 }
@@ -172,53 +188,28 @@ sub next {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open SERVICE";
 	}
 	return undef unless ($self->[0]{'open'});
-	if ($self->lhs) {
-		while (1) {
-			if ($self->[0]{iter_stash}) {
-				while (my $row = $self->[0]{iter_stash}->next) {
-# 					warn "got service RHS row: $row\n";
-					my $lhs		= $self->[0]{lhs_row};
-# 					warn "joining:\n\t$row\n\t$lhs\n";
-					if (my $j = $row->join( $lhs )) {
-						return $j;
-					}
-				}
-				delete $self->[0]{iter_stash};
-			}
-			my $lrow	= $self->lhs->next;
-			unless ($lrow) {
-# 				warn "reached end of service LHS iterator\n";
-				delete $self->[0]{lhs_row};
-				return undef;
-			}
-# 			warn "got service LHS row: $lrow\n";
-			$self->[0]{lhs_row}	= $lrow;
-			my $endpoint	= $lrow->{ $self->endpoint->name };
-			unless (blessed($endpoint) and $endpoint->isa('RDF::Query::Node::Resource')) {
-				throw RDF::Query::Error::ExecutionError -text => "Endpoint variable bound to non-IRI";
-			}
-			my $context	= $self->[0]{context};
-			my $bound	= $context->bound || {};
-			my $sparql	= $self->sparql( $bound );
-			my $plan	= $RDF::Query::Plan::PLAN_CLASSES{'service'}->new( $endpoint, $self->pattern, $self->silent, $sparql );
-# 			warn $plan;
-			my $iter	= $plan->execute( $context );
-			return undef unless ($iter);
-			$self->[0]{iter_stash}	= $iter;
-		}
-	} else {
-		my $iter	= $self->[0]{iter};
-		my $result	= $iter->next;
-		return undef unless $result;
-		$self->[0]{'count'}++;
-		my $row	= RDF::Query::VariableBindings->new( $result );
-		$row->label( origin => [ $self->endpoint ] );
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $row );
-		}
-		return $row;
-	}
-}
+# 	my $fh	= $self->[0]{fh};
+# 	warn 'calling fd_retrieve';
+# 	my $result = fd_retrieve $fh or die "I can't read from file descriptor\n";
+# 	warn 'got result: ' . Dumper($result);
+# 	if (not($result) or ref($result) ne 'HASH') {
+# 		if (my $log = $self->[0]{logger}) {
+# 			$log->push_key_value( 'cardinality-service', $self->[3], $self->[0]{'count'} );
+# 			if (my $bf = $self->[0]{ 'log-service-pattern' }) {
+# 				$log->push_key_value( 'cardinality-bf-service-' . $self->[1], $bf, $self->[0]{'count'} );
+# 			}
+# 		}
+# 		$self->[0]{'open'}	= 0;
+# 		return undef;
+# 	}
+	my $iter	= $self->[0]{iter};
+	my $result	= $iter->next;
+	return undef unless $result;
+	$self->[0]{'count'}++;
+	my $row	= RDF::Query::VariableBindings->new( $result );
+	$row->label( origin => [ $self->endpoint ] );
+	return $row;
+};
 
 =item C<< close >>
 
@@ -248,14 +239,10 @@ sub close {
 }
 
 sub _get_iterator {
-	my $self		= shift;
-	my $context		= shift;
-	my $endpoint	= shift;
-	my $sparql		= shift;
-	my $url			= $endpoint . '?query=' . uri_escape($sparql);
-	my $l			= Log::Log4perl->get_logger("rdf.query.plan.service");
-	$l->trace( 'SERVICE URL: ' . $url );
-	my $query		= $context->query;
+	my $self	= shift;
+	my $context	= shift;
+	my $url		= shift;
+	my $query	= $context->query;
 	
 	my $handler	= RDF::Trine::Iterator::SAXHandler->new();
 	my $p		= XML::SAX::ParserFactory->parser(Handler => $handler);
@@ -269,43 +256,19 @@ sub _get_iterator {
 						$u;
 					};
 	
-	my $req			= HTTP::Request->new('GET', $url );
-	my $response	= $self->_request( $ua, $req );
-	if (blessed($response) and $response->is_success) {
+	my $response	= $ua->get( $url );
+	if ($response->is_success) {
 		$p->parse_string( $response->content );
 		return $handler->iterator;
-	} elsif ($self->silent) {
-		my $v		= RDF::Query::VariableBindings->new( {} );
-		my $iter	= RDF::Trine::Iterator::Bindings->new( [ $v ] );
-		return $iter;
 	} else {
 		my $status		= $response->status_line;
 		my $sparql		= $self->sparql;
-# 		warn "url: $url\n";
-		unless ($self->silent) {
-			throw RDF::Query::Error::ExecutionError -text => "*** error making remote SPARQL call to endpoint $endpoint ($status) while making service call for query: $sparql";
-		}
+		my $endpoint	= $self->endpoint;
+		warn "url: $url\n";
+		throw RDF::Query::Error::ExecutionError -text => "*** error making remote SPARQL call to endpoint $endpoint ($status) while making service call for query: $sparql";
 	}
 }
 
-sub _request {
-	my $self	= shift;
-	my $ua		= shift;
-	my $req		= shift;
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.service");
-	
-	if ($ENV{RDFQUERY_THROW_ON_SERVICE}) {
-		if ($self->silent) {
-			return;
-		} else {
-			throw RDF::Query::Error::RequestedInterruptError -text => "Won't execute SERVICE block. Unset RDFQUERY_THROW_ON_SERVICE to continue.";
-		}
-	}
-	
-	my $response	= $ua->request( $req );
-	return $response;
-}
-
 # sub _get_and_parse_url {
 # 	my $self	= shift;
 # 	my $context	= shift;
@@ -367,11 +330,7 @@ sub _request {
 
 sub endpoint {
 	my $self	= shift;
-	if (@_) {
-		$self->[1]	= shift;
-	}
-	my $e		= $self->[1];
-	return $e;
+	return $self->[1];
 }
 
 =item C<< sparql >>
@@ -381,31 +340,6 @@ Returns the SPARQL query (as a string) that will be sent to the remote endpoint.
 =cut
 
 sub sparql {
-	my $self	= shift;
-	my $sparql	= $self->[4];
-	if (ref($sparql)) {
-		$sparql	= $sparql->( @_ );
-	}
-	return $sparql;
-}
-
-=item C<< lhs >>
-
-=cut
-
-sub lhs {
-	my $self	= shift;
-	my $lhs		= $self->[5];
-	return $lhs;
-}
-
-=item C<< silent >>
-
-Returns a boolean value indicating whether the service plan will ignore errors.
-
-=cut
-
-sub silent {
 	my $self	= shift;
 	return $self->[3];
 }
@@ -490,35 +424,12 @@ sub plan_node_data {
 sub graph {
 	my $self	= shift;
 	my $g		= shift;
-	$g->add_node( "$self", label => "Service (" . $self->endpoint->value . ")" . $self->graph_labels );
+	$g->add_node( "$self", label => "Service (" . $self->endpoint . ")" . $self->graph_labels );
 	$g->add_node( "${self}-sparql", label => $self->sparql );
 	$g->add_edge( "$self" => "${self}-sparql" );
 	return "$self";
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the query plan appropriate for display
-on the command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my ($s, $count)	= ('  ', 0);
-	if (@_) {
-		$s		= shift;
-		$count	= shift;
-	}
-	my $indent	= '' . ($s x $count);
-	my $type	= $self->plan_node_name;
-	my $sparql	= $self->sparql;
-	$sparql		=~ s/\n/\n${indent}${s}${s}/g;
-	my $string	= sprintf("%s%s (0x%x)\n", $indent, $type, refaddr($self))
-				. "${indent}${s}" . $self->endpoint->as_string . "\n"
-				. "${indent}${s}${sparql}\n";
-	return $string;
-}
 
 1;
 
