@@ -7,13 +7,10 @@ RDF::Query::Plan::Sort - Executable query plan for Sorts.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Sort version 2.919.
+This document describes RDF::Query::Plan::Sort version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -22,14 +19,13 @@ package RDF::Query::Plan::Sort;
 
 use strict;
 use warnings;
-use Scalar::Util qw(refaddr);
 use base qw(RDF::Query::Plan);
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -58,31 +54,20 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "SORT plan can't be executed while already open";
 	}
 	my $plan	= $self->[1];
 	$plan->execute( $context );
 	
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.sort");
-	$l->trace("executing sort");
 	if ($plan->state == $self->OPEN) {
 		my $exprs	= $self->[2];
 		my @rows	= $plan->get_all;
-		if ($l->is_trace) {
-			$l->trace("sorting result list:");
-			$l->trace("- $_") foreach (@rows);
-		}
 		my $query	= $context->query;
 		
 		use sort 'stable';
-		my @sorted	= sort { _cmp_rows( $context, $exprs, $a, $b ) } @rows;
-		if ($l->is_trace) {
-			$l->trace("sorted list:");
-			$l->trace("- $_") foreach (@sorted);
-		}
-		$self->[0]{rows}	= \@sorted;
+		@rows		= sort { _cmp_rows( $context, $exprs, $a, $b ) } @rows;
+		$self->[0]{rows}	= \@rows;
 		$self->state( $self->OPEN );
 	} else {
 		warn "could not execute plan in distinct";
@@ -99,11 +84,7 @@ sub next {
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open SORT";
 	}
-	my $bindings	= shift(@{ $self->[0]{rows} });
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $bindings );
-	}
-	return $bindings;
+	return shift(@{ $self->[0]{rows} });
 }
 
 =item C<< close >>
@@ -126,29 +107,24 @@ sub _cmp_rows {
 	my $a		= shift;
 	my $b		= shift;
 	
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.sort");
 	my $query	= $context->query || 'RDF::Query';
 	my $bridge	= $context->model;
 	
 	no warnings 'numeric';
-	no warnings 'uninitialized';
 	foreach my $data (@$exprs) {
 		my ($expr, $rev)	= @$data;
-		my $a_val	= $query->var_or_expr_value( $a, $expr, $context );
-		my $b_val	= $query->var_or_expr_value( $b, $expr, $context );
+		my $a_val	= $query->var_or_expr_value( $a, $expr );
+		my $b_val	= $query->var_or_expr_value( $b, $expr );
 		local($RDF::Query::Node::Literal::LAZY_COMPARISONS)	= 1;
-		$l->trace("comparing $a_val <=> $b_val");
 		my $cmp		= $a_val <=> $b_val;
 		if ($cmp != 0) {
 			if ($rev) {
 				$cmp	*= -1;
 			}
-			$l->trace("==> $cmp");
 			return $cmp;
 		} else {
 		}
 	}
-	$l->trace("==> 0");
 	return 0;
 }
 
@@ -237,30 +213,6 @@ sub graph {
 	return "$self";
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the plan appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $type	= $self->plan_node_name;
-	my $string	= sprintf("%s%s (0x%x)\n", $indent, $type, refaddr($self));
-	$string		.= "${indent}${s}sory by:\n";
-	my $exprs	= $self->[2];
-	foreach my $e (@$exprs) {
-		my $dir		= ($e->[1] == 0 ? 'asc  ' : 'desc ');
-		$string		.= "${indent}${s}${s}${dir}" . $e->[0] . "\n";
-	}
-	$string		.= $self->pattern->explain( $s, $count+1 );
-	return $string;
-}
-
 
 1;
 
