@@ -7,13 +7,10 @@ RDF::Query::Plan::SubSelect - Executable query plan for sub-select queries.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::SubSelect version 2.919.
+This document describes RDF::Query::Plan::SubSelect version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -37,7 +34,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION		= '2.919';
+	$VERSION		= '3.000_01';
 }
 
 ######################################################################
@@ -52,12 +49,8 @@ representing a SELECT query.
 sub new {
 	my $class	= shift;
 	my $query	= shift;
-	my $plan	= shift;
-	unless (blessed($plan) and $plan->isa('RDF::Query::Plan')) {
-		Carp::confess;
-	}
-	my $keys	= {};
-	my $self	= $class->SUPER::new( $query, $plan );
+	my $keys	= shift || {};
+	my $self	= $class->SUPER::new( $query );
 	$self->[0]{referenced_variables}	= [ $query->variables ];
 	$self->[0]{logging_keys}	= $keys;
 	return $self;
@@ -70,15 +63,12 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "SUBSELECT plan can't be executed while already open";
 	}
-	my $l				= Log::Log4perl->get_logger("rdf.query.plan.subselect");
-	$l->trace("executing subselect");
-	my $plan			= $self->plan;
-	$l->trace("subselect plan: " . $plan->sse);
-	my $iter			= $plan->execute( $context );
+	my $l		= Log::Log4perl->get_logger("rdf.query.plan.subselect");
+	my $query	= $self->query;
+	my $iter	= $query->execute( $context->model );
 	if ($iter) {
 		$self->[0]{iter}	= $iter;
 		$self->[0]{'open'}	= 1;
@@ -100,18 +90,13 @@ sub next {
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open SERVICE";
 	}
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.subselect");
 	return undef unless ($self->[0]{'open'});
 	my $iter	= $self->[0]{iter};
 	my $result	= $iter->next;
 	
 	return undef unless $result;
-	$l->trace("- got subselect result $result");
 	$self->[0]{'count'}++;
 	my $row	= RDF::Query::VariableBindings->new( $result );
-	if (my $d = $self->delegate) {
-		$d->log_result( $self, $row );
-	}
 	return $row;
 };
 
@@ -124,10 +109,6 @@ sub close {
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "close() cannot be called on an un-open SERVICE";
 	}
-	my $plan			= $self->plan;
-	if (defined($plan)) {
-		$plan->close();
-	}
 	delete $self->[0]{iter};
 	delete $self->[0]{args};
 	delete $self->[0]{count};
@@ -145,17 +126,6 @@ sub query {
 	return $self->[1];
 }
 
-=item C<< plan >>
-
-Returns the sub-select query plan object.
-
-=cut
-
-sub plan {
-	my $self	= shift;
-	return $self->[2];
-}
-
 =item C<< distinct >>
 
 Returns true if the pattern is guaranteed to return distinct results.
@@ -202,7 +172,7 @@ identifiers.
 
 sub plan_prototype {
 	my $self	= shift;
-	return qw(P);
+	return qw(Q);
 }
 
 =item C<< plan_node_data >>
@@ -214,7 +184,7 @@ the signature returned by C<< plan_prototype >>.
 
 sub plan_node_data {
 	my $self	= shift;
-	return ($self->plan);
+	return ($self->query);
 }
 
 =item C<< graph ( $g ) >>
