@@ -7,13 +7,10 @@ RDF::Query::Plan::ThresholdUnion - Executable query plan for unions.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::ThresholdUnion version 2.919.
+This document describes RDF::Query::Plan::ThresholdUnion version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -33,7 +30,7 @@ use RDF::Query::ExecutionContext;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -64,7 +61,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "ThresholdUnion plan can't be executed while already open";
 	}
@@ -101,9 +97,6 @@ sub next {
 	my $row		= $iter->next;
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.thresholdunion");
 	if ($row) {
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $row );
-		}
 		return $row;
 	} else {
 		$l->trace("thresholdunion sub-plan finished");
@@ -132,11 +125,7 @@ sub next {
 		$iter->execute( $self->[0]{context} );
 		if ($iter->state == $self->OPEN) {
 			$self->[0]{iter}	= $iter;
-			my $bindings	= $self->next;
-			if (my $d = $self->delegate) {
-				$d->log_result( $self, $bindings );
-			}
-			return $bindings;
+			return $self->next;
 		} else {
 			throw RDF::Query::Error::ExecutionError -text => "execute() on child [${index}] of UNION failed during next()";
 		}
