@@ -7,13 +7,10 @@ RDF::Query::Plan::Triple - Executable query plan for Triples.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Triple version 2.919.
+This document describes RDF::Query::Plan::Triple version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -35,7 +32,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -107,7 +104,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "TRIPLE plan can't be executed while already open";
 	}
@@ -184,9 +180,6 @@ sub next {
 		}
 		@{ $bindings }{ keys %$pre_bound }	= values %$pre_bound;
 		$self->[0]{count}++;
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $bindings );
-		}
 		return $bindings;
 	}
 	return;
