@@ -7,13 +7,10 @@ RDF::Query::Plan::Union - Executable query plan for unions.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Union version 2.919.
+This document describes RDF::Query::Plan::Union version 3.000_01, released 30 January 2010.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Plan> class.
-
 =over 4
 
 =cut
@@ -32,7 +29,7 @@ use RDF::Query::ExecutionContext;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -60,7 +57,6 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
-	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "BGP plan can't be executed while already open";
 	}
@@ -85,7 +81,6 @@ sub execute ($) {
 
 sub next {
 	my $self	= shift;
-	my $l		= Log::Log4perl->get_logger("rdf.query.plan.union");
 	unless ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "next() cannot be called on an un-open BGP";
 	}
@@ -93,10 +88,6 @@ sub next {
 	return undef unless ($iter);
 	my $row		= $iter->next;
 	if (defined($row)) {
-		$l->trace( "union row: $row" );
-		if (my $d = $self->delegate) {
-			$d->log_result( $self, $row );
-		}
 		return $row;
 	} else {
 		$self->[0]{iter}	= undef;
@@ -107,18 +98,12 @@ sub next {
 			my $iter	= $self->[1][ $index ];
 			$iter->execute( $self->[0]{context} );
 			if ($iter->state == $self->OPEN) {
-				$l->trace( "union moving to next branch" );
 				$self->[0]{iter}	= $iter;
-				my $bindings	= $self->next;
-				if (my $d = $self->delegate) {
-					$d->log_result( $self, $bindings );
-				}
-				return $bindings;
+				return $self->next;
 			} else {
 				throw RDF::Query::Error::ExecutionError -text => "execute() on RHS of UNION failed during next()";
 			}
 		} else {
-			$l->trace( "union reached end of last branch" );
 			$iter->close();
 			delete $self->[0]{iter};
 			return undef;
