@@ -7,7 +7,7 @@ RDF::Query::Util - Miscellaneous utility functions to support work with RDF::Que
 
 =head1 VERSION
 
-This document describes RDF::Query::Util version 2.919.
+This document describes RDF::Query::Util version 3.000_01, released 30 January 2010.
 
 =head1 SYNOPSIS
 
@@ -33,14 +33,12 @@ use Carp qw(carp croak confess);
 use URI::file;
 use RDF::Query;
 use LWP::Simple;
-use File::Spec;
-use JSON;
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.919';
+	$VERSION	= '3.000_01';
 }
 
 ######################################################################
@@ -72,15 +70,6 @@ PREFIX wn: <http://xmlns.com/wordnet/1.6/>
 PREFIX wot: <http://xmlns.com/wot/0.1/>
 END
 
-{
-	my $file	= File::Spec->catfile($ENV{HOME}, '.prefix-cmd', 'prefixes.json');
-	if (-r $file) {
-		my $json		= do { local($/) = undef; open( my $fh, '<', $file ) or next; <$fh> };
-		my $prefixes	= from_json($json);
-		$PREFIXES	= join("\n", map { "PREFIX $_: <" . $prefixes->{$_} . ">" } (keys %$prefixes));
-	}
-}
-
 =item C<< cli_make_query_and_model >>
 
 Returns a query object, model, and args HASHref based on the arguments in @ARGV.
@@ -104,7 +93,7 @@ following the final argument parsed by C<< &cli_parse_args >>.
 =cut
 
 sub cli_make_query {
-	my %args	= cli_parse_args(@_);
+	my %args	= cli_parse_args();
 	my $class	= delete $args{ class } || 'RDF::Query';
 	my $sparql	= delete $args{ query };
 	my $l		= Log::Log4perl->get_logger("rdf.query.util");
@@ -192,17 +181,18 @@ sub make_model {
 		return $model;
 	} else {
 		# create a temporary triplestore, and wrap it into a model
-		my $model	= RDF::Trine::Model->temporary_model;
+		my $store	= RDF::Trine::Store::DBI->temporary_store();
+		my $model	= RDF::Trine::Model->new( $store );
 		
 		# read in the list of files with RDF/XML content for querying
 		my @files	= @_;
 		
+		# create a rdf/xml parser object that we'll use to read in the rdf data
+		my $parser	= RDF::Trine::Parser->new('rdfxml');
+		
 		# loop over all the files
 		foreach my $i (0 .. $#files) {
 			my $file	= $files[ $i ];
-			my $pclass	= RDF::Trine::Parser->guess_parser_by_filename( $file ) || 'RDF::Trine::Parser::RDFXML';
-			my $parser	= $pclass->new();
-			
 			if ($file =~ m<^https?:\/\/>) {
 				$l->debug("fetching RDF from $file ...");
 				$parser->parse_url_into_model( $file, $model );
@@ -226,10 +216,11 @@ The allowable arguments are listed below.
 =cut
 
 sub cli_parse_args {
-	my %args	= @_;
+	my %args;
 	$args{ class }	= 'RDF::Query';
 	my @service_descriptions;
 	
+	return unless (@ARGV);
 	while (scalar(@ARGV) and $ARGV[0] =~ /^-(\w+)/) {
 		my $opt	= shift(@ARGV);
 		if ($opt eq '-e') {
@@ -240,12 +231,6 @@ sub cli_parse_args {
 			$args{ optimize }	= 1;
 		} elsif ($opt eq '-o') {
 			$args{ force_no_optimization }	= 1;
-		} elsif ($opt eq '-k') {
-			$args{ canonicalize }	= 1;
-		} elsif ($opt eq '-C') {
-			my $k	= shift(@ARGV);
-			my $v	= shift(@ARGV);
-			$args{ $k }	= $v;
 		} elsif ($opt eq '-c') {
 			my $class		= shift(@ARGV);
 			eval "require $class";
@@ -295,17 +280,7 @@ sub cli_parse_args {
 		} elsif ($opt eq '-m') {
 			$args{ model }	= shift(@ARGV);
 		} elsif ($opt eq '-w') {
-			if (exists($args{update}) and not($args{update})) {
-				warn "Model requested to be both read-only and read-write.\n";
-			} else {
-				$args{ update }	= 1;
-			}
-		} elsif ($opt eq '-r') {
-			if (exists($args{update}) and $args{update}) {
-				warn "Model requested to be both read-only and read-write.\n";
-			} else {
-				$args{ update }	= 0;
-			}
+			$args{ update }	= 1;
 		} elsif ($opt eq '--') {
 			last;
 		}
@@ -320,7 +295,7 @@ sub cli_parse_args {
 			my $file	= shift(@ARGV);
 			my $sparql	= ($file eq '-')
 						? do { local($/) = undef; <> }
-						: do { local($/) = undef; open(my $fh, '<', $file) || croak $!; binmode($fh, ':utf8'); <$fh> };
+						: do { local($/) = undef; open(my $fh, '<', $file) || die $!; binmode($fh, ':utf8'); <$fh> };
 			$args{ query }	= $sparql;
 		}
 	}
@@ -334,6 +309,41 @@ sub cli_parse_args {
 	return %args;
 }
 
+=item C<< start_endpoint ( $model, $port ) >>
+
+Starts an SPARQL endpoint HTTP server on port $port.
+
+If called in list context, returns the PID and the actual port the server bound
+to. If called in scalar context, returns only the port.
+
+=cut
+
+sub start_endpoint {
+	my $model	= shift;
+	my $port	= shift;
+	my $path	= shift;
+	
+	require CGI;
+	require RDF::Endpoint::Server;
+	
+	local($ENV{TMPDIR})	= '/tmp';
+	my $cgi	= CGI->new;
+	my $s	= RDF::Endpoint::Server->new_with_model( $model,
+				Port		=> $port,
+				Prefix		=> '',
+				CGI			=> $cgi,
+				IncludePath	=> $path,
+			);
+	
+	my $pid	= $s->background();
+#	warn "Endpoint started as [$pid]\n";
+	if (wantarray) {
+		return ($pid, $port);
+	} else {
+		return $port;
+	}
+}
+
 1;
 
 __END__
